menu

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 28, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the menu type in the database.
	Label = "menu"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedByID holds the string denoting the created_by_id field in the database.
	FieldCreatedByID = "created_by_id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedByID holds the string denoting the updated_by_id field in the database.
	FieldUpdatedByID = "updated_by_id"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldDeletedByID holds the string denoting the deleted_by_id field in the database.
	FieldDeletedByID = "deleted_by_id"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldPublishedAt holds the string denoting the published_at field in the database.
	FieldPublishedAt = "published_at"
	// FieldArchivedAt holds the string denoting the archived_at field in the database.
	FieldArchivedAt = "archived_at"
	// FieldOwnerDomainID holds the string denoting the owner_domain_id field in the database.
	FieldOwnerDomainID = "owner_domain_id"
	// FieldParentID holds the string denoting the parent_id field in the database.
	FieldParentID = "parent_id"
	// FieldPath holds the string denoting the path field in the database.
	FieldPath = "path"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldComponent holds the string denoting the component field in the database.
	FieldComponent = "component"
	// FieldRedirect holds the string denoting the redirect field in the database.
	FieldRedirect = "redirect"
	// FieldHidden holds the string denoting the hidden field in the database.
	FieldHidden = "hidden"
	// FieldAffix holds the string denoting the affix field in the database.
	FieldAffix = "affix"
	// FieldIcon holds the string denoting the icon field in the database.
	FieldIcon = "icon"
	// FieldSort holds the string denoting the sort field in the database.
	FieldSort = "sort"
	// FieldMeta holds the string denoting the meta field in the database.
	FieldMeta = "meta"
	// FieldParams holds the string denoting the params field in the database.
	FieldParams = "params"
	// EdgeRoles holds the string denoting the roles edge name in mutations.
	EdgeRoles = "roles"
	// EdgeParent holds the string denoting the parent edge name in mutations.
	EdgeParent = "parent"
	// EdgeChildren holds the string denoting the children edge name in mutations.
	EdgeChildren = "children"
	// Table holds the table name of the menu in the database.
	Table = "menus"
	// RolesTable is the table that holds the roles relation/edge. The primary key declared below.
	RolesTable = "role_menus"
	// RolesInverseTable is the table name for the Role entity.
	// It exists in this package in order to avoid circular dependency with the "role" package.
	RolesInverseTable = "roles"
	// ParentTable is the table that holds the parent relation/edge.
	ParentTable = "menus"
	// ParentColumn is the table column denoting the parent relation/edge.
	ParentColumn = "parent_id"
	// ChildrenTable is the table that holds the children relation/edge.
	ChildrenTable = "menus"
	// ChildrenColumn is the table column denoting the children relation/edge.
	ChildrenColumn = "parent_id"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// PathValidator is a validator for the "path" field. It is called by the builders before save.
	PathValidator func(string) error
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// DefaultHidden holds the default value on creation for the "hidden" field.
	DefaultHidden bool
	// DefaultAffix holds the default value on creation for the "affix" field.
	DefaultAffix bool
	// DefaultSort holds the default value on creation for the "sort" field.
	DefaultSort int
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for menu fields.

var (
	// RolesPrimaryKey and RolesColumn2 are the table columns denoting the
	// primary key for the roles relation (M2M).
	RolesPrimaryKey = []string{"role_id", "menu_id"}
)

Functions

func Affix

func Affix(v bool) predicate.Menu

Affix applies equality check predicate on the "affix" field. It's identical to AffixEQ.

func AffixEQ

func AffixEQ(v bool) predicate.Menu

AffixEQ applies the EQ predicate on the "affix" field.

func AffixNEQ

func AffixNEQ(v bool) predicate.Menu

AffixNEQ applies the NEQ predicate on the "affix" field.

func And

func And(predicates ...predicate.Menu) predicate.Menu

And groups predicates with the AND operator between them.

func ArchivedAt

func ArchivedAt(v time.Time) predicate.Menu

ArchivedAt applies equality check predicate on the "archived_at" field. It's identical to ArchivedAtEQ.

func ArchivedAtEQ

func ArchivedAtEQ(v time.Time) predicate.Menu

ArchivedAtEQ applies the EQ predicate on the "archived_at" field.

func ArchivedAtGT

func ArchivedAtGT(v time.Time) predicate.Menu

ArchivedAtGT applies the GT predicate on the "archived_at" field.

func ArchivedAtGTE

func ArchivedAtGTE(v time.Time) predicate.Menu

ArchivedAtGTE applies the GTE predicate on the "archived_at" field.

func ArchivedAtIn

func ArchivedAtIn(vs ...time.Time) predicate.Menu

ArchivedAtIn applies the In predicate on the "archived_at" field.

func ArchivedAtIsNil

func ArchivedAtIsNil() predicate.Menu

ArchivedAtIsNil applies the IsNil predicate on the "archived_at" field.

func ArchivedAtLT

func ArchivedAtLT(v time.Time) predicate.Menu

ArchivedAtLT applies the LT predicate on the "archived_at" field.

func ArchivedAtLTE

func ArchivedAtLTE(v time.Time) predicate.Menu

ArchivedAtLTE applies the LTE predicate on the "archived_at" field.

func ArchivedAtNEQ

func ArchivedAtNEQ(v time.Time) predicate.Menu

ArchivedAtNEQ applies the NEQ predicate on the "archived_at" field.

func ArchivedAtNotIn

func ArchivedAtNotIn(vs ...time.Time) predicate.Menu

ArchivedAtNotIn applies the NotIn predicate on the "archived_at" field.

func ArchivedAtNotNil

func ArchivedAtNotNil() predicate.Menu

ArchivedAtNotNil applies the NotNil predicate on the "archived_at" field.

func Component

func Component(v string) predicate.Menu

Component applies equality check predicate on the "component" field. It's identical to ComponentEQ.

func ComponentContains

func ComponentContains(v string) predicate.Menu

ComponentContains applies the Contains predicate on the "component" field.

func ComponentContainsFold

func ComponentContainsFold(v string) predicate.Menu

ComponentContainsFold applies the ContainsFold predicate on the "component" field.

func ComponentEQ

func ComponentEQ(v string) predicate.Menu

ComponentEQ applies the EQ predicate on the "component" field.

func ComponentEqualFold

func ComponentEqualFold(v string) predicate.Menu

ComponentEqualFold applies the EqualFold predicate on the "component" field.

func ComponentGT

func ComponentGT(v string) predicate.Menu

ComponentGT applies the GT predicate on the "component" field.

func ComponentGTE

func ComponentGTE(v string) predicate.Menu

ComponentGTE applies the GTE predicate on the "component" field.

func ComponentHasPrefix

func ComponentHasPrefix(v string) predicate.Menu

ComponentHasPrefix applies the HasPrefix predicate on the "component" field.

func ComponentHasSuffix

func ComponentHasSuffix(v string) predicate.Menu

ComponentHasSuffix applies the HasSuffix predicate on the "component" field.

func ComponentIn

func ComponentIn(vs ...string) predicate.Menu

ComponentIn applies the In predicate on the "component" field.

func ComponentIsNil

func ComponentIsNil() predicate.Menu

ComponentIsNil applies the IsNil predicate on the "component" field.

func ComponentLT

func ComponentLT(v string) predicate.Menu

ComponentLT applies the LT predicate on the "component" field.

func ComponentLTE

func ComponentLTE(v string) predicate.Menu

ComponentLTE applies the LTE predicate on the "component" field.

func ComponentNEQ

func ComponentNEQ(v string) predicate.Menu

ComponentNEQ applies the NEQ predicate on the "component" field.

func ComponentNotIn

func ComponentNotIn(vs ...string) predicate.Menu

ComponentNotIn applies the NotIn predicate on the "component" field.

func ComponentNotNil

func ComponentNotNil() predicate.Menu

ComponentNotNil applies the NotNil predicate on the "component" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Menu

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Menu

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Menu

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Menu

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Menu

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.Menu

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Menu

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Menu

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Menu

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Menu

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.Menu

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedByID

func CreatedByID(v uuid.UUID) predicate.Menu

CreatedByID applies equality check predicate on the "created_by_id" field. It's identical to CreatedByIDEQ.

func CreatedByIDEQ

func CreatedByIDEQ(v uuid.UUID) predicate.Menu

CreatedByIDEQ applies the EQ predicate on the "created_by_id" field.

func CreatedByIDGT

func CreatedByIDGT(v uuid.UUID) predicate.Menu

CreatedByIDGT applies the GT predicate on the "created_by_id" field.

func CreatedByIDGTE

func CreatedByIDGTE(v uuid.UUID) predicate.Menu

CreatedByIDGTE applies the GTE predicate on the "created_by_id" field.

func CreatedByIDIn

func CreatedByIDIn(vs ...uuid.UUID) predicate.Menu

CreatedByIDIn applies the In predicate on the "created_by_id" field.

func CreatedByIDIsNil

func CreatedByIDIsNil() predicate.Menu

CreatedByIDIsNil applies the IsNil predicate on the "created_by_id" field.

func CreatedByIDLT

func CreatedByIDLT(v uuid.UUID) predicate.Menu

CreatedByIDLT applies the LT predicate on the "created_by_id" field.

func CreatedByIDLTE

func CreatedByIDLTE(v uuid.UUID) predicate.Menu

CreatedByIDLTE applies the LTE predicate on the "created_by_id" field.

func CreatedByIDNEQ

func CreatedByIDNEQ(v uuid.UUID) predicate.Menu

CreatedByIDNEQ applies the NEQ predicate on the "created_by_id" field.

func CreatedByIDNotIn

func CreatedByIDNotIn(vs ...uuid.UUID) predicate.Menu

CreatedByIDNotIn applies the NotIn predicate on the "created_by_id" field.

func CreatedByIDNotNil

func CreatedByIDNotNil() predicate.Menu

CreatedByIDNotNil applies the NotNil predicate on the "created_by_id" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.Menu

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.Menu

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.Menu

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.Menu

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.Menu

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.Menu

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.Menu

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.Menu

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.Menu

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.Menu

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.Menu

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedByID

func DeletedByID(v uuid.UUID) predicate.Menu

DeletedByID applies equality check predicate on the "deleted_by_id" field. It's identical to DeletedByIDEQ.

func DeletedByIDEQ

func DeletedByIDEQ(v uuid.UUID) predicate.Menu

DeletedByIDEQ applies the EQ predicate on the "deleted_by_id" field.

func DeletedByIDGT

func DeletedByIDGT(v uuid.UUID) predicate.Menu

DeletedByIDGT applies the GT predicate on the "deleted_by_id" field.

func DeletedByIDGTE

func DeletedByIDGTE(v uuid.UUID) predicate.Menu

DeletedByIDGTE applies the GTE predicate on the "deleted_by_id" field.

func DeletedByIDIn

func DeletedByIDIn(vs ...uuid.UUID) predicate.Menu

DeletedByIDIn applies the In predicate on the "deleted_by_id" field.

func DeletedByIDIsNil

func DeletedByIDIsNil() predicate.Menu

DeletedByIDIsNil applies the IsNil predicate on the "deleted_by_id" field.

func DeletedByIDLT

func DeletedByIDLT(v uuid.UUID) predicate.Menu

DeletedByIDLT applies the LT predicate on the "deleted_by_id" field.

func DeletedByIDLTE

func DeletedByIDLTE(v uuid.UUID) predicate.Menu

DeletedByIDLTE applies the LTE predicate on the "deleted_by_id" field.

func DeletedByIDNEQ

func DeletedByIDNEQ(v uuid.UUID) predicate.Menu

DeletedByIDNEQ applies the NEQ predicate on the "deleted_by_id" field.

func DeletedByIDNotIn

func DeletedByIDNotIn(vs ...uuid.UUID) predicate.Menu

DeletedByIDNotIn applies the NotIn predicate on the "deleted_by_id" field.

func DeletedByIDNotNil

func DeletedByIDNotNil() predicate.Menu

DeletedByIDNotNil applies the NotNil predicate on the "deleted_by_id" field.

func HasChildren

func HasChildren() predicate.Menu

HasChildren applies the HasEdge predicate on the "children" edge.

func HasChildrenWith

func HasChildrenWith(preds ...predicate.Menu) predicate.Menu

HasChildrenWith applies the HasEdge predicate on the "children" edge with a given conditions (other predicates).

func HasParent

func HasParent() predicate.Menu

HasParent applies the HasEdge predicate on the "parent" edge.

func HasParentWith

func HasParentWith(preds ...predicate.Menu) predicate.Menu

HasParentWith applies the HasEdge predicate on the "parent" edge with a given conditions (other predicates).

func HasRoles

func HasRoles() predicate.Menu

HasRoles applies the HasEdge predicate on the "roles" edge.

func HasRolesWith

func HasRolesWith(preds ...predicate.Role) predicate.Menu

HasRolesWith applies the HasEdge predicate on the "roles" edge with a given conditions (other predicates).

func Hidden

func Hidden(v bool) predicate.Menu

Hidden applies equality check predicate on the "hidden" field. It's identical to HiddenEQ.

func HiddenEQ

func HiddenEQ(v bool) predicate.Menu

HiddenEQ applies the EQ predicate on the "hidden" field.

func HiddenNEQ

func HiddenNEQ(v bool) predicate.Menu

HiddenNEQ applies the NEQ predicate on the "hidden" field.

func ID

func ID(id uuid.UUID) predicate.Menu

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Menu

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Menu

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Menu

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Menu

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Menu

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Menu

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Menu

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Menu

IDNotIn applies the NotIn predicate on the ID field.

func Icon

func Icon(v string) predicate.Menu

Icon applies equality check predicate on the "icon" field. It's identical to IconEQ.

func IconContains

func IconContains(v string) predicate.Menu

IconContains applies the Contains predicate on the "icon" field.

func IconContainsFold

func IconContainsFold(v string) predicate.Menu

IconContainsFold applies the ContainsFold predicate on the "icon" field.

func IconEQ

func IconEQ(v string) predicate.Menu

IconEQ applies the EQ predicate on the "icon" field.

func IconEqualFold

func IconEqualFold(v string) predicate.Menu

IconEqualFold applies the EqualFold predicate on the "icon" field.

func IconGT

func IconGT(v string) predicate.Menu

IconGT applies the GT predicate on the "icon" field.

func IconGTE

func IconGTE(v string) predicate.Menu

IconGTE applies the GTE predicate on the "icon" field.

func IconHasPrefix

func IconHasPrefix(v string) predicate.Menu

IconHasPrefix applies the HasPrefix predicate on the "icon" field.

func IconHasSuffix

func IconHasSuffix(v string) predicate.Menu

IconHasSuffix applies the HasSuffix predicate on the "icon" field.

func IconIn

func IconIn(vs ...string) predicate.Menu

IconIn applies the In predicate on the "icon" field.

func IconIsNil

func IconIsNil() predicate.Menu

IconIsNil applies the IsNil predicate on the "icon" field.

func IconLT

func IconLT(v string) predicate.Menu

IconLT applies the LT predicate on the "icon" field.

func IconLTE

func IconLTE(v string) predicate.Menu

IconLTE applies the LTE predicate on the "icon" field.

func IconNEQ

func IconNEQ(v string) predicate.Menu

IconNEQ applies the NEQ predicate on the "icon" field.

func IconNotIn

func IconNotIn(vs ...string) predicate.Menu

IconNotIn applies the NotIn predicate on the "icon" field.

func IconNotNil

func IconNotNil() predicate.Menu

IconNotNil applies the NotNil predicate on the "icon" field.

func MetaIsNil

func MetaIsNil() predicate.Menu

MetaIsNil applies the IsNil predicate on the "meta" field.

func MetaNotNil

func MetaNotNil() predicate.Menu

MetaNotNil applies the NotNil predicate on the "meta" field.

func Name

func Name(v string) predicate.Menu

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Menu

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Menu

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Menu

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Menu

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Menu

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Menu

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Menu

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Menu

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Menu

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Menu

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Menu

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Menu

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Menu

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Menu) predicate.Menu

Or groups predicates with the OR operator between them.

func OwnerDomainID

func OwnerDomainID(v uuid.UUID) predicate.Menu

OwnerDomainID applies equality check predicate on the "owner_domain_id" field. It's identical to OwnerDomainIDEQ.

func OwnerDomainIDEQ

func OwnerDomainIDEQ(v uuid.UUID) predicate.Menu

OwnerDomainIDEQ applies the EQ predicate on the "owner_domain_id" field.

func OwnerDomainIDGT

func OwnerDomainIDGT(v uuid.UUID) predicate.Menu

OwnerDomainIDGT applies the GT predicate on the "owner_domain_id" field.

func OwnerDomainIDGTE

func OwnerDomainIDGTE(v uuid.UUID) predicate.Menu

OwnerDomainIDGTE applies the GTE predicate on the "owner_domain_id" field.

func OwnerDomainIDIn

func OwnerDomainIDIn(vs ...uuid.UUID) predicate.Menu

OwnerDomainIDIn applies the In predicate on the "owner_domain_id" field.

func OwnerDomainIDIsNil

func OwnerDomainIDIsNil() predicate.Menu

OwnerDomainIDIsNil applies the IsNil predicate on the "owner_domain_id" field.

func OwnerDomainIDLT

func OwnerDomainIDLT(v uuid.UUID) predicate.Menu

OwnerDomainIDLT applies the LT predicate on the "owner_domain_id" field.

func OwnerDomainIDLTE

func OwnerDomainIDLTE(v uuid.UUID) predicate.Menu

OwnerDomainIDLTE applies the LTE predicate on the "owner_domain_id" field.

func OwnerDomainIDNEQ

func OwnerDomainIDNEQ(v uuid.UUID) predicate.Menu

OwnerDomainIDNEQ applies the NEQ predicate on the "owner_domain_id" field.

func OwnerDomainIDNotIn

func OwnerDomainIDNotIn(vs ...uuid.UUID) predicate.Menu

OwnerDomainIDNotIn applies the NotIn predicate on the "owner_domain_id" field.

func OwnerDomainIDNotNil

func OwnerDomainIDNotNil() predicate.Menu

OwnerDomainIDNotNil applies the NotNil predicate on the "owner_domain_id" field.

func ParamsIsNil

func ParamsIsNil() predicate.Menu

ParamsIsNil applies the IsNil predicate on the "params" field.

func ParamsNotNil

func ParamsNotNil() predicate.Menu

ParamsNotNil applies the NotNil predicate on the "params" field.

func ParentID

func ParentID(v uuid.UUID) predicate.Menu

ParentID applies equality check predicate on the "parent_id" field. It's identical to ParentIDEQ.

func ParentIDEQ

func ParentIDEQ(v uuid.UUID) predicate.Menu

ParentIDEQ applies the EQ predicate on the "parent_id" field.

func ParentIDIn

func ParentIDIn(vs ...uuid.UUID) predicate.Menu

ParentIDIn applies the In predicate on the "parent_id" field.

func ParentIDIsNil

func ParentIDIsNil() predicate.Menu

ParentIDIsNil applies the IsNil predicate on the "parent_id" field.

func ParentIDNEQ

func ParentIDNEQ(v uuid.UUID) predicate.Menu

ParentIDNEQ applies the NEQ predicate on the "parent_id" field.

func ParentIDNotIn

func ParentIDNotIn(vs ...uuid.UUID) predicate.Menu

ParentIDNotIn applies the NotIn predicate on the "parent_id" field.

func ParentIDNotNil

func ParentIDNotNil() predicate.Menu

ParentIDNotNil applies the NotNil predicate on the "parent_id" field.

func Path

func Path(v string) predicate.Menu

Path applies equality check predicate on the "path" field. It's identical to PathEQ.

func PathContains

func PathContains(v string) predicate.Menu

PathContains applies the Contains predicate on the "path" field.

func PathContainsFold

func PathContainsFold(v string) predicate.Menu

PathContainsFold applies the ContainsFold predicate on the "path" field.

func PathEQ

func PathEQ(v string) predicate.Menu

PathEQ applies the EQ predicate on the "path" field.

func PathEqualFold

func PathEqualFold(v string) predicate.Menu

PathEqualFold applies the EqualFold predicate on the "path" field.

func PathGT

func PathGT(v string) predicate.Menu

PathGT applies the GT predicate on the "path" field.

func PathGTE

func PathGTE(v string) predicate.Menu

PathGTE applies the GTE predicate on the "path" field.

func PathHasPrefix

func PathHasPrefix(v string) predicate.Menu

PathHasPrefix applies the HasPrefix predicate on the "path" field.

func PathHasSuffix

func PathHasSuffix(v string) predicate.Menu

PathHasSuffix applies the HasSuffix predicate on the "path" field.

func PathIn

func PathIn(vs ...string) predicate.Menu

PathIn applies the In predicate on the "path" field.

func PathLT

func PathLT(v string) predicate.Menu

PathLT applies the LT predicate on the "path" field.

func PathLTE

func PathLTE(v string) predicate.Menu

PathLTE applies the LTE predicate on the "path" field.

func PathNEQ

func PathNEQ(v string) predicate.Menu

PathNEQ applies the NEQ predicate on the "path" field.

func PathNotIn

func PathNotIn(vs ...string) predicate.Menu

PathNotIn applies the NotIn predicate on the "path" field.

func PublishedAt

func PublishedAt(v time.Time) predicate.Menu

PublishedAt applies equality check predicate on the "published_at" field. It's identical to PublishedAtEQ.

func PublishedAtEQ

func PublishedAtEQ(v time.Time) predicate.Menu

PublishedAtEQ applies the EQ predicate on the "published_at" field.

func PublishedAtGT

func PublishedAtGT(v time.Time) predicate.Menu

PublishedAtGT applies the GT predicate on the "published_at" field.

func PublishedAtGTE

func PublishedAtGTE(v time.Time) predicate.Menu

PublishedAtGTE applies the GTE predicate on the "published_at" field.

func PublishedAtIn

func PublishedAtIn(vs ...time.Time) predicate.Menu

PublishedAtIn applies the In predicate on the "published_at" field.

func PublishedAtIsNil

func PublishedAtIsNil() predicate.Menu

PublishedAtIsNil applies the IsNil predicate on the "published_at" field.

func PublishedAtLT

func PublishedAtLT(v time.Time) predicate.Menu

PublishedAtLT applies the LT predicate on the "published_at" field.

func PublishedAtLTE

func PublishedAtLTE(v time.Time) predicate.Menu

PublishedAtLTE applies the LTE predicate on the "published_at" field.

func PublishedAtNEQ

func PublishedAtNEQ(v time.Time) predicate.Menu

PublishedAtNEQ applies the NEQ predicate on the "published_at" field.

func PublishedAtNotIn

func PublishedAtNotIn(vs ...time.Time) predicate.Menu

PublishedAtNotIn applies the NotIn predicate on the "published_at" field.

func PublishedAtNotNil

func PublishedAtNotNil() predicate.Menu

PublishedAtNotNil applies the NotNil predicate on the "published_at" field.

func Redirect

func Redirect(v string) predicate.Menu

Redirect applies equality check predicate on the "redirect" field. It's identical to RedirectEQ.

func RedirectContains

func RedirectContains(v string) predicate.Menu

RedirectContains applies the Contains predicate on the "redirect" field.

func RedirectContainsFold

func RedirectContainsFold(v string) predicate.Menu

RedirectContainsFold applies the ContainsFold predicate on the "redirect" field.

func RedirectEQ

func RedirectEQ(v string) predicate.Menu

RedirectEQ applies the EQ predicate on the "redirect" field.

func RedirectEqualFold

func RedirectEqualFold(v string) predicate.Menu

RedirectEqualFold applies the EqualFold predicate on the "redirect" field.

func RedirectGT

func RedirectGT(v string) predicate.Menu

RedirectGT applies the GT predicate on the "redirect" field.

func RedirectGTE

func RedirectGTE(v string) predicate.Menu

RedirectGTE applies the GTE predicate on the "redirect" field.

func RedirectHasPrefix

func RedirectHasPrefix(v string) predicate.Menu

RedirectHasPrefix applies the HasPrefix predicate on the "redirect" field.

func RedirectHasSuffix

func RedirectHasSuffix(v string) predicate.Menu

RedirectHasSuffix applies the HasSuffix predicate on the "redirect" field.

func RedirectIn

func RedirectIn(vs ...string) predicate.Menu

RedirectIn applies the In predicate on the "redirect" field.

func RedirectIsNil

func RedirectIsNil() predicate.Menu

RedirectIsNil applies the IsNil predicate on the "redirect" field.

func RedirectLT

func RedirectLT(v string) predicate.Menu

RedirectLT applies the LT predicate on the "redirect" field.

func RedirectLTE

func RedirectLTE(v string) predicate.Menu

RedirectLTE applies the LTE predicate on the "redirect" field.

func RedirectNEQ

func RedirectNEQ(v string) predicate.Menu

RedirectNEQ applies the NEQ predicate on the "redirect" field.

func RedirectNotIn

func RedirectNotIn(vs ...string) predicate.Menu

RedirectNotIn applies the NotIn predicate on the "redirect" field.

func RedirectNotNil

func RedirectNotNil() predicate.Menu

RedirectNotNil applies the NotNil predicate on the "redirect" field.

func Sort

func Sort(v int) predicate.Menu

Sort applies equality check predicate on the "sort" field. It's identical to SortEQ.

func SortEQ

func SortEQ(v int) predicate.Menu

SortEQ applies the EQ predicate on the "sort" field.

func SortGT

func SortGT(v int) predicate.Menu

SortGT applies the GT predicate on the "sort" field.

func SortGTE

func SortGTE(v int) predicate.Menu

SortGTE applies the GTE predicate on the "sort" field.

func SortIn

func SortIn(vs ...int) predicate.Menu

SortIn applies the In predicate on the "sort" field.

func SortLT

func SortLT(v int) predicate.Menu

SortLT applies the LT predicate on the "sort" field.

func SortLTE

func SortLTE(v int) predicate.Menu

SortLTE applies the LTE predicate on the "sort" field.

func SortNEQ

func SortNEQ(v int) predicate.Menu

SortNEQ applies the NEQ predicate on the "sort" field.

func SortNotIn

func SortNotIn(vs ...int) predicate.Menu

SortNotIn applies the NotIn predicate on the "sort" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Menu

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Menu

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Menu

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Menu

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Menu

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.Menu

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Menu

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Menu

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Menu

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Menu

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.Menu

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedByID

func UpdatedByID(v uuid.UUID) predicate.Menu

UpdatedByID applies equality check predicate on the "updated_by_id" field. It's identical to UpdatedByIDEQ.

func UpdatedByIDEQ

func UpdatedByIDEQ(v uuid.UUID) predicate.Menu

UpdatedByIDEQ applies the EQ predicate on the "updated_by_id" field.

func UpdatedByIDGT

func UpdatedByIDGT(v uuid.UUID) predicate.Menu

UpdatedByIDGT applies the GT predicate on the "updated_by_id" field.

func UpdatedByIDGTE

func UpdatedByIDGTE(v uuid.UUID) predicate.Menu

UpdatedByIDGTE applies the GTE predicate on the "updated_by_id" field.

func UpdatedByIDIn

func UpdatedByIDIn(vs ...uuid.UUID) predicate.Menu

UpdatedByIDIn applies the In predicate on the "updated_by_id" field.

func UpdatedByIDIsNil

func UpdatedByIDIsNil() predicate.Menu

UpdatedByIDIsNil applies the IsNil predicate on the "updated_by_id" field.

func UpdatedByIDLT

func UpdatedByIDLT(v uuid.UUID) predicate.Menu

UpdatedByIDLT applies the LT predicate on the "updated_by_id" field.

func UpdatedByIDLTE

func UpdatedByIDLTE(v uuid.UUID) predicate.Menu

UpdatedByIDLTE applies the LTE predicate on the "updated_by_id" field.

func UpdatedByIDNEQ

func UpdatedByIDNEQ(v uuid.UUID) predicate.Menu

UpdatedByIDNEQ applies the NEQ predicate on the "updated_by_id" field.

func UpdatedByIDNotIn

func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.Menu

UpdatedByIDNotIn applies the NotIn predicate on the "updated_by_id" field.

func UpdatedByIDNotNil

func UpdatedByIDNotNil() predicate.Menu

UpdatedByIDNotNil applies the NotNil predicate on the "updated_by_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Menu queries.

func ByAffix

func ByAffix(opts ...sql.OrderTermOption) OrderOption

ByAffix orders the results by the affix field.

func ByArchivedAt

func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption

ByArchivedAt orders the results by the archived_at field.

func ByChildren

func ByChildren(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByChildren orders the results by children terms.

func ByChildrenCount

func ByChildrenCount(opts ...sql.OrderTermOption) OrderOption

ByChildrenCount orders the results by children count.

func ByComponent

func ByComponent(opts ...sql.OrderTermOption) OrderOption

ByComponent orders the results by the component field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedByID

func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption

ByCreatedByID orders the results by the created_by_id field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedByID

func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption

ByDeletedByID orders the results by the deleted_by_id field.

func ByHidden

func ByHidden(opts ...sql.OrderTermOption) OrderOption

ByHidden orders the results by the hidden field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIcon

func ByIcon(opts ...sql.OrderTermOption) OrderOption

ByIcon orders the results by the icon field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByOwnerDomainID

func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption

ByOwnerDomainID orders the results by the owner_domain_id field.

func ByParentField

func ByParentField(field string, opts ...sql.OrderTermOption) OrderOption

ByParentField orders the results by parent field.

func ByParentID

func ByParentID(opts ...sql.OrderTermOption) OrderOption

ByParentID orders the results by the parent_id field.

func ByPath

func ByPath(opts ...sql.OrderTermOption) OrderOption

ByPath orders the results by the path field.

func ByPublishedAt

func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption

ByPublishedAt orders the results by the published_at field.

func ByRedirect

func ByRedirect(opts ...sql.OrderTermOption) OrderOption

ByRedirect orders the results by the redirect field.

func ByRoles

func ByRoles(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByRoles orders the results by roles terms.

func ByRolesCount

func ByRolesCount(opts ...sql.OrderTermOption) OrderOption

ByRolesCount orders the results by roles count.

func BySort

func BySort(opts ...sql.OrderTermOption) OrderOption

BySort orders the results by the sort field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedByID

func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption

ByUpdatedByID orders the results by the updated_by_id field.

Jump to