operationlog

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 28, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the operationlog type in the database.
	Label = "operation_log"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedByID holds the string denoting the created_by_id field in the database.
	FieldCreatedByID = "created_by_id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedByID holds the string denoting the updated_by_id field in the database.
	FieldUpdatedByID = "updated_by_id"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldDeletedByID holds the string denoting the deleted_by_id field in the database.
	FieldDeletedByID = "deleted_by_id"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldPublishedAt holds the string denoting the published_at field in the database.
	FieldPublishedAt = "published_at"
	// FieldArchivedAt holds the string denoting the archived_at field in the database.
	FieldArchivedAt = "archived_at"
	// FieldOwnerDomainID holds the string denoting the owner_domain_id field in the database.
	FieldOwnerDomainID = "owner_domain_id"
	// FieldRequestID holds the string denoting the request_id field in the database.
	FieldRequestID = "request_id"
	// FieldMethod holds the string denoting the method field in the database.
	FieldMethod = "method"
	// FieldPath holds the string denoting the path field in the database.
	FieldPath = "path"
	// FieldQueryParams holds the string denoting the query_params field in the database.
	FieldQueryParams = "query_params"
	// FieldBody holds the string denoting the body field in the database.
	FieldBody = "body"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldLatency holds the string denoting the latency field in the database.
	FieldLatency = "latency"
	// FieldClientIP holds the string denoting the client_ip field in the database.
	FieldClientIP = "client_ip"
	// FieldUserAgent holds the string denoting the user_agent field in the database.
	FieldUserAgent = "user_agent"
	// FieldErrorMessage holds the string denoting the error_message field in the database.
	FieldErrorMessage = "error_message"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// Table holds the table name of the operationlog in the database.
	Table = "operation_logs"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "operation_logs"
	// UserInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	UserInverseTable = "users"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "user_id"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// MethodValidator is a validator for the "method" field. It is called by the builders before save.
	MethodValidator func(string) error
	// PathValidator is a validator for the "path" field. It is called by the builders before save.
	PathValidator func(string) error
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for operationlog fields.

Functions

func And

func And(predicates ...predicate.OperationLog) predicate.OperationLog

And groups predicates with the AND operator between them.

func ArchivedAt

func ArchivedAt(v time.Time) predicate.OperationLog

ArchivedAt applies equality check predicate on the "archived_at" field. It's identical to ArchivedAtEQ.

func ArchivedAtEQ

func ArchivedAtEQ(v time.Time) predicate.OperationLog

ArchivedAtEQ applies the EQ predicate on the "archived_at" field.

func ArchivedAtGT

func ArchivedAtGT(v time.Time) predicate.OperationLog

ArchivedAtGT applies the GT predicate on the "archived_at" field.

func ArchivedAtGTE

func ArchivedAtGTE(v time.Time) predicate.OperationLog

ArchivedAtGTE applies the GTE predicate on the "archived_at" field.

func ArchivedAtIn

func ArchivedAtIn(vs ...time.Time) predicate.OperationLog

ArchivedAtIn applies the In predicate on the "archived_at" field.

func ArchivedAtIsNil

func ArchivedAtIsNil() predicate.OperationLog

ArchivedAtIsNil applies the IsNil predicate on the "archived_at" field.

func ArchivedAtLT

func ArchivedAtLT(v time.Time) predicate.OperationLog

ArchivedAtLT applies the LT predicate on the "archived_at" field.

func ArchivedAtLTE

func ArchivedAtLTE(v time.Time) predicate.OperationLog

ArchivedAtLTE applies the LTE predicate on the "archived_at" field.

func ArchivedAtNEQ

func ArchivedAtNEQ(v time.Time) predicate.OperationLog

ArchivedAtNEQ applies the NEQ predicate on the "archived_at" field.

func ArchivedAtNotIn

func ArchivedAtNotIn(vs ...time.Time) predicate.OperationLog

ArchivedAtNotIn applies the NotIn predicate on the "archived_at" field.

func ArchivedAtNotNil

func ArchivedAtNotNil() predicate.OperationLog

ArchivedAtNotNil applies the NotNil predicate on the "archived_at" field.

func Body

Body applies equality check predicate on the "body" field. It's identical to BodyEQ.

func BodyContains

func BodyContains(v string) predicate.OperationLog

BodyContains applies the Contains predicate on the "body" field.

func BodyContainsFold

func BodyContainsFold(v string) predicate.OperationLog

BodyContainsFold applies the ContainsFold predicate on the "body" field.

func BodyEQ

func BodyEQ(v string) predicate.OperationLog

BodyEQ applies the EQ predicate on the "body" field.

func BodyEqualFold

func BodyEqualFold(v string) predicate.OperationLog

BodyEqualFold applies the EqualFold predicate on the "body" field.

func BodyGT

func BodyGT(v string) predicate.OperationLog

BodyGT applies the GT predicate on the "body" field.

func BodyGTE

func BodyGTE(v string) predicate.OperationLog

BodyGTE applies the GTE predicate on the "body" field.

func BodyHasPrefix

func BodyHasPrefix(v string) predicate.OperationLog

BodyHasPrefix applies the HasPrefix predicate on the "body" field.

func BodyHasSuffix

func BodyHasSuffix(v string) predicate.OperationLog

BodyHasSuffix applies the HasSuffix predicate on the "body" field.

func BodyIn

func BodyIn(vs ...string) predicate.OperationLog

BodyIn applies the In predicate on the "body" field.

func BodyIsNil

func BodyIsNil() predicate.OperationLog

BodyIsNil applies the IsNil predicate on the "body" field.

func BodyLT

func BodyLT(v string) predicate.OperationLog

BodyLT applies the LT predicate on the "body" field.

func BodyLTE

func BodyLTE(v string) predicate.OperationLog

BodyLTE applies the LTE predicate on the "body" field.

func BodyNEQ

func BodyNEQ(v string) predicate.OperationLog

BodyNEQ applies the NEQ predicate on the "body" field.

func BodyNotIn

func BodyNotIn(vs ...string) predicate.OperationLog

BodyNotIn applies the NotIn predicate on the "body" field.

func BodyNotNil

func BodyNotNil() predicate.OperationLog

BodyNotNil applies the NotNil predicate on the "body" field.

func ClientIP

func ClientIP(v string) predicate.OperationLog

ClientIP applies equality check predicate on the "client_ip" field. It's identical to ClientIPEQ.

func ClientIPContains

func ClientIPContains(v string) predicate.OperationLog

ClientIPContains applies the Contains predicate on the "client_ip" field.

func ClientIPContainsFold

func ClientIPContainsFold(v string) predicate.OperationLog

ClientIPContainsFold applies the ContainsFold predicate on the "client_ip" field.

func ClientIPEQ

func ClientIPEQ(v string) predicate.OperationLog

ClientIPEQ applies the EQ predicate on the "client_ip" field.

func ClientIPEqualFold

func ClientIPEqualFold(v string) predicate.OperationLog

ClientIPEqualFold applies the EqualFold predicate on the "client_ip" field.

func ClientIPGT

func ClientIPGT(v string) predicate.OperationLog

ClientIPGT applies the GT predicate on the "client_ip" field.

func ClientIPGTE

func ClientIPGTE(v string) predicate.OperationLog

ClientIPGTE applies the GTE predicate on the "client_ip" field.

func ClientIPHasPrefix

func ClientIPHasPrefix(v string) predicate.OperationLog

ClientIPHasPrefix applies the HasPrefix predicate on the "client_ip" field.

func ClientIPHasSuffix

func ClientIPHasSuffix(v string) predicate.OperationLog

ClientIPHasSuffix applies the HasSuffix predicate on the "client_ip" field.

func ClientIPIn

func ClientIPIn(vs ...string) predicate.OperationLog

ClientIPIn applies the In predicate on the "client_ip" field.

func ClientIPLT

func ClientIPLT(v string) predicate.OperationLog

ClientIPLT applies the LT predicate on the "client_ip" field.

func ClientIPLTE

func ClientIPLTE(v string) predicate.OperationLog

ClientIPLTE applies the LTE predicate on the "client_ip" field.

func ClientIPNEQ

func ClientIPNEQ(v string) predicate.OperationLog

ClientIPNEQ applies the NEQ predicate on the "client_ip" field.

func ClientIPNotIn

func ClientIPNotIn(vs ...string) predicate.OperationLog

ClientIPNotIn applies the NotIn predicate on the "client_ip" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.OperationLog

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.OperationLog

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.OperationLog

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.OperationLog

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.OperationLog

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.OperationLog

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.OperationLog

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.OperationLog

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.OperationLog

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.OperationLog

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.OperationLog

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedByID

func CreatedByID(v uuid.UUID) predicate.OperationLog

CreatedByID applies equality check predicate on the "created_by_id" field. It's identical to CreatedByIDEQ.

func CreatedByIDEQ

func CreatedByIDEQ(v uuid.UUID) predicate.OperationLog

CreatedByIDEQ applies the EQ predicate on the "created_by_id" field.

func CreatedByIDGT

func CreatedByIDGT(v uuid.UUID) predicate.OperationLog

CreatedByIDGT applies the GT predicate on the "created_by_id" field.

func CreatedByIDGTE

func CreatedByIDGTE(v uuid.UUID) predicate.OperationLog

CreatedByIDGTE applies the GTE predicate on the "created_by_id" field.

func CreatedByIDIn

func CreatedByIDIn(vs ...uuid.UUID) predicate.OperationLog

CreatedByIDIn applies the In predicate on the "created_by_id" field.

func CreatedByIDIsNil

func CreatedByIDIsNil() predicate.OperationLog

CreatedByIDIsNil applies the IsNil predicate on the "created_by_id" field.

func CreatedByIDLT

func CreatedByIDLT(v uuid.UUID) predicate.OperationLog

CreatedByIDLT applies the LT predicate on the "created_by_id" field.

func CreatedByIDLTE

func CreatedByIDLTE(v uuid.UUID) predicate.OperationLog

CreatedByIDLTE applies the LTE predicate on the "created_by_id" field.

func CreatedByIDNEQ

func CreatedByIDNEQ(v uuid.UUID) predicate.OperationLog

CreatedByIDNEQ applies the NEQ predicate on the "created_by_id" field.

func CreatedByIDNotIn

func CreatedByIDNotIn(vs ...uuid.UUID) predicate.OperationLog

CreatedByIDNotIn applies the NotIn predicate on the "created_by_id" field.

func CreatedByIDNotNil

func CreatedByIDNotNil() predicate.OperationLog

CreatedByIDNotNil applies the NotNil predicate on the "created_by_id" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.OperationLog

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.OperationLog

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.OperationLog

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.OperationLog

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.OperationLog

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.OperationLog

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.OperationLog

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.OperationLog

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.OperationLog

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.OperationLog

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.OperationLog

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedByID

func DeletedByID(v uuid.UUID) predicate.OperationLog

DeletedByID applies equality check predicate on the "deleted_by_id" field. It's identical to DeletedByIDEQ.

func DeletedByIDEQ

func DeletedByIDEQ(v uuid.UUID) predicate.OperationLog

DeletedByIDEQ applies the EQ predicate on the "deleted_by_id" field.

func DeletedByIDGT

func DeletedByIDGT(v uuid.UUID) predicate.OperationLog

DeletedByIDGT applies the GT predicate on the "deleted_by_id" field.

func DeletedByIDGTE

func DeletedByIDGTE(v uuid.UUID) predicate.OperationLog

DeletedByIDGTE applies the GTE predicate on the "deleted_by_id" field.

func DeletedByIDIn

func DeletedByIDIn(vs ...uuid.UUID) predicate.OperationLog

DeletedByIDIn applies the In predicate on the "deleted_by_id" field.

func DeletedByIDIsNil

func DeletedByIDIsNil() predicate.OperationLog

DeletedByIDIsNil applies the IsNil predicate on the "deleted_by_id" field.

func DeletedByIDLT

func DeletedByIDLT(v uuid.UUID) predicate.OperationLog

DeletedByIDLT applies the LT predicate on the "deleted_by_id" field.

func DeletedByIDLTE

func DeletedByIDLTE(v uuid.UUID) predicate.OperationLog

DeletedByIDLTE applies the LTE predicate on the "deleted_by_id" field.

func DeletedByIDNEQ

func DeletedByIDNEQ(v uuid.UUID) predicate.OperationLog

DeletedByIDNEQ applies the NEQ predicate on the "deleted_by_id" field.

func DeletedByIDNotIn

func DeletedByIDNotIn(vs ...uuid.UUID) predicate.OperationLog

DeletedByIDNotIn applies the NotIn predicate on the "deleted_by_id" field.

func DeletedByIDNotNil

func DeletedByIDNotNil() predicate.OperationLog

DeletedByIDNotNil applies the NotNil predicate on the "deleted_by_id" field.

func ErrorMessage

func ErrorMessage(v string) predicate.OperationLog

ErrorMessage applies equality check predicate on the "error_message" field. It's identical to ErrorMessageEQ.

func ErrorMessageContains

func ErrorMessageContains(v string) predicate.OperationLog

ErrorMessageContains applies the Contains predicate on the "error_message" field.

func ErrorMessageContainsFold

func ErrorMessageContainsFold(v string) predicate.OperationLog

ErrorMessageContainsFold applies the ContainsFold predicate on the "error_message" field.

func ErrorMessageEQ

func ErrorMessageEQ(v string) predicate.OperationLog

ErrorMessageEQ applies the EQ predicate on the "error_message" field.

func ErrorMessageEqualFold

func ErrorMessageEqualFold(v string) predicate.OperationLog

ErrorMessageEqualFold applies the EqualFold predicate on the "error_message" field.

func ErrorMessageGT

func ErrorMessageGT(v string) predicate.OperationLog

ErrorMessageGT applies the GT predicate on the "error_message" field.

func ErrorMessageGTE

func ErrorMessageGTE(v string) predicate.OperationLog

ErrorMessageGTE applies the GTE predicate on the "error_message" field.

func ErrorMessageHasPrefix

func ErrorMessageHasPrefix(v string) predicate.OperationLog

ErrorMessageHasPrefix applies the HasPrefix predicate on the "error_message" field.

func ErrorMessageHasSuffix

func ErrorMessageHasSuffix(v string) predicate.OperationLog

ErrorMessageHasSuffix applies the HasSuffix predicate on the "error_message" field.

func ErrorMessageIn

func ErrorMessageIn(vs ...string) predicate.OperationLog

ErrorMessageIn applies the In predicate on the "error_message" field.

func ErrorMessageIsNil

func ErrorMessageIsNil() predicate.OperationLog

ErrorMessageIsNil applies the IsNil predicate on the "error_message" field.

func ErrorMessageLT

func ErrorMessageLT(v string) predicate.OperationLog

ErrorMessageLT applies the LT predicate on the "error_message" field.

func ErrorMessageLTE

func ErrorMessageLTE(v string) predicate.OperationLog

ErrorMessageLTE applies the LTE predicate on the "error_message" field.

func ErrorMessageNEQ

func ErrorMessageNEQ(v string) predicate.OperationLog

ErrorMessageNEQ applies the NEQ predicate on the "error_message" field.

func ErrorMessageNotIn

func ErrorMessageNotIn(vs ...string) predicate.OperationLog

ErrorMessageNotIn applies the NotIn predicate on the "error_message" field.

func ErrorMessageNotNil

func ErrorMessageNotNil() predicate.OperationLog

ErrorMessageNotNil applies the NotNil predicate on the "error_message" field.

func HasUser

func HasUser() predicate.OperationLog

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.User) predicate.OperationLog

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.OperationLog

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.OperationLog

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.OperationLog

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.OperationLog

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.OperationLog

IDNotIn applies the NotIn predicate on the ID field.

func Latency

func Latency(v int64) predicate.OperationLog

Latency applies equality check predicate on the "latency" field. It's identical to LatencyEQ.

func LatencyEQ

func LatencyEQ(v int64) predicate.OperationLog

LatencyEQ applies the EQ predicate on the "latency" field.

func LatencyGT

func LatencyGT(v int64) predicate.OperationLog

LatencyGT applies the GT predicate on the "latency" field.

func LatencyGTE

func LatencyGTE(v int64) predicate.OperationLog

LatencyGTE applies the GTE predicate on the "latency" field.

func LatencyIn

func LatencyIn(vs ...int64) predicate.OperationLog

LatencyIn applies the In predicate on the "latency" field.

func LatencyLT

func LatencyLT(v int64) predicate.OperationLog

LatencyLT applies the LT predicate on the "latency" field.

func LatencyLTE

func LatencyLTE(v int64) predicate.OperationLog

LatencyLTE applies the LTE predicate on the "latency" field.

func LatencyNEQ

func LatencyNEQ(v int64) predicate.OperationLog

LatencyNEQ applies the NEQ predicate on the "latency" field.

func LatencyNotIn

func LatencyNotIn(vs ...int64) predicate.OperationLog

LatencyNotIn applies the NotIn predicate on the "latency" field.

func Method

func Method(v string) predicate.OperationLog

Method applies equality check predicate on the "method" field. It's identical to MethodEQ.

func MethodContains

func MethodContains(v string) predicate.OperationLog

MethodContains applies the Contains predicate on the "method" field.

func MethodContainsFold

func MethodContainsFold(v string) predicate.OperationLog

MethodContainsFold applies the ContainsFold predicate on the "method" field.

func MethodEQ

func MethodEQ(v string) predicate.OperationLog

MethodEQ applies the EQ predicate on the "method" field.

func MethodEqualFold

func MethodEqualFold(v string) predicate.OperationLog

MethodEqualFold applies the EqualFold predicate on the "method" field.

func MethodGT

func MethodGT(v string) predicate.OperationLog

MethodGT applies the GT predicate on the "method" field.

func MethodGTE

func MethodGTE(v string) predicate.OperationLog

MethodGTE applies the GTE predicate on the "method" field.

func MethodHasPrefix

func MethodHasPrefix(v string) predicate.OperationLog

MethodHasPrefix applies the HasPrefix predicate on the "method" field.

func MethodHasSuffix

func MethodHasSuffix(v string) predicate.OperationLog

MethodHasSuffix applies the HasSuffix predicate on the "method" field.

func MethodIn

func MethodIn(vs ...string) predicate.OperationLog

MethodIn applies the In predicate on the "method" field.

func MethodLT

func MethodLT(v string) predicate.OperationLog

MethodLT applies the LT predicate on the "method" field.

func MethodLTE

func MethodLTE(v string) predicate.OperationLog

MethodLTE applies the LTE predicate on the "method" field.

func MethodNEQ

func MethodNEQ(v string) predicate.OperationLog

MethodNEQ applies the NEQ predicate on the "method" field.

func MethodNotIn

func MethodNotIn(vs ...string) predicate.OperationLog

MethodNotIn applies the NotIn predicate on the "method" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.OperationLog) predicate.OperationLog

Or groups predicates with the OR operator between them.

func OwnerDomainID

func OwnerDomainID(v uuid.UUID) predicate.OperationLog

OwnerDomainID applies equality check predicate on the "owner_domain_id" field. It's identical to OwnerDomainIDEQ.

func OwnerDomainIDEQ

func OwnerDomainIDEQ(v uuid.UUID) predicate.OperationLog

OwnerDomainIDEQ applies the EQ predicate on the "owner_domain_id" field.

func OwnerDomainIDGT

func OwnerDomainIDGT(v uuid.UUID) predicate.OperationLog

OwnerDomainIDGT applies the GT predicate on the "owner_domain_id" field.

func OwnerDomainIDGTE

func OwnerDomainIDGTE(v uuid.UUID) predicate.OperationLog

OwnerDomainIDGTE applies the GTE predicate on the "owner_domain_id" field.

func OwnerDomainIDIn

func OwnerDomainIDIn(vs ...uuid.UUID) predicate.OperationLog

OwnerDomainIDIn applies the In predicate on the "owner_domain_id" field.

func OwnerDomainIDIsNil

func OwnerDomainIDIsNil() predicate.OperationLog

OwnerDomainIDIsNil applies the IsNil predicate on the "owner_domain_id" field.

func OwnerDomainIDLT

func OwnerDomainIDLT(v uuid.UUID) predicate.OperationLog

OwnerDomainIDLT applies the LT predicate on the "owner_domain_id" field.

func OwnerDomainIDLTE

func OwnerDomainIDLTE(v uuid.UUID) predicate.OperationLog

OwnerDomainIDLTE applies the LTE predicate on the "owner_domain_id" field.

func OwnerDomainIDNEQ

func OwnerDomainIDNEQ(v uuid.UUID) predicate.OperationLog

OwnerDomainIDNEQ applies the NEQ predicate on the "owner_domain_id" field.

func OwnerDomainIDNotIn

func OwnerDomainIDNotIn(vs ...uuid.UUID) predicate.OperationLog

OwnerDomainIDNotIn applies the NotIn predicate on the "owner_domain_id" field.

func OwnerDomainIDNotNil

func OwnerDomainIDNotNil() predicate.OperationLog

OwnerDomainIDNotNil applies the NotNil predicate on the "owner_domain_id" field.

func Path

Path applies equality check predicate on the "path" field. It's identical to PathEQ.

func PathContains

func PathContains(v string) predicate.OperationLog

PathContains applies the Contains predicate on the "path" field.

func PathContainsFold

func PathContainsFold(v string) predicate.OperationLog

PathContainsFold applies the ContainsFold predicate on the "path" field.

func PathEQ

func PathEQ(v string) predicate.OperationLog

PathEQ applies the EQ predicate on the "path" field.

func PathEqualFold

func PathEqualFold(v string) predicate.OperationLog

PathEqualFold applies the EqualFold predicate on the "path" field.

func PathGT

func PathGT(v string) predicate.OperationLog

PathGT applies the GT predicate on the "path" field.

func PathGTE

func PathGTE(v string) predicate.OperationLog

PathGTE applies the GTE predicate on the "path" field.

func PathHasPrefix

func PathHasPrefix(v string) predicate.OperationLog

PathHasPrefix applies the HasPrefix predicate on the "path" field.

func PathHasSuffix

func PathHasSuffix(v string) predicate.OperationLog

PathHasSuffix applies the HasSuffix predicate on the "path" field.

func PathIn

func PathIn(vs ...string) predicate.OperationLog

PathIn applies the In predicate on the "path" field.

func PathLT

func PathLT(v string) predicate.OperationLog

PathLT applies the LT predicate on the "path" field.

func PathLTE

func PathLTE(v string) predicate.OperationLog

PathLTE applies the LTE predicate on the "path" field.

func PathNEQ

func PathNEQ(v string) predicate.OperationLog

PathNEQ applies the NEQ predicate on the "path" field.

func PathNotIn

func PathNotIn(vs ...string) predicate.OperationLog

PathNotIn applies the NotIn predicate on the "path" field.

func PublishedAt

func PublishedAt(v time.Time) predicate.OperationLog

PublishedAt applies equality check predicate on the "published_at" field. It's identical to PublishedAtEQ.

func PublishedAtEQ

func PublishedAtEQ(v time.Time) predicate.OperationLog

PublishedAtEQ applies the EQ predicate on the "published_at" field.

func PublishedAtGT

func PublishedAtGT(v time.Time) predicate.OperationLog

PublishedAtGT applies the GT predicate on the "published_at" field.

func PublishedAtGTE

func PublishedAtGTE(v time.Time) predicate.OperationLog

PublishedAtGTE applies the GTE predicate on the "published_at" field.

func PublishedAtIn

func PublishedAtIn(vs ...time.Time) predicate.OperationLog

PublishedAtIn applies the In predicate on the "published_at" field.

func PublishedAtIsNil

func PublishedAtIsNil() predicate.OperationLog

PublishedAtIsNil applies the IsNil predicate on the "published_at" field.

func PublishedAtLT

func PublishedAtLT(v time.Time) predicate.OperationLog

PublishedAtLT applies the LT predicate on the "published_at" field.

func PublishedAtLTE

func PublishedAtLTE(v time.Time) predicate.OperationLog

PublishedAtLTE applies the LTE predicate on the "published_at" field.

func PublishedAtNEQ

func PublishedAtNEQ(v time.Time) predicate.OperationLog

PublishedAtNEQ applies the NEQ predicate on the "published_at" field.

func PublishedAtNotIn

func PublishedAtNotIn(vs ...time.Time) predicate.OperationLog

PublishedAtNotIn applies the NotIn predicate on the "published_at" field.

func PublishedAtNotNil

func PublishedAtNotNil() predicate.OperationLog

PublishedAtNotNil applies the NotNil predicate on the "published_at" field.

func QueryParams

func QueryParams(v string) predicate.OperationLog

QueryParams applies equality check predicate on the "query_params" field. It's identical to QueryParamsEQ.

func QueryParamsContains

func QueryParamsContains(v string) predicate.OperationLog

QueryParamsContains applies the Contains predicate on the "query_params" field.

func QueryParamsContainsFold

func QueryParamsContainsFold(v string) predicate.OperationLog

QueryParamsContainsFold applies the ContainsFold predicate on the "query_params" field.

func QueryParamsEQ

func QueryParamsEQ(v string) predicate.OperationLog

QueryParamsEQ applies the EQ predicate on the "query_params" field.

func QueryParamsEqualFold

func QueryParamsEqualFold(v string) predicate.OperationLog

QueryParamsEqualFold applies the EqualFold predicate on the "query_params" field.

func QueryParamsGT

func QueryParamsGT(v string) predicate.OperationLog

QueryParamsGT applies the GT predicate on the "query_params" field.

func QueryParamsGTE

func QueryParamsGTE(v string) predicate.OperationLog

QueryParamsGTE applies the GTE predicate on the "query_params" field.

func QueryParamsHasPrefix

func QueryParamsHasPrefix(v string) predicate.OperationLog

QueryParamsHasPrefix applies the HasPrefix predicate on the "query_params" field.

func QueryParamsHasSuffix

func QueryParamsHasSuffix(v string) predicate.OperationLog

QueryParamsHasSuffix applies the HasSuffix predicate on the "query_params" field.

func QueryParamsIn

func QueryParamsIn(vs ...string) predicate.OperationLog

QueryParamsIn applies the In predicate on the "query_params" field.

func QueryParamsIsNil

func QueryParamsIsNil() predicate.OperationLog

QueryParamsIsNil applies the IsNil predicate on the "query_params" field.

func QueryParamsLT

func QueryParamsLT(v string) predicate.OperationLog

QueryParamsLT applies the LT predicate on the "query_params" field.

func QueryParamsLTE

func QueryParamsLTE(v string) predicate.OperationLog

QueryParamsLTE applies the LTE predicate on the "query_params" field.

func QueryParamsNEQ

func QueryParamsNEQ(v string) predicate.OperationLog

QueryParamsNEQ applies the NEQ predicate on the "query_params" field.

func QueryParamsNotIn

func QueryParamsNotIn(vs ...string) predicate.OperationLog

QueryParamsNotIn applies the NotIn predicate on the "query_params" field.

func QueryParamsNotNil

func QueryParamsNotNil() predicate.OperationLog

QueryParamsNotNil applies the NotNil predicate on the "query_params" field.

func RequestID

func RequestID(v string) predicate.OperationLog

RequestID applies equality check predicate on the "request_id" field. It's identical to RequestIDEQ.

func RequestIDContains

func RequestIDContains(v string) predicate.OperationLog

RequestIDContains applies the Contains predicate on the "request_id" field.

func RequestIDContainsFold

func RequestIDContainsFold(v string) predicate.OperationLog

RequestIDContainsFold applies the ContainsFold predicate on the "request_id" field.

func RequestIDEQ

func RequestIDEQ(v string) predicate.OperationLog

RequestIDEQ applies the EQ predicate on the "request_id" field.

func RequestIDEqualFold

func RequestIDEqualFold(v string) predicate.OperationLog

RequestIDEqualFold applies the EqualFold predicate on the "request_id" field.

func RequestIDGT

func RequestIDGT(v string) predicate.OperationLog

RequestIDGT applies the GT predicate on the "request_id" field.

func RequestIDGTE

func RequestIDGTE(v string) predicate.OperationLog

RequestIDGTE applies the GTE predicate on the "request_id" field.

func RequestIDHasPrefix

func RequestIDHasPrefix(v string) predicate.OperationLog

RequestIDHasPrefix applies the HasPrefix predicate on the "request_id" field.

func RequestIDHasSuffix

func RequestIDHasSuffix(v string) predicate.OperationLog

RequestIDHasSuffix applies the HasSuffix predicate on the "request_id" field.

func RequestIDIn

func RequestIDIn(vs ...string) predicate.OperationLog

RequestIDIn applies the In predicate on the "request_id" field.

func RequestIDIsNil

func RequestIDIsNil() predicate.OperationLog

RequestIDIsNil applies the IsNil predicate on the "request_id" field.

func RequestIDLT

func RequestIDLT(v string) predicate.OperationLog

RequestIDLT applies the LT predicate on the "request_id" field.

func RequestIDLTE

func RequestIDLTE(v string) predicate.OperationLog

RequestIDLTE applies the LTE predicate on the "request_id" field.

func RequestIDNEQ

func RequestIDNEQ(v string) predicate.OperationLog

RequestIDNEQ applies the NEQ predicate on the "request_id" field.

func RequestIDNotIn

func RequestIDNotIn(vs ...string) predicate.OperationLog

RequestIDNotIn applies the NotIn predicate on the "request_id" field.

func RequestIDNotNil

func RequestIDNotNil() predicate.OperationLog

RequestIDNotNil applies the NotNil predicate on the "request_id" field.

func Status

func Status(v int) predicate.OperationLog

Status applies equality check predicate on the "status" field. It's identical to StatusEQ.

func StatusEQ

func StatusEQ(v int) predicate.OperationLog

StatusEQ applies the EQ predicate on the "status" field.

func StatusGT

func StatusGT(v int) predicate.OperationLog

StatusGT applies the GT predicate on the "status" field.

func StatusGTE

func StatusGTE(v int) predicate.OperationLog

StatusGTE applies the GTE predicate on the "status" field.

func StatusIn

func StatusIn(vs ...int) predicate.OperationLog

StatusIn applies the In predicate on the "status" field.

func StatusLT

func StatusLT(v int) predicate.OperationLog

StatusLT applies the LT predicate on the "status" field.

func StatusLTE

func StatusLTE(v int) predicate.OperationLog

StatusLTE applies the LTE predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v int) predicate.OperationLog

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...int) predicate.OperationLog

StatusNotIn applies the NotIn predicate on the "status" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.OperationLog

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.OperationLog

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.OperationLog

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.OperationLog

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.OperationLog

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.OperationLog

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.OperationLog

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.OperationLog

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.OperationLog

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.OperationLog

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.OperationLog

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedByID

func UpdatedByID(v uuid.UUID) predicate.OperationLog

UpdatedByID applies equality check predicate on the "updated_by_id" field. It's identical to UpdatedByIDEQ.

func UpdatedByIDEQ

func UpdatedByIDEQ(v uuid.UUID) predicate.OperationLog

UpdatedByIDEQ applies the EQ predicate on the "updated_by_id" field.

func UpdatedByIDGT

func UpdatedByIDGT(v uuid.UUID) predicate.OperationLog

UpdatedByIDGT applies the GT predicate on the "updated_by_id" field.

func UpdatedByIDGTE

func UpdatedByIDGTE(v uuid.UUID) predicate.OperationLog

UpdatedByIDGTE applies the GTE predicate on the "updated_by_id" field.

func UpdatedByIDIn

func UpdatedByIDIn(vs ...uuid.UUID) predicate.OperationLog

UpdatedByIDIn applies the In predicate on the "updated_by_id" field.

func UpdatedByIDIsNil

func UpdatedByIDIsNil() predicate.OperationLog

UpdatedByIDIsNil applies the IsNil predicate on the "updated_by_id" field.

func UpdatedByIDLT

func UpdatedByIDLT(v uuid.UUID) predicate.OperationLog

UpdatedByIDLT applies the LT predicate on the "updated_by_id" field.

func UpdatedByIDLTE

func UpdatedByIDLTE(v uuid.UUID) predicate.OperationLog

UpdatedByIDLTE applies the LTE predicate on the "updated_by_id" field.

func UpdatedByIDNEQ

func UpdatedByIDNEQ(v uuid.UUID) predicate.OperationLog

UpdatedByIDNEQ applies the NEQ predicate on the "updated_by_id" field.

func UpdatedByIDNotIn

func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.OperationLog

UpdatedByIDNotIn applies the NotIn predicate on the "updated_by_id" field.

func UpdatedByIDNotNil

func UpdatedByIDNotNil() predicate.OperationLog

UpdatedByIDNotNil applies the NotNil predicate on the "updated_by_id" field.

func UserAgent

func UserAgent(v string) predicate.OperationLog

UserAgent applies equality check predicate on the "user_agent" field. It's identical to UserAgentEQ.

func UserAgentContains

func UserAgentContains(v string) predicate.OperationLog

UserAgentContains applies the Contains predicate on the "user_agent" field.

func UserAgentContainsFold

func UserAgentContainsFold(v string) predicate.OperationLog

UserAgentContainsFold applies the ContainsFold predicate on the "user_agent" field.

func UserAgentEQ

func UserAgentEQ(v string) predicate.OperationLog

UserAgentEQ applies the EQ predicate on the "user_agent" field.

func UserAgentEqualFold

func UserAgentEqualFold(v string) predicate.OperationLog

UserAgentEqualFold applies the EqualFold predicate on the "user_agent" field.

func UserAgentGT

func UserAgentGT(v string) predicate.OperationLog

UserAgentGT applies the GT predicate on the "user_agent" field.

func UserAgentGTE

func UserAgentGTE(v string) predicate.OperationLog

UserAgentGTE applies the GTE predicate on the "user_agent" field.

func UserAgentHasPrefix

func UserAgentHasPrefix(v string) predicate.OperationLog

UserAgentHasPrefix applies the HasPrefix predicate on the "user_agent" field.

func UserAgentHasSuffix

func UserAgentHasSuffix(v string) predicate.OperationLog

UserAgentHasSuffix applies the HasSuffix predicate on the "user_agent" field.

func UserAgentIn

func UserAgentIn(vs ...string) predicate.OperationLog

UserAgentIn applies the In predicate on the "user_agent" field.

func UserAgentIsNil

func UserAgentIsNil() predicate.OperationLog

UserAgentIsNil applies the IsNil predicate on the "user_agent" field.

func UserAgentLT

func UserAgentLT(v string) predicate.OperationLog

UserAgentLT applies the LT predicate on the "user_agent" field.

func UserAgentLTE

func UserAgentLTE(v string) predicate.OperationLog

UserAgentLTE applies the LTE predicate on the "user_agent" field.

func UserAgentNEQ

func UserAgentNEQ(v string) predicate.OperationLog

UserAgentNEQ applies the NEQ predicate on the "user_agent" field.

func UserAgentNotIn

func UserAgentNotIn(vs ...string) predicate.OperationLog

UserAgentNotIn applies the NotIn predicate on the "user_agent" field.

func UserAgentNotNil

func UserAgentNotNil() predicate.OperationLog

UserAgentNotNil applies the NotNil predicate on the "user_agent" field.

func UserID

func UserID(v uuid.UUID) predicate.OperationLog

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDEQ

func UserIDEQ(v uuid.UUID) predicate.OperationLog

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...uuid.UUID) predicate.OperationLog

UserIDIn applies the In predicate on the "user_id" field.

func UserIDIsNil

func UserIDIsNil() predicate.OperationLog

UserIDIsNil applies the IsNil predicate on the "user_id" field.

func UserIDNEQ

func UserIDNEQ(v uuid.UUID) predicate.OperationLog

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...uuid.UUID) predicate.OperationLog

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func UserIDNotNil

func UserIDNotNil() predicate.OperationLog

UserIDNotNil applies the NotNil predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the OperationLog queries.

func ByArchivedAt

func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption

ByArchivedAt orders the results by the archived_at field.

func ByBody

func ByBody(opts ...sql.OrderTermOption) OrderOption

ByBody orders the results by the body field.

func ByClientIP

func ByClientIP(opts ...sql.OrderTermOption) OrderOption

ByClientIP orders the results by the client_ip field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedByID

func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption

ByCreatedByID orders the results by the created_by_id field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedByID

func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption

ByDeletedByID orders the results by the deleted_by_id field.

func ByErrorMessage

func ByErrorMessage(opts ...sql.OrderTermOption) OrderOption

ByErrorMessage orders the results by the error_message field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLatency

func ByLatency(opts ...sql.OrderTermOption) OrderOption

ByLatency orders the results by the latency field.

func ByMethod

func ByMethod(opts ...sql.OrderTermOption) OrderOption

ByMethod orders the results by the method field.

func ByOwnerDomainID

func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption

ByOwnerDomainID orders the results by the owner_domain_id field.

func ByPath

func ByPath(opts ...sql.OrderTermOption) OrderOption

ByPath orders the results by the path field.

func ByPublishedAt

func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption

ByPublishedAt orders the results by the published_at field.

func ByQueryParams

func ByQueryParams(opts ...sql.OrderTermOption) OrderOption

ByQueryParams orders the results by the query_params field.

func ByRequestID

func ByRequestID(opts ...sql.OrderTermOption) OrderOption

ByRequestID orders the results by the request_id field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedByID

func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption

ByUpdatedByID orders the results by the updated_by_id field.

func ByUserAgent

func ByUserAgent(opts ...sql.OrderTermOption) OrderOption

ByUserAgent orders the results by the user_agent field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

Jump to