Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Post) predicate.Post
- func ArchivedAt(v time.Time) predicate.Post
- func ArchivedAtEQ(v time.Time) predicate.Post
- func ArchivedAtGT(v time.Time) predicate.Post
- func ArchivedAtGTE(v time.Time) predicate.Post
- func ArchivedAtIn(vs ...time.Time) predicate.Post
- func ArchivedAtIsNil() predicate.Post
- func ArchivedAtLT(v time.Time) predicate.Post
- func ArchivedAtLTE(v time.Time) predicate.Post
- func ArchivedAtNEQ(v time.Time) predicate.Post
- func ArchivedAtNotIn(vs ...time.Time) predicate.Post
- func ArchivedAtNotNil() predicate.Post
- func Content(v string) predicate.Post
- func ContentContains(v string) predicate.Post
- func ContentContainsFold(v string) predicate.Post
- func ContentEQ(v string) predicate.Post
- func ContentEqualFold(v string) predicate.Post
- func ContentGT(v string) predicate.Post
- func ContentGTE(v string) predicate.Post
- func ContentHasPrefix(v string) predicate.Post
- func ContentHasSuffix(v string) predicate.Post
- func ContentIn(vs ...string) predicate.Post
- func ContentLT(v string) predicate.Post
- func ContentLTE(v string) predicate.Post
- func ContentNEQ(v string) predicate.Post
- func ContentNotIn(vs ...string) predicate.Post
- func CreatedAt(v time.Time) predicate.Post
- func CreatedAtEQ(v time.Time) predicate.Post
- func CreatedAtGT(v time.Time) predicate.Post
- func CreatedAtGTE(v time.Time) predicate.Post
- func CreatedAtIn(vs ...time.Time) predicate.Post
- func CreatedAtIsNil() predicate.Post
- func CreatedAtLT(v time.Time) predicate.Post
- func CreatedAtLTE(v time.Time) predicate.Post
- func CreatedAtNEQ(v time.Time) predicate.Post
- func CreatedAtNotIn(vs ...time.Time) predicate.Post
- func CreatedAtNotNil() predicate.Post
- func CreatedByID(v uuid.UUID) predicate.Post
- func CreatedByIDEQ(v uuid.UUID) predicate.Post
- func CreatedByIDGT(v uuid.UUID) predicate.Post
- func CreatedByIDGTE(v uuid.UUID) predicate.Post
- func CreatedByIDIn(vs ...uuid.UUID) predicate.Post
- func CreatedByIDIsNil() predicate.Post
- func CreatedByIDLT(v uuid.UUID) predicate.Post
- func CreatedByIDLTE(v uuid.UUID) predicate.Post
- func CreatedByIDNEQ(v uuid.UUID) predicate.Post
- func CreatedByIDNotIn(vs ...uuid.UUID) predicate.Post
- func CreatedByIDNotNil() predicate.Post
- func DeletedAt(v time.Time) predicate.Post
- func DeletedAtEQ(v time.Time) predicate.Post
- func DeletedAtGT(v time.Time) predicate.Post
- func DeletedAtGTE(v time.Time) predicate.Post
- func DeletedAtIn(vs ...time.Time) predicate.Post
- func DeletedAtIsNil() predicate.Post
- func DeletedAtLT(v time.Time) predicate.Post
- func DeletedAtLTE(v time.Time) predicate.Post
- func DeletedAtNEQ(v time.Time) predicate.Post
- func DeletedAtNotIn(vs ...time.Time) predicate.Post
- func DeletedAtNotNil() predicate.Post
- func DeletedByID(v uuid.UUID) predicate.Post
- func DeletedByIDEQ(v uuid.UUID) predicate.Post
- func DeletedByIDGT(v uuid.UUID) predicate.Post
- func DeletedByIDGTE(v uuid.UUID) predicate.Post
- func DeletedByIDIn(vs ...uuid.UUID) predicate.Post
- func DeletedByIDIsNil() predicate.Post
- func DeletedByIDLT(v uuid.UUID) predicate.Post
- func DeletedByIDLTE(v uuid.UUID) predicate.Post
- func DeletedByIDNEQ(v uuid.UUID) predicate.Post
- func DeletedByIDNotIn(vs ...uuid.UUID) predicate.Post
- func DeletedByIDNotNil() predicate.Post
- func HasAuthor() predicate.Post
- func HasAuthorWith(preds ...predicate.User) predicate.Post
- func HasMedia() predicate.Post
- func HasMediaWith(preds ...predicate.Media) predicate.Post
- func ID(id uuid.UUID) predicate.Post
- func IDEQ(id uuid.UUID) predicate.Post
- func IDGT(id uuid.UUID) predicate.Post
- func IDGTE(id uuid.UUID) predicate.Post
- func IDIn(ids ...uuid.UUID) predicate.Post
- func IDLT(id uuid.UUID) predicate.Post
- func IDLTE(id uuid.UUID) predicate.Post
- func IDNEQ(id uuid.UUID) predicate.Post
- func IDNotIn(ids ...uuid.UUID) predicate.Post
- func Not(p predicate.Post) predicate.Post
- func Or(predicates ...predicate.Post) predicate.Post
- func OwnerDomainID(v uuid.UUID) predicate.Post
- func OwnerDomainIDEQ(v uuid.UUID) predicate.Post
- func OwnerDomainIDGT(v uuid.UUID) predicate.Post
- func OwnerDomainIDGTE(v uuid.UUID) predicate.Post
- func OwnerDomainIDIn(vs ...uuid.UUID) predicate.Post
- func OwnerDomainIDIsNil() predicate.Post
- func OwnerDomainIDLT(v uuid.UUID) predicate.Post
- func OwnerDomainIDLTE(v uuid.UUID) predicate.Post
- func OwnerDomainIDNEQ(v uuid.UUID) predicate.Post
- func OwnerDomainIDNotIn(vs ...uuid.UUID) predicate.Post
- func OwnerDomainIDNotNil() predicate.Post
- func PublishedAt(v time.Time) predicate.Post
- func PublishedAtEQ(v time.Time) predicate.Post
- func PublishedAtGT(v time.Time) predicate.Post
- func PublishedAtGTE(v time.Time) predicate.Post
- func PublishedAtIn(vs ...time.Time) predicate.Post
- func PublishedAtIsNil() predicate.Post
- func PublishedAtLT(v time.Time) predicate.Post
- func PublishedAtLTE(v time.Time) predicate.Post
- func PublishedAtNEQ(v time.Time) predicate.Post
- func PublishedAtNotIn(vs ...time.Time) predicate.Post
- func PublishedAtNotNil() predicate.Post
- func Slug(v string) predicate.Post
- func SlugContains(v string) predicate.Post
- func SlugContainsFold(v string) predicate.Post
- func SlugEQ(v string) predicate.Post
- func SlugEqualFold(v string) predicate.Post
- func SlugGT(v string) predicate.Post
- func SlugGTE(v string) predicate.Post
- func SlugHasPrefix(v string) predicate.Post
- func SlugHasSuffix(v string) predicate.Post
- func SlugIn(vs ...string) predicate.Post
- func SlugLT(v string) predicate.Post
- func SlugLTE(v string) predicate.Post
- func SlugNEQ(v string) predicate.Post
- func SlugNotIn(vs ...string) predicate.Post
- func StatusEQ(v Status) predicate.Post
- func StatusIn(vs ...Status) predicate.Post
- func StatusNEQ(v Status) predicate.Post
- func StatusNotIn(vs ...Status) predicate.Post
- func StatusValidator(s Status) error
- func TagsIsNil() predicate.Post
- func TagsNotNil() predicate.Post
- func Title(v string) predicate.Post
- func TitleContains(v string) predicate.Post
- func TitleContainsFold(v string) predicate.Post
- func TitleEQ(v string) predicate.Post
- func TitleEqualFold(v string) predicate.Post
- func TitleGT(v string) predicate.Post
- func TitleGTE(v string) predicate.Post
- func TitleHasPrefix(v string) predicate.Post
- func TitleHasSuffix(v string) predicate.Post
- func TitleIn(vs ...string) predicate.Post
- func TitleLT(v string) predicate.Post
- func TitleLTE(v string) predicate.Post
- func TitleNEQ(v string) predicate.Post
- func TitleNotIn(vs ...string) predicate.Post
- func UpdatedAt(v time.Time) predicate.Post
- func UpdatedAtEQ(v time.Time) predicate.Post
- func UpdatedAtGT(v time.Time) predicate.Post
- func UpdatedAtGTE(v time.Time) predicate.Post
- func UpdatedAtIn(vs ...time.Time) predicate.Post
- func UpdatedAtIsNil() predicate.Post
- func UpdatedAtLT(v time.Time) predicate.Post
- func UpdatedAtLTE(v time.Time) predicate.Post
- func UpdatedAtNEQ(v time.Time) predicate.Post
- func UpdatedAtNotIn(vs ...time.Time) predicate.Post
- func UpdatedAtNotNil() predicate.Post
- func UpdatedByID(v uuid.UUID) predicate.Post
- func UpdatedByIDEQ(v uuid.UUID) predicate.Post
- func UpdatedByIDGT(v uuid.UUID) predicate.Post
- func UpdatedByIDGTE(v uuid.UUID) predicate.Post
- func UpdatedByIDIn(vs ...uuid.UUID) predicate.Post
- func UpdatedByIDIsNil() predicate.Post
- func UpdatedByIDLT(v uuid.UUID) predicate.Post
- func UpdatedByIDLTE(v uuid.UUID) predicate.Post
- func UpdatedByIDNEQ(v uuid.UUID) predicate.Post
- func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.Post
- func UpdatedByIDNotNil() predicate.Post
- func ValidColumn(column string) bool
- func ViewCount(v int) predicate.Post
- func ViewCountEQ(v int) predicate.Post
- func ViewCountGT(v int) predicate.Post
- func ViewCountGTE(v int) predicate.Post
- func ViewCountIn(vs ...int) predicate.Post
- func ViewCountLT(v int) predicate.Post
- func ViewCountLTE(v int) predicate.Post
- func ViewCountNEQ(v int) predicate.Post
- func ViewCountNotIn(vs ...int) predicate.Post
- type OrderOption
- func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
- func ByAuthor(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByAuthorCount(opts ...sql.OrderTermOption) OrderOption
- func ByContent(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByMedia(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByMediaCount(opts ...sql.OrderTermOption) OrderOption
- func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption
- func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
- func BySlug(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByTitle(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
- func ByViewCount(opts ...sql.OrderTermOption) OrderOption
- type Status
Constants ¶
const ( // Label holds the string label denoting the post type in the database. Label = "post" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedByID holds the string denoting the created_by_id field in the database. FieldCreatedByID = "created_by_id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedByID holds the string denoting the updated_by_id field in the database. FieldUpdatedByID = "updated_by_id" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedByID holds the string denoting the deleted_by_id field in the database. FieldDeletedByID = "deleted_by_id" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldPublishedAt holds the string denoting the published_at field in the database. FieldPublishedAt = "published_at" // FieldArchivedAt holds the string denoting the archived_at field in the database. FieldArchivedAt = "archived_at" // FieldOwnerDomainID holds the string denoting the owner_domain_id field in the database. FieldOwnerDomainID = "owner_domain_id" // FieldTitle holds the string denoting the title field in the database. FieldTitle = "title" // FieldContent holds the string denoting the content field in the database. FieldContent = "content" // FieldSlug holds the string denoting the slug field in the database. FieldSlug = "slug" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldViewCount holds the string denoting the view_count field in the database. FieldViewCount = "view_count" // FieldTags holds the string denoting the tags field in the database. FieldTags = "tags" // EdgeAuthor holds the string denoting the author edge name in mutations. EdgeAuthor = "author" // EdgeMedia holds the string denoting the media edge name in mutations. EdgeMedia = "media" // Table holds the table name of the post in the database. Table = "posts" // AuthorTable is the table that holds the author relation/edge. The primary key declared below. AuthorTable = "user_posts" // AuthorInverseTable is the table name for the User entity. // It exists in this package in order to avoid circular dependency with the "user" package. AuthorInverseTable = "users" // MediaTable is the table that holds the media relation/edge. The primary key declared below. MediaTable = "post_media" // MediaInverseTable is the table name for the Media entity. // It exists in this package in order to avoid circular dependency with the "media" package. MediaInverseTable = "media" )
const DefaultStatus = StatusDraft
StatusDraft is the default value of the Status enum.
Variables ¶
var ( // AuthorPrimaryKey and AuthorColumn2 are the table columns denoting the // primary key for the author relation (M2M). AuthorPrimaryKey = []string{"user_id", "post_id"} // MediaPrimaryKey and MediaColumn2 are the table columns denoting the // primary key for the media relation (M2M). MediaPrimaryKey = []string{"post_id", "media_id"} )
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // TitleValidator is a validator for the "title" field. It is called by the builders before save. TitleValidator func(string) error // ContentValidator is a validator for the "content" field. It is called by the builders before save. ContentValidator func(string) error // SlugValidator is a validator for the "slug" field. It is called by the builders before save. SlugValidator func(string) error // DefaultViewCount holds the default value on creation for the "view_count" field. DefaultViewCount int // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldCreatedByID, FieldCreatedAt, FieldUpdatedByID, FieldUpdatedAt, FieldDeletedByID, FieldDeletedAt, FieldPublishedAt, FieldArchivedAt, FieldOwnerDomainID, FieldTitle, FieldContent, FieldSlug, FieldStatus, FieldViewCount, FieldTags, }
Columns holds all SQL columns for post fields.
Functions ¶
func ArchivedAt ¶
ArchivedAt applies equality check predicate on the "archived_at" field. It's identical to ArchivedAtEQ.
func ArchivedAtEQ ¶
ArchivedAtEQ applies the EQ predicate on the "archived_at" field.
func ArchivedAtGT ¶
ArchivedAtGT applies the GT predicate on the "archived_at" field.
func ArchivedAtGTE ¶
ArchivedAtGTE applies the GTE predicate on the "archived_at" field.
func ArchivedAtIn ¶
ArchivedAtIn applies the In predicate on the "archived_at" field.
func ArchivedAtIsNil ¶
ArchivedAtIsNil applies the IsNil predicate on the "archived_at" field.
func ArchivedAtLT ¶
ArchivedAtLT applies the LT predicate on the "archived_at" field.
func ArchivedAtLTE ¶
ArchivedAtLTE applies the LTE predicate on the "archived_at" field.
func ArchivedAtNEQ ¶
ArchivedAtNEQ applies the NEQ predicate on the "archived_at" field.
func ArchivedAtNotIn ¶
ArchivedAtNotIn applies the NotIn predicate on the "archived_at" field.
func ArchivedAtNotNil ¶
ArchivedAtNotNil applies the NotNil predicate on the "archived_at" field.
func Content ¶
Content applies equality check predicate on the "content" field. It's identical to ContentEQ.
func ContentContains ¶
ContentContains applies the Contains predicate on the "content" field.
func ContentContainsFold ¶
ContentContainsFold applies the ContainsFold predicate on the "content" field.
func ContentEqualFold ¶
ContentEqualFold applies the EqualFold predicate on the "content" field.
func ContentGTE ¶
ContentGTE applies the GTE predicate on the "content" field.
func ContentHasPrefix ¶
ContentHasPrefix applies the HasPrefix predicate on the "content" field.
func ContentHasSuffix ¶
ContentHasSuffix applies the HasSuffix predicate on the "content" field.
func ContentLTE ¶
ContentLTE applies the LTE predicate on the "content" field.
func ContentNEQ ¶
ContentNEQ applies the NEQ predicate on the "content" field.
func ContentNotIn ¶
ContentNotIn applies the NotIn predicate on the "content" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedByID ¶
CreatedByID applies equality check predicate on the "created_by_id" field. It's identical to CreatedByIDEQ.
func CreatedByIDEQ ¶
CreatedByIDEQ applies the EQ predicate on the "created_by_id" field.
func CreatedByIDGT ¶
CreatedByIDGT applies the GT predicate on the "created_by_id" field.
func CreatedByIDGTE ¶
CreatedByIDGTE applies the GTE predicate on the "created_by_id" field.
func CreatedByIDIn ¶
CreatedByIDIn applies the In predicate on the "created_by_id" field.
func CreatedByIDIsNil ¶
CreatedByIDIsNil applies the IsNil predicate on the "created_by_id" field.
func CreatedByIDLT ¶
CreatedByIDLT applies the LT predicate on the "created_by_id" field.
func CreatedByIDLTE ¶
CreatedByIDLTE applies the LTE predicate on the "created_by_id" field.
func CreatedByIDNEQ ¶
CreatedByIDNEQ applies the NEQ predicate on the "created_by_id" field.
func CreatedByIDNotIn ¶
CreatedByIDNotIn applies the NotIn predicate on the "created_by_id" field.
func CreatedByIDNotNil ¶
CreatedByIDNotNil applies the NotNil predicate on the "created_by_id" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedByID ¶
DeletedByID applies equality check predicate on the "deleted_by_id" field. It's identical to DeletedByIDEQ.
func DeletedByIDEQ ¶
DeletedByIDEQ applies the EQ predicate on the "deleted_by_id" field.
func DeletedByIDGT ¶
DeletedByIDGT applies the GT predicate on the "deleted_by_id" field.
func DeletedByIDGTE ¶
DeletedByIDGTE applies the GTE predicate on the "deleted_by_id" field.
func DeletedByIDIn ¶
DeletedByIDIn applies the In predicate on the "deleted_by_id" field.
func DeletedByIDIsNil ¶
DeletedByIDIsNil applies the IsNil predicate on the "deleted_by_id" field.
func DeletedByIDLT ¶
DeletedByIDLT applies the LT predicate on the "deleted_by_id" field.
func DeletedByIDLTE ¶
DeletedByIDLTE applies the LTE predicate on the "deleted_by_id" field.
func DeletedByIDNEQ ¶
DeletedByIDNEQ applies the NEQ predicate on the "deleted_by_id" field.
func DeletedByIDNotIn ¶
DeletedByIDNotIn applies the NotIn predicate on the "deleted_by_id" field.
func DeletedByIDNotNil ¶
DeletedByIDNotNil applies the NotNil predicate on the "deleted_by_id" field.
func HasAuthorWith ¶
HasAuthorWith applies the HasEdge predicate on the "author" edge with a given conditions (other predicates).
func HasMediaWith ¶
HasMediaWith applies the HasEdge predicate on the "media" edge with a given conditions (other predicates).
func OwnerDomainID ¶
OwnerDomainID applies equality check predicate on the "owner_domain_id" field. It's identical to OwnerDomainIDEQ.
func OwnerDomainIDEQ ¶
OwnerDomainIDEQ applies the EQ predicate on the "owner_domain_id" field.
func OwnerDomainIDGT ¶
OwnerDomainIDGT applies the GT predicate on the "owner_domain_id" field.
func OwnerDomainIDGTE ¶
OwnerDomainIDGTE applies the GTE predicate on the "owner_domain_id" field.
func OwnerDomainIDIn ¶
OwnerDomainIDIn applies the In predicate on the "owner_domain_id" field.
func OwnerDomainIDIsNil ¶
OwnerDomainIDIsNil applies the IsNil predicate on the "owner_domain_id" field.
func OwnerDomainIDLT ¶
OwnerDomainIDLT applies the LT predicate on the "owner_domain_id" field.
func OwnerDomainIDLTE ¶
OwnerDomainIDLTE applies the LTE predicate on the "owner_domain_id" field.
func OwnerDomainIDNEQ ¶
OwnerDomainIDNEQ applies the NEQ predicate on the "owner_domain_id" field.
func OwnerDomainIDNotIn ¶
OwnerDomainIDNotIn applies the NotIn predicate on the "owner_domain_id" field.
func OwnerDomainIDNotNil ¶
OwnerDomainIDNotNil applies the NotNil predicate on the "owner_domain_id" field.
func PublishedAt ¶
PublishedAt applies equality check predicate on the "published_at" field. It's identical to PublishedAtEQ.
func PublishedAtEQ ¶
PublishedAtEQ applies the EQ predicate on the "published_at" field.
func PublishedAtGT ¶
PublishedAtGT applies the GT predicate on the "published_at" field.
func PublishedAtGTE ¶
PublishedAtGTE applies the GTE predicate on the "published_at" field.
func PublishedAtIn ¶
PublishedAtIn applies the In predicate on the "published_at" field.
func PublishedAtIsNil ¶
PublishedAtIsNil applies the IsNil predicate on the "published_at" field.
func PublishedAtLT ¶
PublishedAtLT applies the LT predicate on the "published_at" field.
func PublishedAtLTE ¶
PublishedAtLTE applies the LTE predicate on the "published_at" field.
func PublishedAtNEQ ¶
PublishedAtNEQ applies the NEQ predicate on the "published_at" field.
func PublishedAtNotIn ¶
PublishedAtNotIn applies the NotIn predicate on the "published_at" field.
func PublishedAtNotNil ¶
PublishedAtNotNil applies the NotNil predicate on the "published_at" field.
func SlugContains ¶
SlugContains applies the Contains predicate on the "slug" field.
func SlugContainsFold ¶
SlugContainsFold applies the ContainsFold predicate on the "slug" field.
func SlugEqualFold ¶
SlugEqualFold applies the EqualFold predicate on the "slug" field.
func SlugHasPrefix ¶
SlugHasPrefix applies the HasPrefix predicate on the "slug" field.
func SlugHasSuffix ¶
SlugHasSuffix applies the HasSuffix predicate on the "slug" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func StatusValidator ¶
StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.
func TagsNotNil ¶
TagsNotNil applies the NotNil predicate on the "tags" field.
func Title ¶
Title applies equality check predicate on the "title" field. It's identical to TitleEQ.
func TitleContains ¶
TitleContains applies the Contains predicate on the "title" field.
func TitleContainsFold ¶
TitleContainsFold applies the ContainsFold predicate on the "title" field.
func TitleEqualFold ¶
TitleEqualFold applies the EqualFold predicate on the "title" field.
func TitleHasPrefix ¶
TitleHasPrefix applies the HasPrefix predicate on the "title" field.
func TitleHasSuffix ¶
TitleHasSuffix applies the HasSuffix predicate on the "title" field.
func TitleNotIn ¶
TitleNotIn applies the NotIn predicate on the "title" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedByID ¶
UpdatedByID applies equality check predicate on the "updated_by_id" field. It's identical to UpdatedByIDEQ.
func UpdatedByIDEQ ¶
UpdatedByIDEQ applies the EQ predicate on the "updated_by_id" field.
func UpdatedByIDGT ¶
UpdatedByIDGT applies the GT predicate on the "updated_by_id" field.
func UpdatedByIDGTE ¶
UpdatedByIDGTE applies the GTE predicate on the "updated_by_id" field.
func UpdatedByIDIn ¶
UpdatedByIDIn applies the In predicate on the "updated_by_id" field.
func UpdatedByIDIsNil ¶
UpdatedByIDIsNil applies the IsNil predicate on the "updated_by_id" field.
func UpdatedByIDLT ¶
UpdatedByIDLT applies the LT predicate on the "updated_by_id" field.
func UpdatedByIDLTE ¶
UpdatedByIDLTE applies the LTE predicate on the "updated_by_id" field.
func UpdatedByIDNEQ ¶
UpdatedByIDNEQ applies the NEQ predicate on the "updated_by_id" field.
func UpdatedByIDNotIn ¶
UpdatedByIDNotIn applies the NotIn predicate on the "updated_by_id" field.
func UpdatedByIDNotNil ¶
UpdatedByIDNotNil applies the NotNil predicate on the "updated_by_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func ViewCount ¶
ViewCount applies equality check predicate on the "view_count" field. It's identical to ViewCountEQ.
func ViewCountEQ ¶
ViewCountEQ applies the EQ predicate on the "view_count" field.
func ViewCountGT ¶
ViewCountGT applies the GT predicate on the "view_count" field.
func ViewCountGTE ¶
ViewCountGTE applies the GTE predicate on the "view_count" field.
func ViewCountIn ¶
ViewCountIn applies the In predicate on the "view_count" field.
func ViewCountLT ¶
ViewCountLT applies the LT predicate on the "view_count" field.
func ViewCountLTE ¶
ViewCountLTE applies the LTE predicate on the "view_count" field.
func ViewCountNEQ ¶
ViewCountNEQ applies the NEQ predicate on the "view_count" field.
func ViewCountNotIn ¶
ViewCountNotIn applies the NotIn predicate on the "view_count" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Post queries.
func ByArchivedAt ¶
func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
ByArchivedAt orders the results by the archived_at field.
func ByAuthor ¶
func ByAuthor(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByAuthor orders the results by author terms.
func ByAuthorCount ¶
func ByAuthorCount(opts ...sql.OrderTermOption) OrderOption
ByAuthorCount orders the results by author count.
func ByContent ¶
func ByContent(opts ...sql.OrderTermOption) OrderOption
ByContent orders the results by the content field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedByID ¶
func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
ByCreatedByID orders the results by the created_by_id field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedByID ¶
func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
ByDeletedByID orders the results by the deleted_by_id field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByMedia ¶
func ByMedia(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByMedia orders the results by media terms.
func ByMediaCount ¶
func ByMediaCount(opts ...sql.OrderTermOption) OrderOption
ByMediaCount orders the results by media count.
func ByOwnerDomainID ¶
func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption
ByOwnerDomainID orders the results by the owner_domain_id field.
func ByPublishedAt ¶
func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
ByPublishedAt orders the results by the published_at field.
func BySlug ¶
func BySlug(opts ...sql.OrderTermOption) OrderOption
BySlug orders the results by the slug field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByTitle ¶
func ByTitle(opts ...sql.OrderTermOption) OrderOption
ByTitle orders the results by the title field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedByID ¶
func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
ByUpdatedByID orders the results by the updated_by_id field.
func ByViewCount ¶
func ByViewCount(opts ...sql.OrderTermOption) OrderOption
ByViewCount orders the results by the view_count field.