systemerror

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 28, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the systemerror type in the database.
	Label = "system_error"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedByID holds the string denoting the created_by_id field in the database.
	FieldCreatedByID = "created_by_id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedByID holds the string denoting the updated_by_id field in the database.
	FieldUpdatedByID = "updated_by_id"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldDeletedByID holds the string denoting the deleted_by_id field in the database.
	FieldDeletedByID = "deleted_by_id"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldPublishedAt holds the string denoting the published_at field in the database.
	FieldPublishedAt = "published_at"
	// FieldArchivedAt holds the string denoting the archived_at field in the database.
	FieldArchivedAt = "archived_at"
	// FieldOwnerDomainID holds the string denoting the owner_domain_id field in the database.
	FieldOwnerDomainID = "owner_domain_id"
	// FieldErrorLevel holds the string denoting the error_level field in the database.
	FieldErrorLevel = "error_level"
	// FieldErrorType holds the string denoting the error_type field in the database.
	FieldErrorType = "error_type"
	// FieldErrorMsg holds the string denoting the error_msg field in the database.
	FieldErrorMsg = "error_msg"
	// FieldErrorStack holds the string denoting the error_stack field in the database.
	FieldErrorStack = "error_stack"
	// FieldErrorCode holds the string denoting the error_code field in the database.
	FieldErrorCode = "error_code"
	// FieldRequestID holds the string denoting the request_id field in the database.
	FieldRequestID = "request_id"
	// FieldRequestMethod holds the string denoting the request_method field in the database.
	FieldRequestMethod = "request_method"
	// FieldRequestPath holds the string denoting the request_path field in the database.
	FieldRequestPath = "request_path"
	// FieldRequestBody holds the string denoting the request_body field in the database.
	FieldRequestBody = "request_body"
	// FieldResponseBody holds the string denoting the response_body field in the database.
	FieldResponseBody = "response_body"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// Table holds the table name of the systemerror in the database.
	Table = "system_errors"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "system_errors"
	// UserInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	UserInverseTable = "users"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "user_id"
)
const DefaultErrorLevel = ErrorLevelError

ErrorLevelError is the default value of the ErrorLevel enum.

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// ErrorTypeValidator is a validator for the "error_type" field. It is called by the builders before save.
	ErrorTypeValidator func(string) error
	// ErrorMsgValidator is a validator for the "error_msg" field. It is called by the builders before save.
	ErrorMsgValidator func(string) error
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for systemerror fields.

Functions

func And

func And(predicates ...predicate.SystemError) predicate.SystemError

And groups predicates with the AND operator between them.

func ArchivedAt

func ArchivedAt(v time.Time) predicate.SystemError

ArchivedAt applies equality check predicate on the "archived_at" field. It's identical to ArchivedAtEQ.

func ArchivedAtEQ

func ArchivedAtEQ(v time.Time) predicate.SystemError

ArchivedAtEQ applies the EQ predicate on the "archived_at" field.

func ArchivedAtGT

func ArchivedAtGT(v time.Time) predicate.SystemError

ArchivedAtGT applies the GT predicate on the "archived_at" field.

func ArchivedAtGTE

func ArchivedAtGTE(v time.Time) predicate.SystemError

ArchivedAtGTE applies the GTE predicate on the "archived_at" field.

func ArchivedAtIn

func ArchivedAtIn(vs ...time.Time) predicate.SystemError

ArchivedAtIn applies the In predicate on the "archived_at" field.

func ArchivedAtIsNil

func ArchivedAtIsNil() predicate.SystemError

ArchivedAtIsNil applies the IsNil predicate on the "archived_at" field.

func ArchivedAtLT

func ArchivedAtLT(v time.Time) predicate.SystemError

ArchivedAtLT applies the LT predicate on the "archived_at" field.

func ArchivedAtLTE

func ArchivedAtLTE(v time.Time) predicate.SystemError

ArchivedAtLTE applies the LTE predicate on the "archived_at" field.

func ArchivedAtNEQ

func ArchivedAtNEQ(v time.Time) predicate.SystemError

ArchivedAtNEQ applies the NEQ predicate on the "archived_at" field.

func ArchivedAtNotIn

func ArchivedAtNotIn(vs ...time.Time) predicate.SystemError

ArchivedAtNotIn applies the NotIn predicate on the "archived_at" field.

func ArchivedAtNotNil

func ArchivedAtNotNil() predicate.SystemError

ArchivedAtNotNil applies the NotNil predicate on the "archived_at" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.SystemError

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.SystemError

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.SystemError

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.SystemError

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.SystemError

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.SystemError

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.SystemError

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.SystemError

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.SystemError

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.SystemError

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.SystemError

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedByID

func CreatedByID(v uuid.UUID) predicate.SystemError

CreatedByID applies equality check predicate on the "created_by_id" field. It's identical to CreatedByIDEQ.

func CreatedByIDEQ

func CreatedByIDEQ(v uuid.UUID) predicate.SystemError

CreatedByIDEQ applies the EQ predicate on the "created_by_id" field.

func CreatedByIDGT

func CreatedByIDGT(v uuid.UUID) predicate.SystemError

CreatedByIDGT applies the GT predicate on the "created_by_id" field.

func CreatedByIDGTE

func CreatedByIDGTE(v uuid.UUID) predicate.SystemError

CreatedByIDGTE applies the GTE predicate on the "created_by_id" field.

func CreatedByIDIn

func CreatedByIDIn(vs ...uuid.UUID) predicate.SystemError

CreatedByIDIn applies the In predicate on the "created_by_id" field.

func CreatedByIDIsNil

func CreatedByIDIsNil() predicate.SystemError

CreatedByIDIsNil applies the IsNil predicate on the "created_by_id" field.

func CreatedByIDLT

func CreatedByIDLT(v uuid.UUID) predicate.SystemError

CreatedByIDLT applies the LT predicate on the "created_by_id" field.

func CreatedByIDLTE

func CreatedByIDLTE(v uuid.UUID) predicate.SystemError

CreatedByIDLTE applies the LTE predicate on the "created_by_id" field.

func CreatedByIDNEQ

func CreatedByIDNEQ(v uuid.UUID) predicate.SystemError

CreatedByIDNEQ applies the NEQ predicate on the "created_by_id" field.

func CreatedByIDNotIn

func CreatedByIDNotIn(vs ...uuid.UUID) predicate.SystemError

CreatedByIDNotIn applies the NotIn predicate on the "created_by_id" field.

func CreatedByIDNotNil

func CreatedByIDNotNil() predicate.SystemError

CreatedByIDNotNil applies the NotNil predicate on the "created_by_id" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.SystemError

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.SystemError

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.SystemError

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.SystemError

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.SystemError

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.SystemError

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.SystemError

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.SystemError

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.SystemError

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.SystemError

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.SystemError

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedByID

func DeletedByID(v uuid.UUID) predicate.SystemError

DeletedByID applies equality check predicate on the "deleted_by_id" field. It's identical to DeletedByIDEQ.

func DeletedByIDEQ

func DeletedByIDEQ(v uuid.UUID) predicate.SystemError

DeletedByIDEQ applies the EQ predicate on the "deleted_by_id" field.

func DeletedByIDGT

func DeletedByIDGT(v uuid.UUID) predicate.SystemError

DeletedByIDGT applies the GT predicate on the "deleted_by_id" field.

func DeletedByIDGTE

func DeletedByIDGTE(v uuid.UUID) predicate.SystemError

DeletedByIDGTE applies the GTE predicate on the "deleted_by_id" field.

func DeletedByIDIn

func DeletedByIDIn(vs ...uuid.UUID) predicate.SystemError

DeletedByIDIn applies the In predicate on the "deleted_by_id" field.

func DeletedByIDIsNil

func DeletedByIDIsNil() predicate.SystemError

DeletedByIDIsNil applies the IsNil predicate on the "deleted_by_id" field.

func DeletedByIDLT

func DeletedByIDLT(v uuid.UUID) predicate.SystemError

DeletedByIDLT applies the LT predicate on the "deleted_by_id" field.

func DeletedByIDLTE

func DeletedByIDLTE(v uuid.UUID) predicate.SystemError

DeletedByIDLTE applies the LTE predicate on the "deleted_by_id" field.

func DeletedByIDNEQ

func DeletedByIDNEQ(v uuid.UUID) predicate.SystemError

DeletedByIDNEQ applies the NEQ predicate on the "deleted_by_id" field.

func DeletedByIDNotIn

func DeletedByIDNotIn(vs ...uuid.UUID) predicate.SystemError

DeletedByIDNotIn applies the NotIn predicate on the "deleted_by_id" field.

func DeletedByIDNotNil

func DeletedByIDNotNil() predicate.SystemError

DeletedByIDNotNil applies the NotNil predicate on the "deleted_by_id" field.

func ErrorCode

func ErrorCode(v string) predicate.SystemError

ErrorCode applies equality check predicate on the "error_code" field. It's identical to ErrorCodeEQ.

func ErrorCodeContains

func ErrorCodeContains(v string) predicate.SystemError

ErrorCodeContains applies the Contains predicate on the "error_code" field.

func ErrorCodeContainsFold

func ErrorCodeContainsFold(v string) predicate.SystemError

ErrorCodeContainsFold applies the ContainsFold predicate on the "error_code" field.

func ErrorCodeEQ

func ErrorCodeEQ(v string) predicate.SystemError

ErrorCodeEQ applies the EQ predicate on the "error_code" field.

func ErrorCodeEqualFold

func ErrorCodeEqualFold(v string) predicate.SystemError

ErrorCodeEqualFold applies the EqualFold predicate on the "error_code" field.

func ErrorCodeGT

func ErrorCodeGT(v string) predicate.SystemError

ErrorCodeGT applies the GT predicate on the "error_code" field.

func ErrorCodeGTE

func ErrorCodeGTE(v string) predicate.SystemError

ErrorCodeGTE applies the GTE predicate on the "error_code" field.

func ErrorCodeHasPrefix

func ErrorCodeHasPrefix(v string) predicate.SystemError

ErrorCodeHasPrefix applies the HasPrefix predicate on the "error_code" field.

func ErrorCodeHasSuffix

func ErrorCodeHasSuffix(v string) predicate.SystemError

ErrorCodeHasSuffix applies the HasSuffix predicate on the "error_code" field.

func ErrorCodeIn

func ErrorCodeIn(vs ...string) predicate.SystemError

ErrorCodeIn applies the In predicate on the "error_code" field.

func ErrorCodeIsNil

func ErrorCodeIsNil() predicate.SystemError

ErrorCodeIsNil applies the IsNil predicate on the "error_code" field.

func ErrorCodeLT

func ErrorCodeLT(v string) predicate.SystemError

ErrorCodeLT applies the LT predicate on the "error_code" field.

func ErrorCodeLTE

func ErrorCodeLTE(v string) predicate.SystemError

ErrorCodeLTE applies the LTE predicate on the "error_code" field.

func ErrorCodeNEQ

func ErrorCodeNEQ(v string) predicate.SystemError

ErrorCodeNEQ applies the NEQ predicate on the "error_code" field.

func ErrorCodeNotIn

func ErrorCodeNotIn(vs ...string) predicate.SystemError

ErrorCodeNotIn applies the NotIn predicate on the "error_code" field.

func ErrorCodeNotNil

func ErrorCodeNotNil() predicate.SystemError

ErrorCodeNotNil applies the NotNil predicate on the "error_code" field.

func ErrorLevelEQ

func ErrorLevelEQ(v ErrorLevel) predicate.SystemError

ErrorLevelEQ applies the EQ predicate on the "error_level" field.

func ErrorLevelIn

func ErrorLevelIn(vs ...ErrorLevel) predicate.SystemError

ErrorLevelIn applies the In predicate on the "error_level" field.

func ErrorLevelNEQ

func ErrorLevelNEQ(v ErrorLevel) predicate.SystemError

ErrorLevelNEQ applies the NEQ predicate on the "error_level" field.

func ErrorLevelNotIn

func ErrorLevelNotIn(vs ...ErrorLevel) predicate.SystemError

ErrorLevelNotIn applies the NotIn predicate on the "error_level" field.

func ErrorLevelValidator

func ErrorLevelValidator(el ErrorLevel) error

ErrorLevelValidator is a validator for the "error_level" field enum values. It is called by the builders before save.

func ErrorMsg

func ErrorMsg(v string) predicate.SystemError

ErrorMsg applies equality check predicate on the "error_msg" field. It's identical to ErrorMsgEQ.

func ErrorMsgContains

func ErrorMsgContains(v string) predicate.SystemError

ErrorMsgContains applies the Contains predicate on the "error_msg" field.

func ErrorMsgContainsFold

func ErrorMsgContainsFold(v string) predicate.SystemError

ErrorMsgContainsFold applies the ContainsFold predicate on the "error_msg" field.

func ErrorMsgEQ

func ErrorMsgEQ(v string) predicate.SystemError

ErrorMsgEQ applies the EQ predicate on the "error_msg" field.

func ErrorMsgEqualFold

func ErrorMsgEqualFold(v string) predicate.SystemError

ErrorMsgEqualFold applies the EqualFold predicate on the "error_msg" field.

func ErrorMsgGT

func ErrorMsgGT(v string) predicate.SystemError

ErrorMsgGT applies the GT predicate on the "error_msg" field.

func ErrorMsgGTE

func ErrorMsgGTE(v string) predicate.SystemError

ErrorMsgGTE applies the GTE predicate on the "error_msg" field.

func ErrorMsgHasPrefix

func ErrorMsgHasPrefix(v string) predicate.SystemError

ErrorMsgHasPrefix applies the HasPrefix predicate on the "error_msg" field.

func ErrorMsgHasSuffix

func ErrorMsgHasSuffix(v string) predicate.SystemError

ErrorMsgHasSuffix applies the HasSuffix predicate on the "error_msg" field.

func ErrorMsgIn

func ErrorMsgIn(vs ...string) predicate.SystemError

ErrorMsgIn applies the In predicate on the "error_msg" field.

func ErrorMsgLT

func ErrorMsgLT(v string) predicate.SystemError

ErrorMsgLT applies the LT predicate on the "error_msg" field.

func ErrorMsgLTE

func ErrorMsgLTE(v string) predicate.SystemError

ErrorMsgLTE applies the LTE predicate on the "error_msg" field.

func ErrorMsgNEQ

func ErrorMsgNEQ(v string) predicate.SystemError

ErrorMsgNEQ applies the NEQ predicate on the "error_msg" field.

func ErrorMsgNotIn

func ErrorMsgNotIn(vs ...string) predicate.SystemError

ErrorMsgNotIn applies the NotIn predicate on the "error_msg" field.

func ErrorStack

func ErrorStack(v string) predicate.SystemError

ErrorStack applies equality check predicate on the "error_stack" field. It's identical to ErrorStackEQ.

func ErrorStackContains

func ErrorStackContains(v string) predicate.SystemError

ErrorStackContains applies the Contains predicate on the "error_stack" field.

func ErrorStackContainsFold

func ErrorStackContainsFold(v string) predicate.SystemError

ErrorStackContainsFold applies the ContainsFold predicate on the "error_stack" field.

func ErrorStackEQ

func ErrorStackEQ(v string) predicate.SystemError

ErrorStackEQ applies the EQ predicate on the "error_stack" field.

func ErrorStackEqualFold

func ErrorStackEqualFold(v string) predicate.SystemError

ErrorStackEqualFold applies the EqualFold predicate on the "error_stack" field.

func ErrorStackGT

func ErrorStackGT(v string) predicate.SystemError

ErrorStackGT applies the GT predicate on the "error_stack" field.

func ErrorStackGTE

func ErrorStackGTE(v string) predicate.SystemError

ErrorStackGTE applies the GTE predicate on the "error_stack" field.

func ErrorStackHasPrefix

func ErrorStackHasPrefix(v string) predicate.SystemError

ErrorStackHasPrefix applies the HasPrefix predicate on the "error_stack" field.

func ErrorStackHasSuffix

func ErrorStackHasSuffix(v string) predicate.SystemError

ErrorStackHasSuffix applies the HasSuffix predicate on the "error_stack" field.

func ErrorStackIn

func ErrorStackIn(vs ...string) predicate.SystemError

ErrorStackIn applies the In predicate on the "error_stack" field.

func ErrorStackIsNil

func ErrorStackIsNil() predicate.SystemError

ErrorStackIsNil applies the IsNil predicate on the "error_stack" field.

func ErrorStackLT

func ErrorStackLT(v string) predicate.SystemError

ErrorStackLT applies the LT predicate on the "error_stack" field.

func ErrorStackLTE

func ErrorStackLTE(v string) predicate.SystemError

ErrorStackLTE applies the LTE predicate on the "error_stack" field.

func ErrorStackNEQ

func ErrorStackNEQ(v string) predicate.SystemError

ErrorStackNEQ applies the NEQ predicate on the "error_stack" field.

func ErrorStackNotIn

func ErrorStackNotIn(vs ...string) predicate.SystemError

ErrorStackNotIn applies the NotIn predicate on the "error_stack" field.

func ErrorStackNotNil

func ErrorStackNotNil() predicate.SystemError

ErrorStackNotNil applies the NotNil predicate on the "error_stack" field.

func ErrorType

func ErrorType(v string) predicate.SystemError

ErrorType applies equality check predicate on the "error_type" field. It's identical to ErrorTypeEQ.

func ErrorTypeContains

func ErrorTypeContains(v string) predicate.SystemError

ErrorTypeContains applies the Contains predicate on the "error_type" field.

func ErrorTypeContainsFold

func ErrorTypeContainsFold(v string) predicate.SystemError

ErrorTypeContainsFold applies the ContainsFold predicate on the "error_type" field.

func ErrorTypeEQ

func ErrorTypeEQ(v string) predicate.SystemError

ErrorTypeEQ applies the EQ predicate on the "error_type" field.

func ErrorTypeEqualFold

func ErrorTypeEqualFold(v string) predicate.SystemError

ErrorTypeEqualFold applies the EqualFold predicate on the "error_type" field.

func ErrorTypeGT

func ErrorTypeGT(v string) predicate.SystemError

ErrorTypeGT applies the GT predicate on the "error_type" field.

func ErrorTypeGTE

func ErrorTypeGTE(v string) predicate.SystemError

ErrorTypeGTE applies the GTE predicate on the "error_type" field.

func ErrorTypeHasPrefix

func ErrorTypeHasPrefix(v string) predicate.SystemError

ErrorTypeHasPrefix applies the HasPrefix predicate on the "error_type" field.

func ErrorTypeHasSuffix

func ErrorTypeHasSuffix(v string) predicate.SystemError

ErrorTypeHasSuffix applies the HasSuffix predicate on the "error_type" field.

func ErrorTypeIn

func ErrorTypeIn(vs ...string) predicate.SystemError

ErrorTypeIn applies the In predicate on the "error_type" field.

func ErrorTypeLT

func ErrorTypeLT(v string) predicate.SystemError

ErrorTypeLT applies the LT predicate on the "error_type" field.

func ErrorTypeLTE

func ErrorTypeLTE(v string) predicate.SystemError

ErrorTypeLTE applies the LTE predicate on the "error_type" field.

func ErrorTypeNEQ

func ErrorTypeNEQ(v string) predicate.SystemError

ErrorTypeNEQ applies the NEQ predicate on the "error_type" field.

func ErrorTypeNotIn

func ErrorTypeNotIn(vs ...string) predicate.SystemError

ErrorTypeNotIn applies the NotIn predicate on the "error_type" field.

func HasUser

func HasUser() predicate.SystemError

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.User) predicate.SystemError

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.SystemError

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.SystemError

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.SystemError

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.SystemError

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.SystemError

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.SystemError

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.SystemError

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.SystemError

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.SystemError) predicate.SystemError

Or groups predicates with the OR operator between them.

func OwnerDomainID

func OwnerDomainID(v uuid.UUID) predicate.SystemError

OwnerDomainID applies equality check predicate on the "owner_domain_id" field. It's identical to OwnerDomainIDEQ.

func OwnerDomainIDEQ

func OwnerDomainIDEQ(v uuid.UUID) predicate.SystemError

OwnerDomainIDEQ applies the EQ predicate on the "owner_domain_id" field.

func OwnerDomainIDGT

func OwnerDomainIDGT(v uuid.UUID) predicate.SystemError

OwnerDomainIDGT applies the GT predicate on the "owner_domain_id" field.

func OwnerDomainIDGTE

func OwnerDomainIDGTE(v uuid.UUID) predicate.SystemError

OwnerDomainIDGTE applies the GTE predicate on the "owner_domain_id" field.

func OwnerDomainIDIn

func OwnerDomainIDIn(vs ...uuid.UUID) predicate.SystemError

OwnerDomainIDIn applies the In predicate on the "owner_domain_id" field.

func OwnerDomainIDIsNil

func OwnerDomainIDIsNil() predicate.SystemError

OwnerDomainIDIsNil applies the IsNil predicate on the "owner_domain_id" field.

func OwnerDomainIDLT

func OwnerDomainIDLT(v uuid.UUID) predicate.SystemError

OwnerDomainIDLT applies the LT predicate on the "owner_domain_id" field.

func OwnerDomainIDLTE

func OwnerDomainIDLTE(v uuid.UUID) predicate.SystemError

OwnerDomainIDLTE applies the LTE predicate on the "owner_domain_id" field.

func OwnerDomainIDNEQ

func OwnerDomainIDNEQ(v uuid.UUID) predicate.SystemError

OwnerDomainIDNEQ applies the NEQ predicate on the "owner_domain_id" field.

func OwnerDomainIDNotIn

func OwnerDomainIDNotIn(vs ...uuid.UUID) predicate.SystemError

OwnerDomainIDNotIn applies the NotIn predicate on the "owner_domain_id" field.

func OwnerDomainIDNotNil

func OwnerDomainIDNotNil() predicate.SystemError

OwnerDomainIDNotNil applies the NotNil predicate on the "owner_domain_id" field.

func PublishedAt

func PublishedAt(v time.Time) predicate.SystemError

PublishedAt applies equality check predicate on the "published_at" field. It's identical to PublishedAtEQ.

func PublishedAtEQ

func PublishedAtEQ(v time.Time) predicate.SystemError

PublishedAtEQ applies the EQ predicate on the "published_at" field.

func PublishedAtGT

func PublishedAtGT(v time.Time) predicate.SystemError

PublishedAtGT applies the GT predicate on the "published_at" field.

func PublishedAtGTE

func PublishedAtGTE(v time.Time) predicate.SystemError

PublishedAtGTE applies the GTE predicate on the "published_at" field.

func PublishedAtIn

func PublishedAtIn(vs ...time.Time) predicate.SystemError

PublishedAtIn applies the In predicate on the "published_at" field.

func PublishedAtIsNil

func PublishedAtIsNil() predicate.SystemError

PublishedAtIsNil applies the IsNil predicate on the "published_at" field.

func PublishedAtLT

func PublishedAtLT(v time.Time) predicate.SystemError

PublishedAtLT applies the LT predicate on the "published_at" field.

func PublishedAtLTE

func PublishedAtLTE(v time.Time) predicate.SystemError

PublishedAtLTE applies the LTE predicate on the "published_at" field.

func PublishedAtNEQ

func PublishedAtNEQ(v time.Time) predicate.SystemError

PublishedAtNEQ applies the NEQ predicate on the "published_at" field.

func PublishedAtNotIn

func PublishedAtNotIn(vs ...time.Time) predicate.SystemError

PublishedAtNotIn applies the NotIn predicate on the "published_at" field.

func PublishedAtNotNil

func PublishedAtNotNil() predicate.SystemError

PublishedAtNotNil applies the NotNil predicate on the "published_at" field.

func RequestBody

func RequestBody(v string) predicate.SystemError

RequestBody applies equality check predicate on the "request_body" field. It's identical to RequestBodyEQ.

func RequestBodyContains

func RequestBodyContains(v string) predicate.SystemError

RequestBodyContains applies the Contains predicate on the "request_body" field.

func RequestBodyContainsFold

func RequestBodyContainsFold(v string) predicate.SystemError

RequestBodyContainsFold applies the ContainsFold predicate on the "request_body" field.

func RequestBodyEQ

func RequestBodyEQ(v string) predicate.SystemError

RequestBodyEQ applies the EQ predicate on the "request_body" field.

func RequestBodyEqualFold

func RequestBodyEqualFold(v string) predicate.SystemError

RequestBodyEqualFold applies the EqualFold predicate on the "request_body" field.

func RequestBodyGT

func RequestBodyGT(v string) predicate.SystemError

RequestBodyGT applies the GT predicate on the "request_body" field.

func RequestBodyGTE

func RequestBodyGTE(v string) predicate.SystemError

RequestBodyGTE applies the GTE predicate on the "request_body" field.

func RequestBodyHasPrefix

func RequestBodyHasPrefix(v string) predicate.SystemError

RequestBodyHasPrefix applies the HasPrefix predicate on the "request_body" field.

func RequestBodyHasSuffix

func RequestBodyHasSuffix(v string) predicate.SystemError

RequestBodyHasSuffix applies the HasSuffix predicate on the "request_body" field.

func RequestBodyIn

func RequestBodyIn(vs ...string) predicate.SystemError

RequestBodyIn applies the In predicate on the "request_body" field.

func RequestBodyIsNil

func RequestBodyIsNil() predicate.SystemError

RequestBodyIsNil applies the IsNil predicate on the "request_body" field.

func RequestBodyLT

func RequestBodyLT(v string) predicate.SystemError

RequestBodyLT applies the LT predicate on the "request_body" field.

func RequestBodyLTE

func RequestBodyLTE(v string) predicate.SystemError

RequestBodyLTE applies the LTE predicate on the "request_body" field.

func RequestBodyNEQ

func RequestBodyNEQ(v string) predicate.SystemError

RequestBodyNEQ applies the NEQ predicate on the "request_body" field.

func RequestBodyNotIn

func RequestBodyNotIn(vs ...string) predicate.SystemError

RequestBodyNotIn applies the NotIn predicate on the "request_body" field.

func RequestBodyNotNil

func RequestBodyNotNil() predicate.SystemError

RequestBodyNotNil applies the NotNil predicate on the "request_body" field.

func RequestID

func RequestID(v string) predicate.SystemError

RequestID applies equality check predicate on the "request_id" field. It's identical to RequestIDEQ.

func RequestIDContains

func RequestIDContains(v string) predicate.SystemError

RequestIDContains applies the Contains predicate on the "request_id" field.

func RequestIDContainsFold

func RequestIDContainsFold(v string) predicate.SystemError

RequestIDContainsFold applies the ContainsFold predicate on the "request_id" field.

func RequestIDEQ

func RequestIDEQ(v string) predicate.SystemError

RequestIDEQ applies the EQ predicate on the "request_id" field.

func RequestIDEqualFold

func RequestIDEqualFold(v string) predicate.SystemError

RequestIDEqualFold applies the EqualFold predicate on the "request_id" field.

func RequestIDGT

func RequestIDGT(v string) predicate.SystemError

RequestIDGT applies the GT predicate on the "request_id" field.

func RequestIDGTE

func RequestIDGTE(v string) predicate.SystemError

RequestIDGTE applies the GTE predicate on the "request_id" field.

func RequestIDHasPrefix

func RequestIDHasPrefix(v string) predicate.SystemError

RequestIDHasPrefix applies the HasPrefix predicate on the "request_id" field.

func RequestIDHasSuffix

func RequestIDHasSuffix(v string) predicate.SystemError

RequestIDHasSuffix applies the HasSuffix predicate on the "request_id" field.

func RequestIDIn

func RequestIDIn(vs ...string) predicate.SystemError

RequestIDIn applies the In predicate on the "request_id" field.

func RequestIDIsNil

func RequestIDIsNil() predicate.SystemError

RequestIDIsNil applies the IsNil predicate on the "request_id" field.

func RequestIDLT

func RequestIDLT(v string) predicate.SystemError

RequestIDLT applies the LT predicate on the "request_id" field.

func RequestIDLTE

func RequestIDLTE(v string) predicate.SystemError

RequestIDLTE applies the LTE predicate on the "request_id" field.

func RequestIDNEQ

func RequestIDNEQ(v string) predicate.SystemError

RequestIDNEQ applies the NEQ predicate on the "request_id" field.

func RequestIDNotIn

func RequestIDNotIn(vs ...string) predicate.SystemError

RequestIDNotIn applies the NotIn predicate on the "request_id" field.

func RequestIDNotNil

func RequestIDNotNil() predicate.SystemError

RequestIDNotNil applies the NotNil predicate on the "request_id" field.

func RequestMethod

func RequestMethod(v string) predicate.SystemError

RequestMethod applies equality check predicate on the "request_method" field. It's identical to RequestMethodEQ.

func RequestMethodContains

func RequestMethodContains(v string) predicate.SystemError

RequestMethodContains applies the Contains predicate on the "request_method" field.

func RequestMethodContainsFold

func RequestMethodContainsFold(v string) predicate.SystemError

RequestMethodContainsFold applies the ContainsFold predicate on the "request_method" field.

func RequestMethodEQ

func RequestMethodEQ(v string) predicate.SystemError

RequestMethodEQ applies the EQ predicate on the "request_method" field.

func RequestMethodEqualFold

func RequestMethodEqualFold(v string) predicate.SystemError

RequestMethodEqualFold applies the EqualFold predicate on the "request_method" field.

func RequestMethodGT

func RequestMethodGT(v string) predicate.SystemError

RequestMethodGT applies the GT predicate on the "request_method" field.

func RequestMethodGTE

func RequestMethodGTE(v string) predicate.SystemError

RequestMethodGTE applies the GTE predicate on the "request_method" field.

func RequestMethodHasPrefix

func RequestMethodHasPrefix(v string) predicate.SystemError

RequestMethodHasPrefix applies the HasPrefix predicate on the "request_method" field.

func RequestMethodHasSuffix

func RequestMethodHasSuffix(v string) predicate.SystemError

RequestMethodHasSuffix applies the HasSuffix predicate on the "request_method" field.

func RequestMethodIn

func RequestMethodIn(vs ...string) predicate.SystemError

RequestMethodIn applies the In predicate on the "request_method" field.

func RequestMethodIsNil

func RequestMethodIsNil() predicate.SystemError

RequestMethodIsNil applies the IsNil predicate on the "request_method" field.

func RequestMethodLT

func RequestMethodLT(v string) predicate.SystemError

RequestMethodLT applies the LT predicate on the "request_method" field.

func RequestMethodLTE

func RequestMethodLTE(v string) predicate.SystemError

RequestMethodLTE applies the LTE predicate on the "request_method" field.

func RequestMethodNEQ

func RequestMethodNEQ(v string) predicate.SystemError

RequestMethodNEQ applies the NEQ predicate on the "request_method" field.

func RequestMethodNotIn

func RequestMethodNotIn(vs ...string) predicate.SystemError

RequestMethodNotIn applies the NotIn predicate on the "request_method" field.

func RequestMethodNotNil

func RequestMethodNotNil() predicate.SystemError

RequestMethodNotNil applies the NotNil predicate on the "request_method" field.

func RequestPath

func RequestPath(v string) predicate.SystemError

RequestPath applies equality check predicate on the "request_path" field. It's identical to RequestPathEQ.

func RequestPathContains

func RequestPathContains(v string) predicate.SystemError

RequestPathContains applies the Contains predicate on the "request_path" field.

func RequestPathContainsFold

func RequestPathContainsFold(v string) predicate.SystemError

RequestPathContainsFold applies the ContainsFold predicate on the "request_path" field.

func RequestPathEQ

func RequestPathEQ(v string) predicate.SystemError

RequestPathEQ applies the EQ predicate on the "request_path" field.

func RequestPathEqualFold

func RequestPathEqualFold(v string) predicate.SystemError

RequestPathEqualFold applies the EqualFold predicate on the "request_path" field.

func RequestPathGT

func RequestPathGT(v string) predicate.SystemError

RequestPathGT applies the GT predicate on the "request_path" field.

func RequestPathGTE

func RequestPathGTE(v string) predicate.SystemError

RequestPathGTE applies the GTE predicate on the "request_path" field.

func RequestPathHasPrefix

func RequestPathHasPrefix(v string) predicate.SystemError

RequestPathHasPrefix applies the HasPrefix predicate on the "request_path" field.

func RequestPathHasSuffix

func RequestPathHasSuffix(v string) predicate.SystemError

RequestPathHasSuffix applies the HasSuffix predicate on the "request_path" field.

func RequestPathIn

func RequestPathIn(vs ...string) predicate.SystemError

RequestPathIn applies the In predicate on the "request_path" field.

func RequestPathIsNil

func RequestPathIsNil() predicate.SystemError

RequestPathIsNil applies the IsNil predicate on the "request_path" field.

func RequestPathLT

func RequestPathLT(v string) predicate.SystemError

RequestPathLT applies the LT predicate on the "request_path" field.

func RequestPathLTE

func RequestPathLTE(v string) predicate.SystemError

RequestPathLTE applies the LTE predicate on the "request_path" field.

func RequestPathNEQ

func RequestPathNEQ(v string) predicate.SystemError

RequestPathNEQ applies the NEQ predicate on the "request_path" field.

func RequestPathNotIn

func RequestPathNotIn(vs ...string) predicate.SystemError

RequestPathNotIn applies the NotIn predicate on the "request_path" field.

func RequestPathNotNil

func RequestPathNotNil() predicate.SystemError

RequestPathNotNil applies the NotNil predicate on the "request_path" field.

func ResponseBody

func ResponseBody(v string) predicate.SystemError

ResponseBody applies equality check predicate on the "response_body" field. It's identical to ResponseBodyEQ.

func ResponseBodyContains

func ResponseBodyContains(v string) predicate.SystemError

ResponseBodyContains applies the Contains predicate on the "response_body" field.

func ResponseBodyContainsFold

func ResponseBodyContainsFold(v string) predicate.SystemError

ResponseBodyContainsFold applies the ContainsFold predicate on the "response_body" field.

func ResponseBodyEQ

func ResponseBodyEQ(v string) predicate.SystemError

ResponseBodyEQ applies the EQ predicate on the "response_body" field.

func ResponseBodyEqualFold

func ResponseBodyEqualFold(v string) predicate.SystemError

ResponseBodyEqualFold applies the EqualFold predicate on the "response_body" field.

func ResponseBodyGT

func ResponseBodyGT(v string) predicate.SystemError

ResponseBodyGT applies the GT predicate on the "response_body" field.

func ResponseBodyGTE

func ResponseBodyGTE(v string) predicate.SystemError

ResponseBodyGTE applies the GTE predicate on the "response_body" field.

func ResponseBodyHasPrefix

func ResponseBodyHasPrefix(v string) predicate.SystemError

ResponseBodyHasPrefix applies the HasPrefix predicate on the "response_body" field.

func ResponseBodyHasSuffix

func ResponseBodyHasSuffix(v string) predicate.SystemError

ResponseBodyHasSuffix applies the HasSuffix predicate on the "response_body" field.

func ResponseBodyIn

func ResponseBodyIn(vs ...string) predicate.SystemError

ResponseBodyIn applies the In predicate on the "response_body" field.

func ResponseBodyIsNil

func ResponseBodyIsNil() predicate.SystemError

ResponseBodyIsNil applies the IsNil predicate on the "response_body" field.

func ResponseBodyLT

func ResponseBodyLT(v string) predicate.SystemError

ResponseBodyLT applies the LT predicate on the "response_body" field.

func ResponseBodyLTE

func ResponseBodyLTE(v string) predicate.SystemError

ResponseBodyLTE applies the LTE predicate on the "response_body" field.

func ResponseBodyNEQ

func ResponseBodyNEQ(v string) predicate.SystemError

ResponseBodyNEQ applies the NEQ predicate on the "response_body" field.

func ResponseBodyNotIn

func ResponseBodyNotIn(vs ...string) predicate.SystemError

ResponseBodyNotIn applies the NotIn predicate on the "response_body" field.

func ResponseBodyNotNil

func ResponseBodyNotNil() predicate.SystemError

ResponseBodyNotNil applies the NotNil predicate on the "response_body" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.SystemError

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.SystemError

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.SystemError

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.SystemError

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.SystemError

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.SystemError

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.SystemError

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.SystemError

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.SystemError

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.SystemError

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.SystemError

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedByID

func UpdatedByID(v uuid.UUID) predicate.SystemError

UpdatedByID applies equality check predicate on the "updated_by_id" field. It's identical to UpdatedByIDEQ.

func UpdatedByIDEQ

func UpdatedByIDEQ(v uuid.UUID) predicate.SystemError

UpdatedByIDEQ applies the EQ predicate on the "updated_by_id" field.

func UpdatedByIDGT

func UpdatedByIDGT(v uuid.UUID) predicate.SystemError

UpdatedByIDGT applies the GT predicate on the "updated_by_id" field.

func UpdatedByIDGTE

func UpdatedByIDGTE(v uuid.UUID) predicate.SystemError

UpdatedByIDGTE applies the GTE predicate on the "updated_by_id" field.

func UpdatedByIDIn

func UpdatedByIDIn(vs ...uuid.UUID) predicate.SystemError

UpdatedByIDIn applies the In predicate on the "updated_by_id" field.

func UpdatedByIDIsNil

func UpdatedByIDIsNil() predicate.SystemError

UpdatedByIDIsNil applies the IsNil predicate on the "updated_by_id" field.

func UpdatedByIDLT

func UpdatedByIDLT(v uuid.UUID) predicate.SystemError

UpdatedByIDLT applies the LT predicate on the "updated_by_id" field.

func UpdatedByIDLTE

func UpdatedByIDLTE(v uuid.UUID) predicate.SystemError

UpdatedByIDLTE applies the LTE predicate on the "updated_by_id" field.

func UpdatedByIDNEQ

func UpdatedByIDNEQ(v uuid.UUID) predicate.SystemError

UpdatedByIDNEQ applies the NEQ predicate on the "updated_by_id" field.

func UpdatedByIDNotIn

func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.SystemError

UpdatedByIDNotIn applies the NotIn predicate on the "updated_by_id" field.

func UpdatedByIDNotNil

func UpdatedByIDNotNil() predicate.SystemError

UpdatedByIDNotNil applies the NotNil predicate on the "updated_by_id" field.

func UserID

func UserID(v uuid.UUID) predicate.SystemError

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDEQ

func UserIDEQ(v uuid.UUID) predicate.SystemError

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...uuid.UUID) predicate.SystemError

UserIDIn applies the In predicate on the "user_id" field.

func UserIDIsNil

func UserIDIsNil() predicate.SystemError

UserIDIsNil applies the IsNil predicate on the "user_id" field.

func UserIDNEQ

func UserIDNEQ(v uuid.UUID) predicate.SystemError

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...uuid.UUID) predicate.SystemError

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func UserIDNotNil

func UserIDNotNil() predicate.SystemError

UserIDNotNil applies the NotNil predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type ErrorLevel

type ErrorLevel string

ErrorLevel defines the type for the "error_level" enum field.

const (
	ErrorLevelInfo     ErrorLevel = "info"
	ErrorLevelWarning  ErrorLevel = "warning"
	ErrorLevelError    ErrorLevel = "error"
	ErrorLevelCritical ErrorLevel = "critical"
)

ErrorLevel values.

func (ErrorLevel) String

func (el ErrorLevel) String() string

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the SystemError queries.

func ByArchivedAt

func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption

ByArchivedAt orders the results by the archived_at field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedByID

func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption

ByCreatedByID orders the results by the created_by_id field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedByID

func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption

ByDeletedByID orders the results by the deleted_by_id field.

func ByErrorCode

func ByErrorCode(opts ...sql.OrderTermOption) OrderOption

ByErrorCode orders the results by the error_code field.

func ByErrorLevel

func ByErrorLevel(opts ...sql.OrderTermOption) OrderOption

ByErrorLevel orders the results by the error_level field.

func ByErrorMsg

func ByErrorMsg(opts ...sql.OrderTermOption) OrderOption

ByErrorMsg orders the results by the error_msg field.

func ByErrorStack

func ByErrorStack(opts ...sql.OrderTermOption) OrderOption

ByErrorStack orders the results by the error_stack field.

func ByErrorType

func ByErrorType(opts ...sql.OrderTermOption) OrderOption

ByErrorType orders the results by the error_type field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByOwnerDomainID

func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption

ByOwnerDomainID orders the results by the owner_domain_id field.

func ByPublishedAt

func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption

ByPublishedAt orders the results by the published_at field.

func ByRequestBody

func ByRequestBody(opts ...sql.OrderTermOption) OrderOption

ByRequestBody orders the results by the request_body field.

func ByRequestID

func ByRequestID(opts ...sql.OrderTermOption) OrderOption

ByRequestID orders the results by the request_id field.

func ByRequestMethod

func ByRequestMethod(opts ...sql.OrderTermOption) OrderOption

ByRequestMethod orders the results by the request_method field.

func ByRequestPath

func ByRequestPath(opts ...sql.OrderTermOption) OrderOption

ByRequestPath orders the results by the request_path field.

func ByResponseBody

func ByResponseBody(opts ...sql.OrderTermOption) OrderOption

ByResponseBody orders the results by the response_body field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedByID

func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption

ByUpdatedByID orders the results by the updated_by_id field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

Jump to