Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Dictionary) predicate.Dictionary
- func ArchivedAt(v time.Time) predicate.Dictionary
- func ArchivedAtEQ(v time.Time) predicate.Dictionary
- func ArchivedAtGT(v time.Time) predicate.Dictionary
- func ArchivedAtGTE(v time.Time) predicate.Dictionary
- func ArchivedAtIn(vs ...time.Time) predicate.Dictionary
- func ArchivedAtIsNil() predicate.Dictionary
- func ArchivedAtLT(v time.Time) predicate.Dictionary
- func ArchivedAtLTE(v time.Time) predicate.Dictionary
- func ArchivedAtNEQ(v time.Time) predicate.Dictionary
- func ArchivedAtNotIn(vs ...time.Time) predicate.Dictionary
- func ArchivedAtNotNil() predicate.Dictionary
- func Code(v string) predicate.Dictionary
- func CodeContains(v string) predicate.Dictionary
- func CodeContainsFold(v string) predicate.Dictionary
- func CodeEQ(v string) predicate.Dictionary
- func CodeEqualFold(v string) predicate.Dictionary
- func CodeGT(v string) predicate.Dictionary
- func CodeGTE(v string) predicate.Dictionary
- func CodeHasPrefix(v string) predicate.Dictionary
- func CodeHasSuffix(v string) predicate.Dictionary
- func CodeIn(vs ...string) predicate.Dictionary
- func CodeLT(v string) predicate.Dictionary
- func CodeLTE(v string) predicate.Dictionary
- func CodeNEQ(v string) predicate.Dictionary
- func CodeNotIn(vs ...string) predicate.Dictionary
- func CreatedAt(v time.Time) predicate.Dictionary
- func CreatedAtEQ(v time.Time) predicate.Dictionary
- func CreatedAtGT(v time.Time) predicate.Dictionary
- func CreatedAtGTE(v time.Time) predicate.Dictionary
- func CreatedAtIn(vs ...time.Time) predicate.Dictionary
- func CreatedAtIsNil() predicate.Dictionary
- func CreatedAtLT(v time.Time) predicate.Dictionary
- func CreatedAtLTE(v time.Time) predicate.Dictionary
- func CreatedAtNEQ(v time.Time) predicate.Dictionary
- func CreatedAtNotIn(vs ...time.Time) predicate.Dictionary
- func CreatedAtNotNil() predicate.Dictionary
- func CreatedByID(v uuid.UUID) predicate.Dictionary
- func CreatedByIDEQ(v uuid.UUID) predicate.Dictionary
- func CreatedByIDGT(v uuid.UUID) predicate.Dictionary
- func CreatedByIDGTE(v uuid.UUID) predicate.Dictionary
- func CreatedByIDIn(vs ...uuid.UUID) predicate.Dictionary
- func CreatedByIDIsNil() predicate.Dictionary
- func CreatedByIDLT(v uuid.UUID) predicate.Dictionary
- func CreatedByIDLTE(v uuid.UUID) predicate.Dictionary
- func CreatedByIDNEQ(v uuid.UUID) predicate.Dictionary
- func CreatedByIDNotIn(vs ...uuid.UUID) predicate.Dictionary
- func CreatedByIDNotNil() predicate.Dictionary
- func DeletedAt(v time.Time) predicate.Dictionary
- func DeletedAtEQ(v time.Time) predicate.Dictionary
- func DeletedAtGT(v time.Time) predicate.Dictionary
- func DeletedAtGTE(v time.Time) predicate.Dictionary
- func DeletedAtIn(vs ...time.Time) predicate.Dictionary
- func DeletedAtIsNil() predicate.Dictionary
- func DeletedAtLT(v time.Time) predicate.Dictionary
- func DeletedAtLTE(v time.Time) predicate.Dictionary
- func DeletedAtNEQ(v time.Time) predicate.Dictionary
- func DeletedAtNotIn(vs ...time.Time) predicate.Dictionary
- func DeletedAtNotNil() predicate.Dictionary
- func DeletedByID(v uuid.UUID) predicate.Dictionary
- func DeletedByIDEQ(v uuid.UUID) predicate.Dictionary
- func DeletedByIDGT(v uuid.UUID) predicate.Dictionary
- func DeletedByIDGTE(v uuid.UUID) predicate.Dictionary
- func DeletedByIDIn(vs ...uuid.UUID) predicate.Dictionary
- func DeletedByIDIsNil() predicate.Dictionary
- func DeletedByIDLT(v uuid.UUID) predicate.Dictionary
- func DeletedByIDLTE(v uuid.UUID) predicate.Dictionary
- func DeletedByIDNEQ(v uuid.UUID) predicate.Dictionary
- func DeletedByIDNotIn(vs ...uuid.UUID) predicate.Dictionary
- func DeletedByIDNotNil() predicate.Dictionary
- func Description(v string) predicate.Dictionary
- func DescriptionContains(v string) predicate.Dictionary
- func DescriptionContainsFold(v string) predicate.Dictionary
- func DescriptionEQ(v string) predicate.Dictionary
- func DescriptionEqualFold(v string) predicate.Dictionary
- func DescriptionGT(v string) predicate.Dictionary
- func DescriptionGTE(v string) predicate.Dictionary
- func DescriptionHasPrefix(v string) predicate.Dictionary
- func DescriptionHasSuffix(v string) predicate.Dictionary
- func DescriptionIn(vs ...string) predicate.Dictionary
- func DescriptionIsNil() predicate.Dictionary
- func DescriptionLT(v string) predicate.Dictionary
- func DescriptionLTE(v string) predicate.Dictionary
- func DescriptionNEQ(v string) predicate.Dictionary
- func DescriptionNotIn(vs ...string) predicate.Dictionary
- func DescriptionNotNil() predicate.Dictionary
- func HasItems() predicate.Dictionary
- func HasItemsWith(preds ...predicate.DictionaryDetail) predicate.Dictionary
- func ID(id uuid.UUID) predicate.Dictionary
- func IDEQ(id uuid.UUID) predicate.Dictionary
- func IDGT(id uuid.UUID) predicate.Dictionary
- func IDGTE(id uuid.UUID) predicate.Dictionary
- func IDIn(ids ...uuid.UUID) predicate.Dictionary
- func IDLT(id uuid.UUID) predicate.Dictionary
- func IDLTE(id uuid.UUID) predicate.Dictionary
- func IDNEQ(id uuid.UUID) predicate.Dictionary
- func IDNotIn(ids ...uuid.UUID) predicate.Dictionary
- func Name(v string) predicate.Dictionary
- func NameContains(v string) predicate.Dictionary
- func NameContainsFold(v string) predicate.Dictionary
- func NameEQ(v string) predicate.Dictionary
- func NameEqualFold(v string) predicate.Dictionary
- func NameGT(v string) predicate.Dictionary
- func NameGTE(v string) predicate.Dictionary
- func NameHasPrefix(v string) predicate.Dictionary
- func NameHasSuffix(v string) predicate.Dictionary
- func NameIn(vs ...string) predicate.Dictionary
- func NameLT(v string) predicate.Dictionary
- func NameLTE(v string) predicate.Dictionary
- func NameNEQ(v string) predicate.Dictionary
- func NameNotIn(vs ...string) predicate.Dictionary
- func Not(p predicate.Dictionary) predicate.Dictionary
- func Or(predicates ...predicate.Dictionary) predicate.Dictionary
- func OwnerDomainID(v uuid.UUID) predicate.Dictionary
- func OwnerDomainIDEQ(v uuid.UUID) predicate.Dictionary
- func OwnerDomainIDGT(v uuid.UUID) predicate.Dictionary
- func OwnerDomainIDGTE(v uuid.UUID) predicate.Dictionary
- func OwnerDomainIDIn(vs ...uuid.UUID) predicate.Dictionary
- func OwnerDomainIDIsNil() predicate.Dictionary
- func OwnerDomainIDLT(v uuid.UUID) predicate.Dictionary
- func OwnerDomainIDLTE(v uuid.UUID) predicate.Dictionary
- func OwnerDomainIDNEQ(v uuid.UUID) predicate.Dictionary
- func OwnerDomainIDNotIn(vs ...uuid.UUID) predicate.Dictionary
- func OwnerDomainIDNotNil() predicate.Dictionary
- func PublishedAt(v time.Time) predicate.Dictionary
- func PublishedAtEQ(v time.Time) predicate.Dictionary
- func PublishedAtGT(v time.Time) predicate.Dictionary
- func PublishedAtGTE(v time.Time) predicate.Dictionary
- func PublishedAtIn(vs ...time.Time) predicate.Dictionary
- func PublishedAtIsNil() predicate.Dictionary
- func PublishedAtLT(v time.Time) predicate.Dictionary
- func PublishedAtLTE(v time.Time) predicate.Dictionary
- func PublishedAtNEQ(v time.Time) predicate.Dictionary
- func PublishedAtNotIn(vs ...time.Time) predicate.Dictionary
- func PublishedAtNotNil() predicate.Dictionary
- func Status(v bool) predicate.Dictionary
- func StatusEQ(v bool) predicate.Dictionary
- func StatusNEQ(v bool) predicate.Dictionary
- func UpdatedAt(v time.Time) predicate.Dictionary
- func UpdatedAtEQ(v time.Time) predicate.Dictionary
- func UpdatedAtGT(v time.Time) predicate.Dictionary
- func UpdatedAtGTE(v time.Time) predicate.Dictionary
- func UpdatedAtIn(vs ...time.Time) predicate.Dictionary
- func UpdatedAtIsNil() predicate.Dictionary
- func UpdatedAtLT(v time.Time) predicate.Dictionary
- func UpdatedAtLTE(v time.Time) predicate.Dictionary
- func UpdatedAtNEQ(v time.Time) predicate.Dictionary
- func UpdatedAtNotIn(vs ...time.Time) predicate.Dictionary
- func UpdatedAtNotNil() predicate.Dictionary
- func UpdatedByID(v uuid.UUID) predicate.Dictionary
- func UpdatedByIDEQ(v uuid.UUID) predicate.Dictionary
- func UpdatedByIDGT(v uuid.UUID) predicate.Dictionary
- func UpdatedByIDGTE(v uuid.UUID) predicate.Dictionary
- func UpdatedByIDIn(vs ...uuid.UUID) predicate.Dictionary
- func UpdatedByIDIsNil() predicate.Dictionary
- func UpdatedByIDLT(v uuid.UUID) predicate.Dictionary
- func UpdatedByIDLTE(v uuid.UUID) predicate.Dictionary
- func UpdatedByIDNEQ(v uuid.UUID) predicate.Dictionary
- func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.Dictionary
- func UpdatedByIDNotNil() predicate.Dictionary
- func ValidColumn(column string) bool
- type OrderOption
- func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCode(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
- func ByDescription(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByItems(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByItemsCount(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption
- func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the dictionary type in the database. Label = "dictionary" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedByID holds the string denoting the created_by_id field in the database. FieldCreatedByID = "created_by_id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedByID holds the string denoting the updated_by_id field in the database. FieldUpdatedByID = "updated_by_id" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedByID holds the string denoting the deleted_by_id field in the database. FieldDeletedByID = "deleted_by_id" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldPublishedAt holds the string denoting the published_at field in the database. FieldPublishedAt = "published_at" // FieldArchivedAt holds the string denoting the archived_at field in the database. FieldArchivedAt = "archived_at" // FieldOwnerDomainID holds the string denoting the owner_domain_id field in the database. FieldOwnerDomainID = "owner_domain_id" // FieldCode holds the string denoting the code field in the database. FieldCode = "code" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldDescription holds the string denoting the description field in the database. FieldDescription = "description" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // EdgeItems holds the string denoting the items edge name in mutations. EdgeItems = "items" // Table holds the table name of the dictionary in the database. Table = "dictionaries" // ItemsTable is the table that holds the items relation/edge. ItemsTable = "dictionary_details" // ItemsInverseTable is the table name for the DictionaryDetail entity. // It exists in this package in order to avoid circular dependency with the "dictionarydetail" package. ItemsInverseTable = "dictionary_details" // ItemsColumn is the table column denoting the items relation/edge. ItemsColumn = "dictionary_id" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // CodeValidator is a validator for the "code" field. It is called by the builders before save. CodeValidator func(string) error // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // DefaultStatus holds the default value on creation for the "status" field. DefaultStatus bool // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldCreatedByID, FieldCreatedAt, FieldUpdatedByID, FieldUpdatedAt, FieldDeletedByID, FieldDeletedAt, FieldPublishedAt, FieldArchivedAt, FieldOwnerDomainID, FieldCode, FieldName, FieldDescription, FieldStatus, }
Columns holds all SQL columns for dictionary fields.
Functions ¶
func And ¶
func And(predicates ...predicate.Dictionary) predicate.Dictionary
And groups predicates with the AND operator between them.
func ArchivedAt ¶
func ArchivedAt(v time.Time) predicate.Dictionary
ArchivedAt applies equality check predicate on the "archived_at" field. It's identical to ArchivedAtEQ.
func ArchivedAtEQ ¶
func ArchivedAtEQ(v time.Time) predicate.Dictionary
ArchivedAtEQ applies the EQ predicate on the "archived_at" field.
func ArchivedAtGT ¶
func ArchivedAtGT(v time.Time) predicate.Dictionary
ArchivedAtGT applies the GT predicate on the "archived_at" field.
func ArchivedAtGTE ¶
func ArchivedAtGTE(v time.Time) predicate.Dictionary
ArchivedAtGTE applies the GTE predicate on the "archived_at" field.
func ArchivedAtIn ¶
func ArchivedAtIn(vs ...time.Time) predicate.Dictionary
ArchivedAtIn applies the In predicate on the "archived_at" field.
func ArchivedAtIsNil ¶
func ArchivedAtIsNil() predicate.Dictionary
ArchivedAtIsNil applies the IsNil predicate on the "archived_at" field.
func ArchivedAtLT ¶
func ArchivedAtLT(v time.Time) predicate.Dictionary
ArchivedAtLT applies the LT predicate on the "archived_at" field.
func ArchivedAtLTE ¶
func ArchivedAtLTE(v time.Time) predicate.Dictionary
ArchivedAtLTE applies the LTE predicate on the "archived_at" field.
func ArchivedAtNEQ ¶
func ArchivedAtNEQ(v time.Time) predicate.Dictionary
ArchivedAtNEQ applies the NEQ predicate on the "archived_at" field.
func ArchivedAtNotIn ¶
func ArchivedAtNotIn(vs ...time.Time) predicate.Dictionary
ArchivedAtNotIn applies the NotIn predicate on the "archived_at" field.
func ArchivedAtNotNil ¶
func ArchivedAtNotNil() predicate.Dictionary
ArchivedAtNotNil applies the NotNil predicate on the "archived_at" field.
func Code ¶
func Code(v string) predicate.Dictionary
Code applies equality check predicate on the "code" field. It's identical to CodeEQ.
func CodeContains ¶
func CodeContains(v string) predicate.Dictionary
CodeContains applies the Contains predicate on the "code" field.
func CodeContainsFold ¶
func CodeContainsFold(v string) predicate.Dictionary
CodeContainsFold applies the ContainsFold predicate on the "code" field.
func CodeEQ ¶
func CodeEQ(v string) predicate.Dictionary
CodeEQ applies the EQ predicate on the "code" field.
func CodeEqualFold ¶
func CodeEqualFold(v string) predicate.Dictionary
CodeEqualFold applies the EqualFold predicate on the "code" field.
func CodeGT ¶
func CodeGT(v string) predicate.Dictionary
CodeGT applies the GT predicate on the "code" field.
func CodeGTE ¶
func CodeGTE(v string) predicate.Dictionary
CodeGTE applies the GTE predicate on the "code" field.
func CodeHasPrefix ¶
func CodeHasPrefix(v string) predicate.Dictionary
CodeHasPrefix applies the HasPrefix predicate on the "code" field.
func CodeHasSuffix ¶
func CodeHasSuffix(v string) predicate.Dictionary
CodeHasSuffix applies the HasSuffix predicate on the "code" field.
func CodeIn ¶
func CodeIn(vs ...string) predicate.Dictionary
CodeIn applies the In predicate on the "code" field.
func CodeLT ¶
func CodeLT(v string) predicate.Dictionary
CodeLT applies the LT predicate on the "code" field.
func CodeLTE ¶
func CodeLTE(v string) predicate.Dictionary
CodeLTE applies the LTE predicate on the "code" field.
func CodeNEQ ¶
func CodeNEQ(v string) predicate.Dictionary
CodeNEQ applies the NEQ predicate on the "code" field.
func CodeNotIn ¶
func CodeNotIn(vs ...string) predicate.Dictionary
CodeNotIn applies the NotIn predicate on the "code" field.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.Dictionary
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.Dictionary
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.Dictionary
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.Dictionary
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.Dictionary
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
func CreatedAtIsNil() predicate.Dictionary
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.Dictionary
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.Dictionary
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.Dictionary
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.Dictionary
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
func CreatedAtNotNil() predicate.Dictionary
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedByID ¶
func CreatedByID(v uuid.UUID) predicate.Dictionary
CreatedByID applies equality check predicate on the "created_by_id" field. It's identical to CreatedByIDEQ.
func CreatedByIDEQ ¶
func CreatedByIDEQ(v uuid.UUID) predicate.Dictionary
CreatedByIDEQ applies the EQ predicate on the "created_by_id" field.
func CreatedByIDGT ¶
func CreatedByIDGT(v uuid.UUID) predicate.Dictionary
CreatedByIDGT applies the GT predicate on the "created_by_id" field.
func CreatedByIDGTE ¶
func CreatedByIDGTE(v uuid.UUID) predicate.Dictionary
CreatedByIDGTE applies the GTE predicate on the "created_by_id" field.
func CreatedByIDIn ¶
func CreatedByIDIn(vs ...uuid.UUID) predicate.Dictionary
CreatedByIDIn applies the In predicate on the "created_by_id" field.
func CreatedByIDIsNil ¶
func CreatedByIDIsNil() predicate.Dictionary
CreatedByIDIsNil applies the IsNil predicate on the "created_by_id" field.
func CreatedByIDLT ¶
func CreatedByIDLT(v uuid.UUID) predicate.Dictionary
CreatedByIDLT applies the LT predicate on the "created_by_id" field.
func CreatedByIDLTE ¶
func CreatedByIDLTE(v uuid.UUID) predicate.Dictionary
CreatedByIDLTE applies the LTE predicate on the "created_by_id" field.
func CreatedByIDNEQ ¶
func CreatedByIDNEQ(v uuid.UUID) predicate.Dictionary
CreatedByIDNEQ applies the NEQ predicate on the "created_by_id" field.
func CreatedByIDNotIn ¶
func CreatedByIDNotIn(vs ...uuid.UUID) predicate.Dictionary
CreatedByIDNotIn applies the NotIn predicate on the "created_by_id" field.
func CreatedByIDNotNil ¶
func CreatedByIDNotNil() predicate.Dictionary
CreatedByIDNotNil applies the NotNil predicate on the "created_by_id" field.
func DeletedAt ¶
func DeletedAt(v time.Time) predicate.Dictionary
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
func DeletedAtEQ(v time.Time) predicate.Dictionary
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
func DeletedAtGT(v time.Time) predicate.Dictionary
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
func DeletedAtGTE(v time.Time) predicate.Dictionary
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
func DeletedAtIn(vs ...time.Time) predicate.Dictionary
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
func DeletedAtIsNil() predicate.Dictionary
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
func DeletedAtLT(v time.Time) predicate.Dictionary
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
func DeletedAtLTE(v time.Time) predicate.Dictionary
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
func DeletedAtNEQ(v time.Time) predicate.Dictionary
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
func DeletedAtNotIn(vs ...time.Time) predicate.Dictionary
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
func DeletedAtNotNil() predicate.Dictionary
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedByID ¶
func DeletedByID(v uuid.UUID) predicate.Dictionary
DeletedByID applies equality check predicate on the "deleted_by_id" field. It's identical to DeletedByIDEQ.
func DeletedByIDEQ ¶
func DeletedByIDEQ(v uuid.UUID) predicate.Dictionary
DeletedByIDEQ applies the EQ predicate on the "deleted_by_id" field.
func DeletedByIDGT ¶
func DeletedByIDGT(v uuid.UUID) predicate.Dictionary
DeletedByIDGT applies the GT predicate on the "deleted_by_id" field.
func DeletedByIDGTE ¶
func DeletedByIDGTE(v uuid.UUID) predicate.Dictionary
DeletedByIDGTE applies the GTE predicate on the "deleted_by_id" field.
func DeletedByIDIn ¶
func DeletedByIDIn(vs ...uuid.UUID) predicate.Dictionary
DeletedByIDIn applies the In predicate on the "deleted_by_id" field.
func DeletedByIDIsNil ¶
func DeletedByIDIsNil() predicate.Dictionary
DeletedByIDIsNil applies the IsNil predicate on the "deleted_by_id" field.
func DeletedByIDLT ¶
func DeletedByIDLT(v uuid.UUID) predicate.Dictionary
DeletedByIDLT applies the LT predicate on the "deleted_by_id" field.
func DeletedByIDLTE ¶
func DeletedByIDLTE(v uuid.UUID) predicate.Dictionary
DeletedByIDLTE applies the LTE predicate on the "deleted_by_id" field.
func DeletedByIDNEQ ¶
func DeletedByIDNEQ(v uuid.UUID) predicate.Dictionary
DeletedByIDNEQ applies the NEQ predicate on the "deleted_by_id" field.
func DeletedByIDNotIn ¶
func DeletedByIDNotIn(vs ...uuid.UUID) predicate.Dictionary
DeletedByIDNotIn applies the NotIn predicate on the "deleted_by_id" field.
func DeletedByIDNotNil ¶
func DeletedByIDNotNil() predicate.Dictionary
DeletedByIDNotNil applies the NotNil predicate on the "deleted_by_id" field.
func Description ¶
func Description(v string) predicate.Dictionary
Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.
func DescriptionContains ¶
func DescriptionContains(v string) predicate.Dictionary
DescriptionContains applies the Contains predicate on the "description" field.
func DescriptionContainsFold ¶
func DescriptionContainsFold(v string) predicate.Dictionary
DescriptionContainsFold applies the ContainsFold predicate on the "description" field.
func DescriptionEQ ¶
func DescriptionEQ(v string) predicate.Dictionary
DescriptionEQ applies the EQ predicate on the "description" field.
func DescriptionEqualFold ¶
func DescriptionEqualFold(v string) predicate.Dictionary
DescriptionEqualFold applies the EqualFold predicate on the "description" field.
func DescriptionGT ¶
func DescriptionGT(v string) predicate.Dictionary
DescriptionGT applies the GT predicate on the "description" field.
func DescriptionGTE ¶
func DescriptionGTE(v string) predicate.Dictionary
DescriptionGTE applies the GTE predicate on the "description" field.
func DescriptionHasPrefix ¶
func DescriptionHasPrefix(v string) predicate.Dictionary
DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.
func DescriptionHasSuffix ¶
func DescriptionHasSuffix(v string) predicate.Dictionary
DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.
func DescriptionIn ¶
func DescriptionIn(vs ...string) predicate.Dictionary
DescriptionIn applies the In predicate on the "description" field.
func DescriptionIsNil ¶
func DescriptionIsNil() predicate.Dictionary
DescriptionIsNil applies the IsNil predicate on the "description" field.
func DescriptionLT ¶
func DescriptionLT(v string) predicate.Dictionary
DescriptionLT applies the LT predicate on the "description" field.
func DescriptionLTE ¶
func DescriptionLTE(v string) predicate.Dictionary
DescriptionLTE applies the LTE predicate on the "description" field.
func DescriptionNEQ ¶
func DescriptionNEQ(v string) predicate.Dictionary
DescriptionNEQ applies the NEQ predicate on the "description" field.
func DescriptionNotIn ¶
func DescriptionNotIn(vs ...string) predicate.Dictionary
DescriptionNotIn applies the NotIn predicate on the "description" field.
func DescriptionNotNil ¶
func DescriptionNotNil() predicate.Dictionary
DescriptionNotNil applies the NotNil predicate on the "description" field.
func HasItems ¶
func HasItems() predicate.Dictionary
HasItems applies the HasEdge predicate on the "items" edge.
func HasItemsWith ¶
func HasItemsWith(preds ...predicate.DictionaryDetail) predicate.Dictionary
HasItemsWith applies the HasEdge predicate on the "items" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.Dictionary
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.Dictionary
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.Dictionary
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.Dictionary
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.Dictionary
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.Dictionary
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.Dictionary
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.Dictionary
IDNotIn applies the NotIn predicate on the ID field.
func Name ¶
func Name(v string) predicate.Dictionary
Name applies equality check predicate on the "name" field. It's identical to NameEQ.
func NameContains ¶
func NameContains(v string) predicate.Dictionary
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
func NameContainsFold(v string) predicate.Dictionary
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEQ ¶
func NameEQ(v string) predicate.Dictionary
NameEQ applies the EQ predicate on the "name" field.
func NameEqualFold ¶
func NameEqualFold(v string) predicate.Dictionary
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameGT ¶
func NameGT(v string) predicate.Dictionary
NameGT applies the GT predicate on the "name" field.
func NameGTE ¶
func NameGTE(v string) predicate.Dictionary
NameGTE applies the GTE predicate on the "name" field.
func NameHasPrefix ¶
func NameHasPrefix(v string) predicate.Dictionary
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
func NameHasSuffix(v string) predicate.Dictionary
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameIn ¶
func NameIn(vs ...string) predicate.Dictionary
NameIn applies the In predicate on the "name" field.
func NameLT ¶
func NameLT(v string) predicate.Dictionary
NameLT applies the LT predicate on the "name" field.
func NameLTE ¶
func NameLTE(v string) predicate.Dictionary
NameLTE applies the LTE predicate on the "name" field.
func NameNEQ ¶
func NameNEQ(v string) predicate.Dictionary
NameNEQ applies the NEQ predicate on the "name" field.
func NameNotIn ¶
func NameNotIn(vs ...string) predicate.Dictionary
NameNotIn applies the NotIn predicate on the "name" field.
func Not ¶
func Not(p predicate.Dictionary) predicate.Dictionary
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.Dictionary) predicate.Dictionary
Or groups predicates with the OR operator between them.
func OwnerDomainID ¶
func OwnerDomainID(v uuid.UUID) predicate.Dictionary
OwnerDomainID applies equality check predicate on the "owner_domain_id" field. It's identical to OwnerDomainIDEQ.
func OwnerDomainIDEQ ¶
func OwnerDomainIDEQ(v uuid.UUID) predicate.Dictionary
OwnerDomainIDEQ applies the EQ predicate on the "owner_domain_id" field.
func OwnerDomainIDGT ¶
func OwnerDomainIDGT(v uuid.UUID) predicate.Dictionary
OwnerDomainIDGT applies the GT predicate on the "owner_domain_id" field.
func OwnerDomainIDGTE ¶
func OwnerDomainIDGTE(v uuid.UUID) predicate.Dictionary
OwnerDomainIDGTE applies the GTE predicate on the "owner_domain_id" field.
func OwnerDomainIDIn ¶
func OwnerDomainIDIn(vs ...uuid.UUID) predicate.Dictionary
OwnerDomainIDIn applies the In predicate on the "owner_domain_id" field.
func OwnerDomainIDIsNil ¶
func OwnerDomainIDIsNil() predicate.Dictionary
OwnerDomainIDIsNil applies the IsNil predicate on the "owner_domain_id" field.
func OwnerDomainIDLT ¶
func OwnerDomainIDLT(v uuid.UUID) predicate.Dictionary
OwnerDomainIDLT applies the LT predicate on the "owner_domain_id" field.
func OwnerDomainIDLTE ¶
func OwnerDomainIDLTE(v uuid.UUID) predicate.Dictionary
OwnerDomainIDLTE applies the LTE predicate on the "owner_domain_id" field.
func OwnerDomainIDNEQ ¶
func OwnerDomainIDNEQ(v uuid.UUID) predicate.Dictionary
OwnerDomainIDNEQ applies the NEQ predicate on the "owner_domain_id" field.
func OwnerDomainIDNotIn ¶
func OwnerDomainIDNotIn(vs ...uuid.UUID) predicate.Dictionary
OwnerDomainIDNotIn applies the NotIn predicate on the "owner_domain_id" field.
func OwnerDomainIDNotNil ¶
func OwnerDomainIDNotNil() predicate.Dictionary
OwnerDomainIDNotNil applies the NotNil predicate on the "owner_domain_id" field.
func PublishedAt ¶
func PublishedAt(v time.Time) predicate.Dictionary
PublishedAt applies equality check predicate on the "published_at" field. It's identical to PublishedAtEQ.
func PublishedAtEQ ¶
func PublishedAtEQ(v time.Time) predicate.Dictionary
PublishedAtEQ applies the EQ predicate on the "published_at" field.
func PublishedAtGT ¶
func PublishedAtGT(v time.Time) predicate.Dictionary
PublishedAtGT applies the GT predicate on the "published_at" field.
func PublishedAtGTE ¶
func PublishedAtGTE(v time.Time) predicate.Dictionary
PublishedAtGTE applies the GTE predicate on the "published_at" field.
func PublishedAtIn ¶
func PublishedAtIn(vs ...time.Time) predicate.Dictionary
PublishedAtIn applies the In predicate on the "published_at" field.
func PublishedAtIsNil ¶
func PublishedAtIsNil() predicate.Dictionary
PublishedAtIsNil applies the IsNil predicate on the "published_at" field.
func PublishedAtLT ¶
func PublishedAtLT(v time.Time) predicate.Dictionary
PublishedAtLT applies the LT predicate on the "published_at" field.
func PublishedAtLTE ¶
func PublishedAtLTE(v time.Time) predicate.Dictionary
PublishedAtLTE applies the LTE predicate on the "published_at" field.
func PublishedAtNEQ ¶
func PublishedAtNEQ(v time.Time) predicate.Dictionary
PublishedAtNEQ applies the NEQ predicate on the "published_at" field.
func PublishedAtNotIn ¶
func PublishedAtNotIn(vs ...time.Time) predicate.Dictionary
PublishedAtNotIn applies the NotIn predicate on the "published_at" field.
func PublishedAtNotNil ¶
func PublishedAtNotNil() predicate.Dictionary
PublishedAtNotNil applies the NotNil predicate on the "published_at" field.
func Status ¶
func Status(v bool) predicate.Dictionary
Status applies equality check predicate on the "status" field. It's identical to StatusEQ.
func StatusEQ ¶
func StatusEQ(v bool) predicate.Dictionary
StatusEQ applies the EQ predicate on the "status" field.
func StatusNEQ ¶
func StatusNEQ(v bool) predicate.Dictionary
StatusNEQ applies the NEQ predicate on the "status" field.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.Dictionary
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.Dictionary
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.Dictionary
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.Dictionary
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.Dictionary
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
func UpdatedAtIsNil() predicate.Dictionary
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.Dictionary
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.Dictionary
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.Dictionary
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.Dictionary
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
func UpdatedAtNotNil() predicate.Dictionary
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedByID ¶
func UpdatedByID(v uuid.UUID) predicate.Dictionary
UpdatedByID applies equality check predicate on the "updated_by_id" field. It's identical to UpdatedByIDEQ.
func UpdatedByIDEQ ¶
func UpdatedByIDEQ(v uuid.UUID) predicate.Dictionary
UpdatedByIDEQ applies the EQ predicate on the "updated_by_id" field.
func UpdatedByIDGT ¶
func UpdatedByIDGT(v uuid.UUID) predicate.Dictionary
UpdatedByIDGT applies the GT predicate on the "updated_by_id" field.
func UpdatedByIDGTE ¶
func UpdatedByIDGTE(v uuid.UUID) predicate.Dictionary
UpdatedByIDGTE applies the GTE predicate on the "updated_by_id" field.
func UpdatedByIDIn ¶
func UpdatedByIDIn(vs ...uuid.UUID) predicate.Dictionary
UpdatedByIDIn applies the In predicate on the "updated_by_id" field.
func UpdatedByIDIsNil ¶
func UpdatedByIDIsNil() predicate.Dictionary
UpdatedByIDIsNil applies the IsNil predicate on the "updated_by_id" field.
func UpdatedByIDLT ¶
func UpdatedByIDLT(v uuid.UUID) predicate.Dictionary
UpdatedByIDLT applies the LT predicate on the "updated_by_id" field.
func UpdatedByIDLTE ¶
func UpdatedByIDLTE(v uuid.UUID) predicate.Dictionary
UpdatedByIDLTE applies the LTE predicate on the "updated_by_id" field.
func UpdatedByIDNEQ ¶
func UpdatedByIDNEQ(v uuid.UUID) predicate.Dictionary
UpdatedByIDNEQ applies the NEQ predicate on the "updated_by_id" field.
func UpdatedByIDNotIn ¶
func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.Dictionary
UpdatedByIDNotIn applies the NotIn predicate on the "updated_by_id" field.
func UpdatedByIDNotNil ¶
func UpdatedByIDNotNil() predicate.Dictionary
UpdatedByIDNotNil applies the NotNil predicate on the "updated_by_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Dictionary queries.
func ByArchivedAt ¶
func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
ByArchivedAt orders the results by the archived_at field.
func ByCode ¶
func ByCode(opts ...sql.OrderTermOption) OrderOption
ByCode orders the results by the code field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedByID ¶
func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
ByCreatedByID orders the results by the created_by_id field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedByID ¶
func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
ByDeletedByID orders the results by the deleted_by_id field.
func ByDescription ¶
func ByDescription(opts ...sql.OrderTermOption) OrderOption
ByDescription orders the results by the description field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByItems ¶
func ByItems(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByItems orders the results by items terms.
func ByItemsCount ¶
func ByItemsCount(opts ...sql.OrderTermOption) OrderOption
ByItemsCount orders the results by items count.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByOwnerDomainID ¶
func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption
ByOwnerDomainID orders the results by the owner_domain_id field.
func ByPublishedAt ¶
func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
ByPublishedAt orders the results by the published_at field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedByID ¶
func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
ByUpdatedByID orders the results by the updated_by_id field.