Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.DomainRelation) predicate.DomainRelation
- func ArchivedAt(v time.Time) predicate.DomainRelation
- func ArchivedAtEQ(v time.Time) predicate.DomainRelation
- func ArchivedAtGT(v time.Time) predicate.DomainRelation
- func ArchivedAtGTE(v time.Time) predicate.DomainRelation
- func ArchivedAtIn(vs ...time.Time) predicate.DomainRelation
- func ArchivedAtIsNil() predicate.DomainRelation
- func ArchivedAtLT(v time.Time) predicate.DomainRelation
- func ArchivedAtLTE(v time.Time) predicate.DomainRelation
- func ArchivedAtNEQ(v time.Time) predicate.DomainRelation
- func ArchivedAtNotIn(vs ...time.Time) predicate.DomainRelation
- func ArchivedAtNotNil() predicate.DomainRelation
- func ChildDomainID(v uuid.UUID) predicate.DomainRelation
- func ChildDomainIDEQ(v uuid.UUID) predicate.DomainRelation
- func ChildDomainIDGT(v uuid.UUID) predicate.DomainRelation
- func ChildDomainIDGTE(v uuid.UUID) predicate.DomainRelation
- func ChildDomainIDIn(vs ...uuid.UUID) predicate.DomainRelation
- func ChildDomainIDLT(v uuid.UUID) predicate.DomainRelation
- func ChildDomainIDLTE(v uuid.UUID) predicate.DomainRelation
- func ChildDomainIDNEQ(v uuid.UUID) predicate.DomainRelation
- func ChildDomainIDNotIn(vs ...uuid.UUID) predicate.DomainRelation
- func CreatedAt(v time.Time) predicate.DomainRelation
- func CreatedAtEQ(v time.Time) predicate.DomainRelation
- func CreatedAtGT(v time.Time) predicate.DomainRelation
- func CreatedAtGTE(v time.Time) predicate.DomainRelation
- func CreatedAtIn(vs ...time.Time) predicate.DomainRelation
- func CreatedAtIsNil() predicate.DomainRelation
- func CreatedAtLT(v time.Time) predicate.DomainRelation
- func CreatedAtLTE(v time.Time) predicate.DomainRelation
- func CreatedAtNEQ(v time.Time) predicate.DomainRelation
- func CreatedAtNotIn(vs ...time.Time) predicate.DomainRelation
- func CreatedAtNotNil() predicate.DomainRelation
- func CreatedByID(v uuid.UUID) predicate.DomainRelation
- func CreatedByIDEQ(v uuid.UUID) predicate.DomainRelation
- func CreatedByIDGT(v uuid.UUID) predicate.DomainRelation
- func CreatedByIDGTE(v uuid.UUID) predicate.DomainRelation
- func CreatedByIDIn(vs ...uuid.UUID) predicate.DomainRelation
- func CreatedByIDIsNil() predicate.DomainRelation
- func CreatedByIDLT(v uuid.UUID) predicate.DomainRelation
- func CreatedByIDLTE(v uuid.UUID) predicate.DomainRelation
- func CreatedByIDNEQ(v uuid.UUID) predicate.DomainRelation
- func CreatedByIDNotIn(vs ...uuid.UUID) predicate.DomainRelation
- func CreatedByIDNotNil() predicate.DomainRelation
- func DeletedAt(v time.Time) predicate.DomainRelation
- func DeletedAtEQ(v time.Time) predicate.DomainRelation
- func DeletedAtGT(v time.Time) predicate.DomainRelation
- func DeletedAtGTE(v time.Time) predicate.DomainRelation
- func DeletedAtIn(vs ...time.Time) predicate.DomainRelation
- func DeletedAtIsNil() predicate.DomainRelation
- func DeletedAtLT(v time.Time) predicate.DomainRelation
- func DeletedAtLTE(v time.Time) predicate.DomainRelation
- func DeletedAtNEQ(v time.Time) predicate.DomainRelation
- func DeletedAtNotIn(vs ...time.Time) predicate.DomainRelation
- func DeletedAtNotNil() predicate.DomainRelation
- func DeletedByID(v uuid.UUID) predicate.DomainRelation
- func DeletedByIDEQ(v uuid.UUID) predicate.DomainRelation
- func DeletedByIDGT(v uuid.UUID) predicate.DomainRelation
- func DeletedByIDGTE(v uuid.UUID) predicate.DomainRelation
- func DeletedByIDIn(vs ...uuid.UUID) predicate.DomainRelation
- func DeletedByIDIsNil() predicate.DomainRelation
- func DeletedByIDLT(v uuid.UUID) predicate.DomainRelation
- func DeletedByIDLTE(v uuid.UUID) predicate.DomainRelation
- func DeletedByIDNEQ(v uuid.UUID) predicate.DomainRelation
- func DeletedByIDNotIn(vs ...uuid.UUID) predicate.DomainRelation
- func DeletedByIDNotNil() predicate.DomainRelation
- func ID(id uuid.UUID) predicate.DomainRelation
- func IDEQ(id uuid.UUID) predicate.DomainRelation
- func IDGT(id uuid.UUID) predicate.DomainRelation
- func IDGTE(id uuid.UUID) predicate.DomainRelation
- func IDIn(ids ...uuid.UUID) predicate.DomainRelation
- func IDLT(id uuid.UUID) predicate.DomainRelation
- func IDLTE(id uuid.UUID) predicate.DomainRelation
- func IDNEQ(id uuid.UUID) predicate.DomainRelation
- func IDNotIn(ids ...uuid.UUID) predicate.DomainRelation
- func Not(p predicate.DomainRelation) predicate.DomainRelation
- func Or(predicates ...predicate.DomainRelation) predicate.DomainRelation
- func ParentDomainID(v uuid.UUID) predicate.DomainRelation
- func ParentDomainIDEQ(v uuid.UUID) predicate.DomainRelation
- func ParentDomainIDGT(v uuid.UUID) predicate.DomainRelation
- func ParentDomainIDGTE(v uuid.UUID) predicate.DomainRelation
- func ParentDomainIDIn(vs ...uuid.UUID) predicate.DomainRelation
- func ParentDomainIDLT(v uuid.UUID) predicate.DomainRelation
- func ParentDomainIDLTE(v uuid.UUID) predicate.DomainRelation
- func ParentDomainIDNEQ(v uuid.UUID) predicate.DomainRelation
- func ParentDomainIDNotIn(vs ...uuid.UUID) predicate.DomainRelation
- func PublishedAt(v time.Time) predicate.DomainRelation
- func PublishedAtEQ(v time.Time) predicate.DomainRelation
- func PublishedAtGT(v time.Time) predicate.DomainRelation
- func PublishedAtGTE(v time.Time) predicate.DomainRelation
- func PublishedAtIn(vs ...time.Time) predicate.DomainRelation
- func PublishedAtIsNil() predicate.DomainRelation
- func PublishedAtLT(v time.Time) predicate.DomainRelation
- func PublishedAtLTE(v time.Time) predicate.DomainRelation
- func PublishedAtNEQ(v time.Time) predicate.DomainRelation
- func PublishedAtNotIn(vs ...time.Time) predicate.DomainRelation
- func PublishedAtNotNil() predicate.DomainRelation
- func RelationTypeEQ(v RelationType) predicate.DomainRelation
- func RelationTypeIn(vs ...RelationType) predicate.DomainRelation
- func RelationTypeNEQ(v RelationType) predicate.DomainRelation
- func RelationTypeNotIn(vs ...RelationType) predicate.DomainRelation
- func RelationTypeValidator(rt RelationType) error
- func UpdatedAt(v time.Time) predicate.DomainRelation
- func UpdatedAtEQ(v time.Time) predicate.DomainRelation
- func UpdatedAtGT(v time.Time) predicate.DomainRelation
- func UpdatedAtGTE(v time.Time) predicate.DomainRelation
- func UpdatedAtIn(vs ...time.Time) predicate.DomainRelation
- func UpdatedAtIsNil() predicate.DomainRelation
- func UpdatedAtLT(v time.Time) predicate.DomainRelation
- func UpdatedAtLTE(v time.Time) predicate.DomainRelation
- func UpdatedAtNEQ(v time.Time) predicate.DomainRelation
- func UpdatedAtNotIn(vs ...time.Time) predicate.DomainRelation
- func UpdatedAtNotNil() predicate.DomainRelation
- func UpdatedByID(v uuid.UUID) predicate.DomainRelation
- func UpdatedByIDEQ(v uuid.UUID) predicate.DomainRelation
- func UpdatedByIDGT(v uuid.UUID) predicate.DomainRelation
- func UpdatedByIDGTE(v uuid.UUID) predicate.DomainRelation
- func UpdatedByIDIn(vs ...uuid.UUID) predicate.DomainRelation
- func UpdatedByIDIsNil() predicate.DomainRelation
- func UpdatedByIDLT(v uuid.UUID) predicate.DomainRelation
- func UpdatedByIDLTE(v uuid.UUID) predicate.DomainRelation
- func UpdatedByIDNEQ(v uuid.UUID) predicate.DomainRelation
- func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.DomainRelation
- func UpdatedByIDNotNil() predicate.DomainRelation
- func ValidColumn(column string) bool
- type OrderOption
- func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
- func ByChildDomainID(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByParentDomainID(opts ...sql.OrderTermOption) OrderOption
- func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
- func ByRelationType(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
- type RelationType
Constants ¶
const ( // Label holds the string label denoting the domainrelation type in the database. Label = "domain_relation" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedByID holds the string denoting the created_by_id field in the database. FieldCreatedByID = "created_by_id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedByID holds the string denoting the updated_by_id field in the database. FieldUpdatedByID = "updated_by_id" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedByID holds the string denoting the deleted_by_id field in the database. FieldDeletedByID = "deleted_by_id" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldPublishedAt holds the string denoting the published_at field in the database. FieldPublishedAt = "published_at" // FieldArchivedAt holds the string denoting the archived_at field in the database. FieldArchivedAt = "archived_at" // FieldParentDomainID holds the string denoting the parent_domain_id field in the database. FieldParentDomainID = "parent_domain_id" // FieldChildDomainID holds the string denoting the child_domain_id field in the database. FieldChildDomainID = "child_domain_id" // FieldRelationType holds the string denoting the relation_type field in the database. FieldRelationType = "relation_type" // Table holds the table name of the domainrelation in the database. Table = "domain_relations" )
const DefaultRelationType = RelationTypeContains
RelationTypeContains is the default value of the RelationType enum.
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldCreatedByID, FieldCreatedAt, FieldUpdatedByID, FieldUpdatedAt, FieldDeletedByID, FieldDeletedAt, FieldPublishedAt, FieldArchivedAt, FieldParentDomainID, FieldChildDomainID, FieldRelationType, }
Columns holds all SQL columns for domainrelation fields.
Functions ¶
func And ¶
func And(predicates ...predicate.DomainRelation) predicate.DomainRelation
And groups predicates with the AND operator between them.
func ArchivedAt ¶
func ArchivedAt(v time.Time) predicate.DomainRelation
ArchivedAt applies equality check predicate on the "archived_at" field. It's identical to ArchivedAtEQ.
func ArchivedAtEQ ¶
func ArchivedAtEQ(v time.Time) predicate.DomainRelation
ArchivedAtEQ applies the EQ predicate on the "archived_at" field.
func ArchivedAtGT ¶
func ArchivedAtGT(v time.Time) predicate.DomainRelation
ArchivedAtGT applies the GT predicate on the "archived_at" field.
func ArchivedAtGTE ¶
func ArchivedAtGTE(v time.Time) predicate.DomainRelation
ArchivedAtGTE applies the GTE predicate on the "archived_at" field.
func ArchivedAtIn ¶
func ArchivedAtIn(vs ...time.Time) predicate.DomainRelation
ArchivedAtIn applies the In predicate on the "archived_at" field.
func ArchivedAtIsNil ¶
func ArchivedAtIsNil() predicate.DomainRelation
ArchivedAtIsNil applies the IsNil predicate on the "archived_at" field.
func ArchivedAtLT ¶
func ArchivedAtLT(v time.Time) predicate.DomainRelation
ArchivedAtLT applies the LT predicate on the "archived_at" field.
func ArchivedAtLTE ¶
func ArchivedAtLTE(v time.Time) predicate.DomainRelation
ArchivedAtLTE applies the LTE predicate on the "archived_at" field.
func ArchivedAtNEQ ¶
func ArchivedAtNEQ(v time.Time) predicate.DomainRelation
ArchivedAtNEQ applies the NEQ predicate on the "archived_at" field.
func ArchivedAtNotIn ¶
func ArchivedAtNotIn(vs ...time.Time) predicate.DomainRelation
ArchivedAtNotIn applies the NotIn predicate on the "archived_at" field.
func ArchivedAtNotNil ¶
func ArchivedAtNotNil() predicate.DomainRelation
ArchivedAtNotNil applies the NotNil predicate on the "archived_at" field.
func ChildDomainID ¶
func ChildDomainID(v uuid.UUID) predicate.DomainRelation
ChildDomainID applies equality check predicate on the "child_domain_id" field. It's identical to ChildDomainIDEQ.
func ChildDomainIDEQ ¶
func ChildDomainIDEQ(v uuid.UUID) predicate.DomainRelation
ChildDomainIDEQ applies the EQ predicate on the "child_domain_id" field.
func ChildDomainIDGT ¶
func ChildDomainIDGT(v uuid.UUID) predicate.DomainRelation
ChildDomainIDGT applies the GT predicate on the "child_domain_id" field.
func ChildDomainIDGTE ¶
func ChildDomainIDGTE(v uuid.UUID) predicate.DomainRelation
ChildDomainIDGTE applies the GTE predicate on the "child_domain_id" field.
func ChildDomainIDIn ¶
func ChildDomainIDIn(vs ...uuid.UUID) predicate.DomainRelation
ChildDomainIDIn applies the In predicate on the "child_domain_id" field.
func ChildDomainIDLT ¶
func ChildDomainIDLT(v uuid.UUID) predicate.DomainRelation
ChildDomainIDLT applies the LT predicate on the "child_domain_id" field.
func ChildDomainIDLTE ¶
func ChildDomainIDLTE(v uuid.UUID) predicate.DomainRelation
ChildDomainIDLTE applies the LTE predicate on the "child_domain_id" field.
func ChildDomainIDNEQ ¶
func ChildDomainIDNEQ(v uuid.UUID) predicate.DomainRelation
ChildDomainIDNEQ applies the NEQ predicate on the "child_domain_id" field.
func ChildDomainIDNotIn ¶
func ChildDomainIDNotIn(vs ...uuid.UUID) predicate.DomainRelation
ChildDomainIDNotIn applies the NotIn predicate on the "child_domain_id" field.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.DomainRelation
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.DomainRelation
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.DomainRelation
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.DomainRelation
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.DomainRelation
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
func CreatedAtIsNil() predicate.DomainRelation
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.DomainRelation
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.DomainRelation
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.DomainRelation
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.DomainRelation
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
func CreatedAtNotNil() predicate.DomainRelation
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedByID ¶
func CreatedByID(v uuid.UUID) predicate.DomainRelation
CreatedByID applies equality check predicate on the "created_by_id" field. It's identical to CreatedByIDEQ.
func CreatedByIDEQ ¶
func CreatedByIDEQ(v uuid.UUID) predicate.DomainRelation
CreatedByIDEQ applies the EQ predicate on the "created_by_id" field.
func CreatedByIDGT ¶
func CreatedByIDGT(v uuid.UUID) predicate.DomainRelation
CreatedByIDGT applies the GT predicate on the "created_by_id" field.
func CreatedByIDGTE ¶
func CreatedByIDGTE(v uuid.UUID) predicate.DomainRelation
CreatedByIDGTE applies the GTE predicate on the "created_by_id" field.
func CreatedByIDIn ¶
func CreatedByIDIn(vs ...uuid.UUID) predicate.DomainRelation
CreatedByIDIn applies the In predicate on the "created_by_id" field.
func CreatedByIDIsNil ¶
func CreatedByIDIsNil() predicate.DomainRelation
CreatedByIDIsNil applies the IsNil predicate on the "created_by_id" field.
func CreatedByIDLT ¶
func CreatedByIDLT(v uuid.UUID) predicate.DomainRelation
CreatedByIDLT applies the LT predicate on the "created_by_id" field.
func CreatedByIDLTE ¶
func CreatedByIDLTE(v uuid.UUID) predicate.DomainRelation
CreatedByIDLTE applies the LTE predicate on the "created_by_id" field.
func CreatedByIDNEQ ¶
func CreatedByIDNEQ(v uuid.UUID) predicate.DomainRelation
CreatedByIDNEQ applies the NEQ predicate on the "created_by_id" field.
func CreatedByIDNotIn ¶
func CreatedByIDNotIn(vs ...uuid.UUID) predicate.DomainRelation
CreatedByIDNotIn applies the NotIn predicate on the "created_by_id" field.
func CreatedByIDNotNil ¶
func CreatedByIDNotNil() predicate.DomainRelation
CreatedByIDNotNil applies the NotNil predicate on the "created_by_id" field.
func DeletedAt ¶
func DeletedAt(v time.Time) predicate.DomainRelation
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
func DeletedAtEQ(v time.Time) predicate.DomainRelation
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
func DeletedAtGT(v time.Time) predicate.DomainRelation
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
func DeletedAtGTE(v time.Time) predicate.DomainRelation
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
func DeletedAtIn(vs ...time.Time) predicate.DomainRelation
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
func DeletedAtIsNil() predicate.DomainRelation
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
func DeletedAtLT(v time.Time) predicate.DomainRelation
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
func DeletedAtLTE(v time.Time) predicate.DomainRelation
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
func DeletedAtNEQ(v time.Time) predicate.DomainRelation
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
func DeletedAtNotIn(vs ...time.Time) predicate.DomainRelation
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
func DeletedAtNotNil() predicate.DomainRelation
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedByID ¶
func DeletedByID(v uuid.UUID) predicate.DomainRelation
DeletedByID applies equality check predicate on the "deleted_by_id" field. It's identical to DeletedByIDEQ.
func DeletedByIDEQ ¶
func DeletedByIDEQ(v uuid.UUID) predicate.DomainRelation
DeletedByIDEQ applies the EQ predicate on the "deleted_by_id" field.
func DeletedByIDGT ¶
func DeletedByIDGT(v uuid.UUID) predicate.DomainRelation
DeletedByIDGT applies the GT predicate on the "deleted_by_id" field.
func DeletedByIDGTE ¶
func DeletedByIDGTE(v uuid.UUID) predicate.DomainRelation
DeletedByIDGTE applies the GTE predicate on the "deleted_by_id" field.
func DeletedByIDIn ¶
func DeletedByIDIn(vs ...uuid.UUID) predicate.DomainRelation
DeletedByIDIn applies the In predicate on the "deleted_by_id" field.
func DeletedByIDIsNil ¶
func DeletedByIDIsNil() predicate.DomainRelation
DeletedByIDIsNil applies the IsNil predicate on the "deleted_by_id" field.
func DeletedByIDLT ¶
func DeletedByIDLT(v uuid.UUID) predicate.DomainRelation
DeletedByIDLT applies the LT predicate on the "deleted_by_id" field.
func DeletedByIDLTE ¶
func DeletedByIDLTE(v uuid.UUID) predicate.DomainRelation
DeletedByIDLTE applies the LTE predicate on the "deleted_by_id" field.
func DeletedByIDNEQ ¶
func DeletedByIDNEQ(v uuid.UUID) predicate.DomainRelation
DeletedByIDNEQ applies the NEQ predicate on the "deleted_by_id" field.
func DeletedByIDNotIn ¶
func DeletedByIDNotIn(vs ...uuid.UUID) predicate.DomainRelation
DeletedByIDNotIn applies the NotIn predicate on the "deleted_by_id" field.
func DeletedByIDNotNil ¶
func DeletedByIDNotNil() predicate.DomainRelation
DeletedByIDNotNil applies the NotNil predicate on the "deleted_by_id" field.
func ID ¶
func ID(id uuid.UUID) predicate.DomainRelation
ID filters vertices based on their ID field.
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.DomainRelation
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.DomainRelation
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.DomainRelation
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.DomainRelation
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.DomainRelation
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.DomainRelation
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.DomainRelation
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.DomainRelation
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.DomainRelation) predicate.DomainRelation
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.DomainRelation) predicate.DomainRelation
Or groups predicates with the OR operator between them.
func ParentDomainID ¶
func ParentDomainID(v uuid.UUID) predicate.DomainRelation
ParentDomainID applies equality check predicate on the "parent_domain_id" field. It's identical to ParentDomainIDEQ.
func ParentDomainIDEQ ¶
func ParentDomainIDEQ(v uuid.UUID) predicate.DomainRelation
ParentDomainIDEQ applies the EQ predicate on the "parent_domain_id" field.
func ParentDomainIDGT ¶
func ParentDomainIDGT(v uuid.UUID) predicate.DomainRelation
ParentDomainIDGT applies the GT predicate on the "parent_domain_id" field.
func ParentDomainIDGTE ¶
func ParentDomainIDGTE(v uuid.UUID) predicate.DomainRelation
ParentDomainIDGTE applies the GTE predicate on the "parent_domain_id" field.
func ParentDomainIDIn ¶
func ParentDomainIDIn(vs ...uuid.UUID) predicate.DomainRelation
ParentDomainIDIn applies the In predicate on the "parent_domain_id" field.
func ParentDomainIDLT ¶
func ParentDomainIDLT(v uuid.UUID) predicate.DomainRelation
ParentDomainIDLT applies the LT predicate on the "parent_domain_id" field.
func ParentDomainIDLTE ¶
func ParentDomainIDLTE(v uuid.UUID) predicate.DomainRelation
ParentDomainIDLTE applies the LTE predicate on the "parent_domain_id" field.
func ParentDomainIDNEQ ¶
func ParentDomainIDNEQ(v uuid.UUID) predicate.DomainRelation
ParentDomainIDNEQ applies the NEQ predicate on the "parent_domain_id" field.
func ParentDomainIDNotIn ¶
func ParentDomainIDNotIn(vs ...uuid.UUID) predicate.DomainRelation
ParentDomainIDNotIn applies the NotIn predicate on the "parent_domain_id" field.
func PublishedAt ¶
func PublishedAt(v time.Time) predicate.DomainRelation
PublishedAt applies equality check predicate on the "published_at" field. It's identical to PublishedAtEQ.
func PublishedAtEQ ¶
func PublishedAtEQ(v time.Time) predicate.DomainRelation
PublishedAtEQ applies the EQ predicate on the "published_at" field.
func PublishedAtGT ¶
func PublishedAtGT(v time.Time) predicate.DomainRelation
PublishedAtGT applies the GT predicate on the "published_at" field.
func PublishedAtGTE ¶
func PublishedAtGTE(v time.Time) predicate.DomainRelation
PublishedAtGTE applies the GTE predicate on the "published_at" field.
func PublishedAtIn ¶
func PublishedAtIn(vs ...time.Time) predicate.DomainRelation
PublishedAtIn applies the In predicate on the "published_at" field.
func PublishedAtIsNil ¶
func PublishedAtIsNil() predicate.DomainRelation
PublishedAtIsNil applies the IsNil predicate on the "published_at" field.
func PublishedAtLT ¶
func PublishedAtLT(v time.Time) predicate.DomainRelation
PublishedAtLT applies the LT predicate on the "published_at" field.
func PublishedAtLTE ¶
func PublishedAtLTE(v time.Time) predicate.DomainRelation
PublishedAtLTE applies the LTE predicate on the "published_at" field.
func PublishedAtNEQ ¶
func PublishedAtNEQ(v time.Time) predicate.DomainRelation
PublishedAtNEQ applies the NEQ predicate on the "published_at" field.
func PublishedAtNotIn ¶
func PublishedAtNotIn(vs ...time.Time) predicate.DomainRelation
PublishedAtNotIn applies the NotIn predicate on the "published_at" field.
func PublishedAtNotNil ¶
func PublishedAtNotNil() predicate.DomainRelation
PublishedAtNotNil applies the NotNil predicate on the "published_at" field.
func RelationTypeEQ ¶
func RelationTypeEQ(v RelationType) predicate.DomainRelation
RelationTypeEQ applies the EQ predicate on the "relation_type" field.
func RelationTypeIn ¶
func RelationTypeIn(vs ...RelationType) predicate.DomainRelation
RelationTypeIn applies the In predicate on the "relation_type" field.
func RelationTypeNEQ ¶
func RelationTypeNEQ(v RelationType) predicate.DomainRelation
RelationTypeNEQ applies the NEQ predicate on the "relation_type" field.
func RelationTypeNotIn ¶
func RelationTypeNotIn(vs ...RelationType) predicate.DomainRelation
RelationTypeNotIn applies the NotIn predicate on the "relation_type" field.
func RelationTypeValidator ¶
func RelationTypeValidator(rt RelationType) error
RelationTypeValidator is a validator for the "relation_type" field enum values. It is called by the builders before save.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.DomainRelation
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.DomainRelation
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.DomainRelation
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.DomainRelation
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.DomainRelation
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
func UpdatedAtIsNil() predicate.DomainRelation
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.DomainRelation
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.DomainRelation
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.DomainRelation
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.DomainRelation
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
func UpdatedAtNotNil() predicate.DomainRelation
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedByID ¶
func UpdatedByID(v uuid.UUID) predicate.DomainRelation
UpdatedByID applies equality check predicate on the "updated_by_id" field. It's identical to UpdatedByIDEQ.
func UpdatedByIDEQ ¶
func UpdatedByIDEQ(v uuid.UUID) predicate.DomainRelation
UpdatedByIDEQ applies the EQ predicate on the "updated_by_id" field.
func UpdatedByIDGT ¶
func UpdatedByIDGT(v uuid.UUID) predicate.DomainRelation
UpdatedByIDGT applies the GT predicate on the "updated_by_id" field.
func UpdatedByIDGTE ¶
func UpdatedByIDGTE(v uuid.UUID) predicate.DomainRelation
UpdatedByIDGTE applies the GTE predicate on the "updated_by_id" field.
func UpdatedByIDIn ¶
func UpdatedByIDIn(vs ...uuid.UUID) predicate.DomainRelation
UpdatedByIDIn applies the In predicate on the "updated_by_id" field.
func UpdatedByIDIsNil ¶
func UpdatedByIDIsNil() predicate.DomainRelation
UpdatedByIDIsNil applies the IsNil predicate on the "updated_by_id" field.
func UpdatedByIDLT ¶
func UpdatedByIDLT(v uuid.UUID) predicate.DomainRelation
UpdatedByIDLT applies the LT predicate on the "updated_by_id" field.
func UpdatedByIDLTE ¶
func UpdatedByIDLTE(v uuid.UUID) predicate.DomainRelation
UpdatedByIDLTE applies the LTE predicate on the "updated_by_id" field.
func UpdatedByIDNEQ ¶
func UpdatedByIDNEQ(v uuid.UUID) predicate.DomainRelation
UpdatedByIDNEQ applies the NEQ predicate on the "updated_by_id" field.
func UpdatedByIDNotIn ¶
func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.DomainRelation
UpdatedByIDNotIn applies the NotIn predicate on the "updated_by_id" field.
func UpdatedByIDNotNil ¶
func UpdatedByIDNotNil() predicate.DomainRelation
UpdatedByIDNotNil applies the NotNil predicate on the "updated_by_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the DomainRelation queries.
func ByArchivedAt ¶
func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
ByArchivedAt orders the results by the archived_at field.
func ByChildDomainID ¶
func ByChildDomainID(opts ...sql.OrderTermOption) OrderOption
ByChildDomainID orders the results by the child_domain_id field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedByID ¶
func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
ByCreatedByID orders the results by the created_by_id field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedByID ¶
func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
ByDeletedByID orders the results by the deleted_by_id field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByParentDomainID ¶
func ByParentDomainID(opts ...sql.OrderTermOption) OrderOption
ByParentDomainID orders the results by the parent_domain_id field.
func ByPublishedAt ¶
func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
ByPublishedAt orders the results by the published_at field.
func ByRelationType ¶
func ByRelationType(opts ...sql.OrderTermOption) OrderOption
ByRelationType orders the results by the relation_type field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedByID ¶
func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
ByUpdatedByID orders the results by the updated_by_id field.
type RelationType ¶
type RelationType string
RelationType defines the type for the "relation_type" enum field.
const ( RelationTypeContains RelationType = "contains" RelationTypeDelegates RelationType = "delegates" RelationTypeInherits RelationType = "inherits" )
RelationType values.
func (RelationType) String ¶
func (rt RelationType) String() string