Documentation
¶
Index ¶
- func FixedError(err error) ent.Hook
- func If(hk ent.Hook, cond Condition) ent.Hook
- func On(hk ent.Hook, op ent.Op) ent.Hook
- func Reject(op ent.Op) ent.Hook
- func Unless(hk ent.Hook, op ent.Op) ent.Hook
- type APIPermissionFunc
- type APIPermissionMapFunc
- type ApiKeyFunc
- type AuditLogFunc
- type Chain
- type Condition
- func And(first, second Condition, rest ...Condition) Condition
- func HasAddedFields(field string, fields ...string) Condition
- func HasClearedFields(field string, fields ...string) Condition
- func HasFields(field string, fields ...string) Condition
- func HasOp(op ent.Op) Condition
- func Not(cond Condition) Condition
- func Or(first, second Condition, rest ...Condition) Condition
- type DictionaryDetailFunc
- type DictionaryFunc
- type DomainFunc
- type DomainMembershipFunc
- type DomainRelationFunc
- type DomainTypeFunc
- type InvitationTokenFunc
- type MediaFolderFunc
- type MediaFormatFunc
- type MediaFunc
- type MenuFunc
- type OperationLogFunc
- type OrganizationFunc
- type OrganizationMemberFunc
- type PasswordResetTokenFunc
- type PermissionFunc
- type PostFunc
- type ResourceDomainBindingFunc
- type RoleBindingFunc
- type RoleFunc
- type SessionFunc
- type SystemConfigFunc
- type SystemErrorFunc
- type TenantFunc
- type TenantUserFunc
- type UserFunc
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func If ¶
If executes the given hook under condition.
hook.If(ComputeAverage, And(HasFields(...), HasAddedFields(...)))
func On ¶
On executes the given hook only for the given operation.
hook.On(Log, ent.Delete|ent.Create)
Types ¶
type APIPermissionFunc ¶
The APIPermissionFunc type is an adapter to allow the use of ordinary function as APIPermission mutator.
type APIPermissionMapFunc ¶
The APIPermissionMapFunc type is an adapter to allow the use of ordinary function as APIPermissionMap mutator.
type ApiKeyFunc ¶
The ApiKeyFunc type is an adapter to allow the use of ordinary function as ApiKey mutator.
type AuditLogFunc ¶
The AuditLogFunc type is an adapter to allow the use of ordinary function as AuditLog mutator.
type Chain ¶
type Chain struct {
// contains filtered or unexported fields
}
Chain acts as a list of hooks and is effectively immutable. Once created, it will always hold the same set of hooks in the same order.
func (Chain) Append ¶
Append extends a chain, adding the specified hook as the last ones in the mutation flow.
type Condition ¶
Condition is a hook condition function.
func HasAddedFields ¶
HasAddedFields is a condition validating `.AddedField` on fields.
func HasClearedFields ¶
HasClearedFields is a condition validating `.FieldCleared` on fields.
type DictionaryDetailFunc ¶
The DictionaryDetailFunc type is an adapter to allow the use of ordinary function as DictionaryDetail mutator.
type DictionaryFunc ¶
The DictionaryFunc type is an adapter to allow the use of ordinary function as Dictionary mutator.
type DomainFunc ¶
The DomainFunc type is an adapter to allow the use of ordinary function as Domain mutator.
type DomainMembershipFunc ¶
The DomainMembershipFunc type is an adapter to allow the use of ordinary function as DomainMembership mutator.
type DomainRelationFunc ¶
The DomainRelationFunc type is an adapter to allow the use of ordinary function as DomainRelation mutator.
type DomainTypeFunc ¶
The DomainTypeFunc type is an adapter to allow the use of ordinary function as DomainType mutator.
type InvitationTokenFunc ¶
The InvitationTokenFunc type is an adapter to allow the use of ordinary function as InvitationToken mutator.
type MediaFolderFunc ¶
The MediaFolderFunc type is an adapter to allow the use of ordinary function as MediaFolder mutator.
type MediaFormatFunc ¶
The MediaFormatFunc type is an adapter to allow the use of ordinary function as MediaFormat mutator.
type MediaFunc ¶
The MediaFunc type is an adapter to allow the use of ordinary function as Media mutator.
type MenuFunc ¶
The MenuFunc type is an adapter to allow the use of ordinary function as Menu mutator.
type OperationLogFunc ¶
The OperationLogFunc type is an adapter to allow the use of ordinary function as OperationLog mutator.
type OrganizationFunc ¶
The OrganizationFunc type is an adapter to allow the use of ordinary function as Organization mutator.
type OrganizationMemberFunc ¶
type OrganizationMemberFunc func(context.Context, *ent.OrganizationMemberMutation) (ent.Value, error)
The OrganizationMemberFunc type is an adapter to allow the use of ordinary function as OrganizationMember mutator.
type PasswordResetTokenFunc ¶
type PasswordResetTokenFunc func(context.Context, *ent.PasswordResetTokenMutation) (ent.Value, error)
The PasswordResetTokenFunc type is an adapter to allow the use of ordinary function as PasswordResetToken mutator.
type PermissionFunc ¶
The PermissionFunc type is an adapter to allow the use of ordinary function as Permission mutator.
type PostFunc ¶
The PostFunc type is an adapter to allow the use of ordinary function as Post mutator.
type ResourceDomainBindingFunc ¶
type ResourceDomainBindingFunc func(context.Context, *ent.ResourceDomainBindingMutation) (ent.Value, error)
The ResourceDomainBindingFunc type is an adapter to allow the use of ordinary function as ResourceDomainBinding mutator.
type RoleBindingFunc ¶
The RoleBindingFunc type is an adapter to allow the use of ordinary function as RoleBinding mutator.
type RoleFunc ¶
The RoleFunc type is an adapter to allow the use of ordinary function as Role mutator.
type SessionFunc ¶
The SessionFunc type is an adapter to allow the use of ordinary function as Session mutator.
type SystemConfigFunc ¶
The SystemConfigFunc type is an adapter to allow the use of ordinary function as SystemConfig mutator.
type SystemErrorFunc ¶
The SystemErrorFunc type is an adapter to allow the use of ordinary function as SystemError mutator.
type TenantFunc ¶
The TenantFunc type is an adapter to allow the use of ordinary function as Tenant mutator.
type TenantUserFunc ¶
The TenantUserFunc type is an adapter to allow the use of ordinary function as TenantUser mutator.