Documentation
¶
Index ¶
- Constants
- Variables
- func Affix(v bool) predicate.Menu
- func AffixEQ(v bool) predicate.Menu
- func AffixNEQ(v bool) predicate.Menu
- func And(predicates ...predicate.Menu) predicate.Menu
- func ArchivedAt(v time.Time) predicate.Menu
- func ArchivedAtEQ(v time.Time) predicate.Menu
- func ArchivedAtGT(v time.Time) predicate.Menu
- func ArchivedAtGTE(v time.Time) predicate.Menu
- func ArchivedAtIn(vs ...time.Time) predicate.Menu
- func ArchivedAtIsNil() predicate.Menu
- func ArchivedAtLT(v time.Time) predicate.Menu
- func ArchivedAtLTE(v time.Time) predicate.Menu
- func ArchivedAtNEQ(v time.Time) predicate.Menu
- func ArchivedAtNotIn(vs ...time.Time) predicate.Menu
- func ArchivedAtNotNil() predicate.Menu
- func Component(v string) predicate.Menu
- func ComponentContains(v string) predicate.Menu
- func ComponentContainsFold(v string) predicate.Menu
- func ComponentEQ(v string) predicate.Menu
- func ComponentEqualFold(v string) predicate.Menu
- func ComponentGT(v string) predicate.Menu
- func ComponentGTE(v string) predicate.Menu
- func ComponentHasPrefix(v string) predicate.Menu
- func ComponentHasSuffix(v string) predicate.Menu
- func ComponentIn(vs ...string) predicate.Menu
- func ComponentIsNil() predicate.Menu
- func ComponentLT(v string) predicate.Menu
- func ComponentLTE(v string) predicate.Menu
- func ComponentNEQ(v string) predicate.Menu
- func ComponentNotIn(vs ...string) predicate.Menu
- func ComponentNotNil() predicate.Menu
- func CreatedAt(v time.Time) predicate.Menu
- func CreatedAtEQ(v time.Time) predicate.Menu
- func CreatedAtGT(v time.Time) predicate.Menu
- func CreatedAtGTE(v time.Time) predicate.Menu
- func CreatedAtIn(vs ...time.Time) predicate.Menu
- func CreatedAtIsNil() predicate.Menu
- func CreatedAtLT(v time.Time) predicate.Menu
- func CreatedAtLTE(v time.Time) predicate.Menu
- func CreatedAtNEQ(v time.Time) predicate.Menu
- func CreatedAtNotIn(vs ...time.Time) predicate.Menu
- func CreatedAtNotNil() predicate.Menu
- func CreatedByID(v uuid.UUID) predicate.Menu
- func CreatedByIDEQ(v uuid.UUID) predicate.Menu
- func CreatedByIDGT(v uuid.UUID) predicate.Menu
- func CreatedByIDGTE(v uuid.UUID) predicate.Menu
- func CreatedByIDIn(vs ...uuid.UUID) predicate.Menu
- func CreatedByIDIsNil() predicate.Menu
- func CreatedByIDLT(v uuid.UUID) predicate.Menu
- func CreatedByIDLTE(v uuid.UUID) predicate.Menu
- func CreatedByIDNEQ(v uuid.UUID) predicate.Menu
- func CreatedByIDNotIn(vs ...uuid.UUID) predicate.Menu
- func CreatedByIDNotNil() predicate.Menu
- func DeletedAt(v time.Time) predicate.Menu
- func DeletedAtEQ(v time.Time) predicate.Menu
- func DeletedAtGT(v time.Time) predicate.Menu
- func DeletedAtGTE(v time.Time) predicate.Menu
- func DeletedAtIn(vs ...time.Time) predicate.Menu
- func DeletedAtIsNil() predicate.Menu
- func DeletedAtLT(v time.Time) predicate.Menu
- func DeletedAtLTE(v time.Time) predicate.Menu
- func DeletedAtNEQ(v time.Time) predicate.Menu
- func DeletedAtNotIn(vs ...time.Time) predicate.Menu
- func DeletedAtNotNil() predicate.Menu
- func DeletedByID(v uuid.UUID) predicate.Menu
- func DeletedByIDEQ(v uuid.UUID) predicate.Menu
- func DeletedByIDGT(v uuid.UUID) predicate.Menu
- func DeletedByIDGTE(v uuid.UUID) predicate.Menu
- func DeletedByIDIn(vs ...uuid.UUID) predicate.Menu
- func DeletedByIDIsNil() predicate.Menu
- func DeletedByIDLT(v uuid.UUID) predicate.Menu
- func DeletedByIDLTE(v uuid.UUID) predicate.Menu
- func DeletedByIDNEQ(v uuid.UUID) predicate.Menu
- func DeletedByIDNotIn(vs ...uuid.UUID) predicate.Menu
- func DeletedByIDNotNil() predicate.Menu
- func HasChildren() predicate.Menu
- func HasChildrenWith(preds ...predicate.Menu) predicate.Menu
- func HasParent() predicate.Menu
- func HasParentWith(preds ...predicate.Menu) predicate.Menu
- func HasRoles() predicate.Menu
- func HasRolesWith(preds ...predicate.Role) predicate.Menu
- func Hidden(v bool) predicate.Menu
- func HiddenEQ(v bool) predicate.Menu
- func HiddenNEQ(v bool) predicate.Menu
- func ID(id uuid.UUID) predicate.Menu
- func IDEQ(id uuid.UUID) predicate.Menu
- func IDGT(id uuid.UUID) predicate.Menu
- func IDGTE(id uuid.UUID) predicate.Menu
- func IDIn(ids ...uuid.UUID) predicate.Menu
- func IDLT(id uuid.UUID) predicate.Menu
- func IDLTE(id uuid.UUID) predicate.Menu
- func IDNEQ(id uuid.UUID) predicate.Menu
- func IDNotIn(ids ...uuid.UUID) predicate.Menu
- func Icon(v string) predicate.Menu
- func IconContains(v string) predicate.Menu
- func IconContainsFold(v string) predicate.Menu
- func IconEQ(v string) predicate.Menu
- func IconEqualFold(v string) predicate.Menu
- func IconGT(v string) predicate.Menu
- func IconGTE(v string) predicate.Menu
- func IconHasPrefix(v string) predicate.Menu
- func IconHasSuffix(v string) predicate.Menu
- func IconIn(vs ...string) predicate.Menu
- func IconIsNil() predicate.Menu
- func IconLT(v string) predicate.Menu
- func IconLTE(v string) predicate.Menu
- func IconNEQ(v string) predicate.Menu
- func IconNotIn(vs ...string) predicate.Menu
- func IconNotNil() predicate.Menu
- func MetaIsNil() predicate.Menu
- func MetaNotNil() predicate.Menu
- func Name(v string) predicate.Menu
- func NameContains(v string) predicate.Menu
- func NameContainsFold(v string) predicate.Menu
- func NameEQ(v string) predicate.Menu
- func NameEqualFold(v string) predicate.Menu
- func NameGT(v string) predicate.Menu
- func NameGTE(v string) predicate.Menu
- func NameHasPrefix(v string) predicate.Menu
- func NameHasSuffix(v string) predicate.Menu
- func NameIn(vs ...string) predicate.Menu
- func NameLT(v string) predicate.Menu
- func NameLTE(v string) predicate.Menu
- func NameNEQ(v string) predicate.Menu
- func NameNotIn(vs ...string) predicate.Menu
- func Not(p predicate.Menu) predicate.Menu
- func Or(predicates ...predicate.Menu) predicate.Menu
- func OwnerDomainID(v uuid.UUID) predicate.Menu
- func OwnerDomainIDEQ(v uuid.UUID) predicate.Menu
- func OwnerDomainIDGT(v uuid.UUID) predicate.Menu
- func OwnerDomainIDGTE(v uuid.UUID) predicate.Menu
- func OwnerDomainIDIn(vs ...uuid.UUID) predicate.Menu
- func OwnerDomainIDIsNil() predicate.Menu
- func OwnerDomainIDLT(v uuid.UUID) predicate.Menu
- func OwnerDomainIDLTE(v uuid.UUID) predicate.Menu
- func OwnerDomainIDNEQ(v uuid.UUID) predicate.Menu
- func OwnerDomainIDNotIn(vs ...uuid.UUID) predicate.Menu
- func OwnerDomainIDNotNil() predicate.Menu
- func ParamsIsNil() predicate.Menu
- func ParamsNotNil() predicate.Menu
- func ParentID(v uuid.UUID) predicate.Menu
- func ParentIDEQ(v uuid.UUID) predicate.Menu
- func ParentIDIn(vs ...uuid.UUID) predicate.Menu
- func ParentIDIsNil() predicate.Menu
- func ParentIDNEQ(v uuid.UUID) predicate.Menu
- func ParentIDNotIn(vs ...uuid.UUID) predicate.Menu
- func ParentIDNotNil() predicate.Menu
- func Path(v string) predicate.Menu
- func PathContains(v string) predicate.Menu
- func PathContainsFold(v string) predicate.Menu
- func PathEQ(v string) predicate.Menu
- func PathEqualFold(v string) predicate.Menu
- func PathGT(v string) predicate.Menu
- func PathGTE(v string) predicate.Menu
- func PathHasPrefix(v string) predicate.Menu
- func PathHasSuffix(v string) predicate.Menu
- func PathIn(vs ...string) predicate.Menu
- func PathLT(v string) predicate.Menu
- func PathLTE(v string) predicate.Menu
- func PathNEQ(v string) predicate.Menu
- func PathNotIn(vs ...string) predicate.Menu
- func PublishedAt(v time.Time) predicate.Menu
- func PublishedAtEQ(v time.Time) predicate.Menu
- func PublishedAtGT(v time.Time) predicate.Menu
- func PublishedAtGTE(v time.Time) predicate.Menu
- func PublishedAtIn(vs ...time.Time) predicate.Menu
- func PublishedAtIsNil() predicate.Menu
- func PublishedAtLT(v time.Time) predicate.Menu
- func PublishedAtLTE(v time.Time) predicate.Menu
- func PublishedAtNEQ(v time.Time) predicate.Menu
- func PublishedAtNotIn(vs ...time.Time) predicate.Menu
- func PublishedAtNotNil() predicate.Menu
- func Redirect(v string) predicate.Menu
- func RedirectContains(v string) predicate.Menu
- func RedirectContainsFold(v string) predicate.Menu
- func RedirectEQ(v string) predicate.Menu
- func RedirectEqualFold(v string) predicate.Menu
- func RedirectGT(v string) predicate.Menu
- func RedirectGTE(v string) predicate.Menu
- func RedirectHasPrefix(v string) predicate.Menu
- func RedirectHasSuffix(v string) predicate.Menu
- func RedirectIn(vs ...string) predicate.Menu
- func RedirectIsNil() predicate.Menu
- func RedirectLT(v string) predicate.Menu
- func RedirectLTE(v string) predicate.Menu
- func RedirectNEQ(v string) predicate.Menu
- func RedirectNotIn(vs ...string) predicate.Menu
- func RedirectNotNil() predicate.Menu
- func Sort(v int) predicate.Menu
- func SortEQ(v int) predicate.Menu
- func SortGT(v int) predicate.Menu
- func SortGTE(v int) predicate.Menu
- func SortIn(vs ...int) predicate.Menu
- func SortLT(v int) predicate.Menu
- func SortLTE(v int) predicate.Menu
- func SortNEQ(v int) predicate.Menu
- func SortNotIn(vs ...int) predicate.Menu
- func UpdatedAt(v time.Time) predicate.Menu
- func UpdatedAtEQ(v time.Time) predicate.Menu
- func UpdatedAtGT(v time.Time) predicate.Menu
- func UpdatedAtGTE(v time.Time) predicate.Menu
- func UpdatedAtIn(vs ...time.Time) predicate.Menu
- func UpdatedAtIsNil() predicate.Menu
- func UpdatedAtLT(v time.Time) predicate.Menu
- func UpdatedAtLTE(v time.Time) predicate.Menu
- func UpdatedAtNEQ(v time.Time) predicate.Menu
- func UpdatedAtNotIn(vs ...time.Time) predicate.Menu
- func UpdatedAtNotNil() predicate.Menu
- func UpdatedByID(v uuid.UUID) predicate.Menu
- func UpdatedByIDEQ(v uuid.UUID) predicate.Menu
- func UpdatedByIDGT(v uuid.UUID) predicate.Menu
- func UpdatedByIDGTE(v uuid.UUID) predicate.Menu
- func UpdatedByIDIn(vs ...uuid.UUID) predicate.Menu
- func UpdatedByIDIsNil() predicate.Menu
- func UpdatedByIDLT(v uuid.UUID) predicate.Menu
- func UpdatedByIDLTE(v uuid.UUID) predicate.Menu
- func UpdatedByIDNEQ(v uuid.UUID) predicate.Menu
- func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.Menu
- func UpdatedByIDNotNil() predicate.Menu
- func ValidColumn(column string) bool
- type OrderOption
- func ByAffix(opts ...sql.OrderTermOption) OrderOption
- func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
- func ByChildren(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByChildrenCount(opts ...sql.OrderTermOption) OrderOption
- func ByComponent(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
- func ByHidden(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIcon(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption
- func ByParentField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByParentID(opts ...sql.OrderTermOption) OrderOption
- func ByPath(opts ...sql.OrderTermOption) OrderOption
- func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
- func ByRedirect(opts ...sql.OrderTermOption) OrderOption
- func ByRoles(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByRolesCount(opts ...sql.OrderTermOption) OrderOption
- func BySort(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the menu type in the database. Label = "menu" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedByID holds the string denoting the created_by_id field in the database. FieldCreatedByID = "created_by_id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedByID holds the string denoting the updated_by_id field in the database. FieldUpdatedByID = "updated_by_id" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedByID holds the string denoting the deleted_by_id field in the database. FieldDeletedByID = "deleted_by_id" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldPublishedAt holds the string denoting the published_at field in the database. FieldPublishedAt = "published_at" // FieldArchivedAt holds the string denoting the archived_at field in the database. FieldArchivedAt = "archived_at" // FieldOwnerDomainID holds the string denoting the owner_domain_id field in the database. FieldOwnerDomainID = "owner_domain_id" // FieldParentID holds the string denoting the parent_id field in the database. FieldParentID = "parent_id" // FieldPath holds the string denoting the path field in the database. FieldPath = "path" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldComponent holds the string denoting the component field in the database. FieldComponent = "component" // FieldRedirect holds the string denoting the redirect field in the database. FieldRedirect = "redirect" // FieldHidden holds the string denoting the hidden field in the database. FieldHidden = "hidden" // FieldAffix holds the string denoting the affix field in the database. FieldAffix = "affix" // FieldIcon holds the string denoting the icon field in the database. FieldIcon = "icon" // FieldSort holds the string denoting the sort field in the database. FieldSort = "sort" // FieldMeta holds the string denoting the meta field in the database. FieldMeta = "meta" // FieldParams holds the string denoting the params field in the database. FieldParams = "params" // EdgeRoles holds the string denoting the roles edge name in mutations. EdgeRoles = "roles" // EdgeParent holds the string denoting the parent edge name in mutations. EdgeParent = "parent" // EdgeChildren holds the string denoting the children edge name in mutations. EdgeChildren = "children" // Table holds the table name of the menu in the database. Table = "menus" // RolesTable is the table that holds the roles relation/edge. The primary key declared below. RolesTable = "role_menus" // RolesInverseTable is the table name for the Role entity. // It exists in this package in order to avoid circular dependency with the "role" package. RolesInverseTable = "roles" // ParentTable is the table that holds the parent relation/edge. ParentTable = "menus" // ParentColumn is the table column denoting the parent relation/edge. ParentColumn = "parent_id" // ChildrenTable is the table that holds the children relation/edge. ChildrenTable = "menus" // ChildrenColumn is the table column denoting the children relation/edge. ChildrenColumn = "parent_id" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // PathValidator is a validator for the "path" field. It is called by the builders before save. PathValidator func(string) error // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // DefaultHidden holds the default value on creation for the "hidden" field. DefaultHidden bool // DefaultAffix holds the default value on creation for the "affix" field. DefaultAffix bool // DefaultSort holds the default value on creation for the "sort" field. DefaultSort int // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldCreatedByID, FieldCreatedAt, FieldUpdatedByID, FieldUpdatedAt, FieldDeletedByID, FieldDeletedAt, FieldPublishedAt, FieldArchivedAt, FieldOwnerDomainID, FieldParentID, FieldPath, FieldName, FieldComponent, FieldRedirect, FieldHidden, FieldAffix, FieldIcon, FieldSort, FieldMeta, FieldParams, }
Columns holds all SQL columns for menu fields.
var ( // RolesPrimaryKey and RolesColumn2 are the table columns denoting the // primary key for the roles relation (M2M). RolesPrimaryKey = []string{"role_id", "menu_id"} )
Functions ¶
func Affix ¶
Affix applies equality check predicate on the "affix" field. It's identical to AffixEQ.
func ArchivedAt ¶
ArchivedAt applies equality check predicate on the "archived_at" field. It's identical to ArchivedAtEQ.
func ArchivedAtEQ ¶
ArchivedAtEQ applies the EQ predicate on the "archived_at" field.
func ArchivedAtGT ¶
ArchivedAtGT applies the GT predicate on the "archived_at" field.
func ArchivedAtGTE ¶
ArchivedAtGTE applies the GTE predicate on the "archived_at" field.
func ArchivedAtIn ¶
ArchivedAtIn applies the In predicate on the "archived_at" field.
func ArchivedAtIsNil ¶
ArchivedAtIsNil applies the IsNil predicate on the "archived_at" field.
func ArchivedAtLT ¶
ArchivedAtLT applies the LT predicate on the "archived_at" field.
func ArchivedAtLTE ¶
ArchivedAtLTE applies the LTE predicate on the "archived_at" field.
func ArchivedAtNEQ ¶
ArchivedAtNEQ applies the NEQ predicate on the "archived_at" field.
func ArchivedAtNotIn ¶
ArchivedAtNotIn applies the NotIn predicate on the "archived_at" field.
func ArchivedAtNotNil ¶
ArchivedAtNotNil applies the NotNil predicate on the "archived_at" field.
func Component ¶
Component applies equality check predicate on the "component" field. It's identical to ComponentEQ.
func ComponentContains ¶
ComponentContains applies the Contains predicate on the "component" field.
func ComponentContainsFold ¶
ComponentContainsFold applies the ContainsFold predicate on the "component" field.
func ComponentEQ ¶
ComponentEQ applies the EQ predicate on the "component" field.
func ComponentEqualFold ¶
ComponentEqualFold applies the EqualFold predicate on the "component" field.
func ComponentGT ¶
ComponentGT applies the GT predicate on the "component" field.
func ComponentGTE ¶
ComponentGTE applies the GTE predicate on the "component" field.
func ComponentHasPrefix ¶
ComponentHasPrefix applies the HasPrefix predicate on the "component" field.
func ComponentHasSuffix ¶
ComponentHasSuffix applies the HasSuffix predicate on the "component" field.
func ComponentIn ¶
ComponentIn applies the In predicate on the "component" field.
func ComponentIsNil ¶
ComponentIsNil applies the IsNil predicate on the "component" field.
func ComponentLT ¶
ComponentLT applies the LT predicate on the "component" field.
func ComponentLTE ¶
ComponentLTE applies the LTE predicate on the "component" field.
func ComponentNEQ ¶
ComponentNEQ applies the NEQ predicate on the "component" field.
func ComponentNotIn ¶
ComponentNotIn applies the NotIn predicate on the "component" field.
func ComponentNotNil ¶
ComponentNotNil applies the NotNil predicate on the "component" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedByID ¶
CreatedByID applies equality check predicate on the "created_by_id" field. It's identical to CreatedByIDEQ.
func CreatedByIDEQ ¶
CreatedByIDEQ applies the EQ predicate on the "created_by_id" field.
func CreatedByIDGT ¶
CreatedByIDGT applies the GT predicate on the "created_by_id" field.
func CreatedByIDGTE ¶
CreatedByIDGTE applies the GTE predicate on the "created_by_id" field.
func CreatedByIDIn ¶
CreatedByIDIn applies the In predicate on the "created_by_id" field.
func CreatedByIDIsNil ¶
CreatedByIDIsNil applies the IsNil predicate on the "created_by_id" field.
func CreatedByIDLT ¶
CreatedByIDLT applies the LT predicate on the "created_by_id" field.
func CreatedByIDLTE ¶
CreatedByIDLTE applies the LTE predicate on the "created_by_id" field.
func CreatedByIDNEQ ¶
CreatedByIDNEQ applies the NEQ predicate on the "created_by_id" field.
func CreatedByIDNotIn ¶
CreatedByIDNotIn applies the NotIn predicate on the "created_by_id" field.
func CreatedByIDNotNil ¶
CreatedByIDNotNil applies the NotNil predicate on the "created_by_id" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedByID ¶
DeletedByID applies equality check predicate on the "deleted_by_id" field. It's identical to DeletedByIDEQ.
func DeletedByIDEQ ¶
DeletedByIDEQ applies the EQ predicate on the "deleted_by_id" field.
func DeletedByIDGT ¶
DeletedByIDGT applies the GT predicate on the "deleted_by_id" field.
func DeletedByIDGTE ¶
DeletedByIDGTE applies the GTE predicate on the "deleted_by_id" field.
func DeletedByIDIn ¶
DeletedByIDIn applies the In predicate on the "deleted_by_id" field.
func DeletedByIDIsNil ¶
DeletedByIDIsNil applies the IsNil predicate on the "deleted_by_id" field.
func DeletedByIDLT ¶
DeletedByIDLT applies the LT predicate on the "deleted_by_id" field.
func DeletedByIDLTE ¶
DeletedByIDLTE applies the LTE predicate on the "deleted_by_id" field.
func DeletedByIDNEQ ¶
DeletedByIDNEQ applies the NEQ predicate on the "deleted_by_id" field.
func DeletedByIDNotIn ¶
DeletedByIDNotIn applies the NotIn predicate on the "deleted_by_id" field.
func DeletedByIDNotNil ¶
DeletedByIDNotNil applies the NotNil predicate on the "deleted_by_id" field.
func HasChildren ¶
HasChildren applies the HasEdge predicate on the "children" edge.
func HasChildrenWith ¶
HasChildrenWith applies the HasEdge predicate on the "children" edge with a given conditions (other predicates).
func HasParentWith ¶
HasParentWith applies the HasEdge predicate on the "parent" edge with a given conditions (other predicates).
func HasRolesWith ¶
HasRolesWith applies the HasEdge predicate on the "roles" edge with a given conditions (other predicates).
func Hidden ¶
Hidden applies equality check predicate on the "hidden" field. It's identical to HiddenEQ.
func IconContains ¶
IconContains applies the Contains predicate on the "icon" field.
func IconContainsFold ¶
IconContainsFold applies the ContainsFold predicate on the "icon" field.
func IconEqualFold ¶
IconEqualFold applies the EqualFold predicate on the "icon" field.
func IconHasPrefix ¶
IconHasPrefix applies the HasPrefix predicate on the "icon" field.
func IconHasSuffix ¶
IconHasSuffix applies the HasSuffix predicate on the "icon" field.
func IconNotNil ¶
IconNotNil applies the NotNil predicate on the "icon" field.
func MetaNotNil ¶
MetaNotNil applies the NotNil predicate on the "meta" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func OwnerDomainID ¶
OwnerDomainID applies equality check predicate on the "owner_domain_id" field. It's identical to OwnerDomainIDEQ.
func OwnerDomainIDEQ ¶
OwnerDomainIDEQ applies the EQ predicate on the "owner_domain_id" field.
func OwnerDomainIDGT ¶
OwnerDomainIDGT applies the GT predicate on the "owner_domain_id" field.
func OwnerDomainIDGTE ¶
OwnerDomainIDGTE applies the GTE predicate on the "owner_domain_id" field.
func OwnerDomainIDIn ¶
OwnerDomainIDIn applies the In predicate on the "owner_domain_id" field.
func OwnerDomainIDIsNil ¶
OwnerDomainIDIsNil applies the IsNil predicate on the "owner_domain_id" field.
func OwnerDomainIDLT ¶
OwnerDomainIDLT applies the LT predicate on the "owner_domain_id" field.
func OwnerDomainIDLTE ¶
OwnerDomainIDLTE applies the LTE predicate on the "owner_domain_id" field.
func OwnerDomainIDNEQ ¶
OwnerDomainIDNEQ applies the NEQ predicate on the "owner_domain_id" field.
func OwnerDomainIDNotIn ¶
OwnerDomainIDNotIn applies the NotIn predicate on the "owner_domain_id" field.
func OwnerDomainIDNotNil ¶
OwnerDomainIDNotNil applies the NotNil predicate on the "owner_domain_id" field.
func ParamsIsNil ¶
ParamsIsNil applies the IsNil predicate on the "params" field.
func ParamsNotNil ¶
ParamsNotNil applies the NotNil predicate on the "params" field.
func ParentID ¶
ParentID applies equality check predicate on the "parent_id" field. It's identical to ParentIDEQ.
func ParentIDEQ ¶
ParentIDEQ applies the EQ predicate on the "parent_id" field.
func ParentIDIn ¶
ParentIDIn applies the In predicate on the "parent_id" field.
func ParentIDIsNil ¶
ParentIDIsNil applies the IsNil predicate on the "parent_id" field.
func ParentIDNEQ ¶
ParentIDNEQ applies the NEQ predicate on the "parent_id" field.
func ParentIDNotIn ¶
ParentIDNotIn applies the NotIn predicate on the "parent_id" field.
func ParentIDNotNil ¶
ParentIDNotNil applies the NotNil predicate on the "parent_id" field.
func PathContains ¶
PathContains applies the Contains predicate on the "path" field.
func PathContainsFold ¶
PathContainsFold applies the ContainsFold predicate on the "path" field.
func PathEqualFold ¶
PathEqualFold applies the EqualFold predicate on the "path" field.
func PathHasPrefix ¶
PathHasPrefix applies the HasPrefix predicate on the "path" field.
func PathHasSuffix ¶
PathHasSuffix applies the HasSuffix predicate on the "path" field.
func PublishedAt ¶
PublishedAt applies equality check predicate on the "published_at" field. It's identical to PublishedAtEQ.
func PublishedAtEQ ¶
PublishedAtEQ applies the EQ predicate on the "published_at" field.
func PublishedAtGT ¶
PublishedAtGT applies the GT predicate on the "published_at" field.
func PublishedAtGTE ¶
PublishedAtGTE applies the GTE predicate on the "published_at" field.
func PublishedAtIn ¶
PublishedAtIn applies the In predicate on the "published_at" field.
func PublishedAtIsNil ¶
PublishedAtIsNil applies the IsNil predicate on the "published_at" field.
func PublishedAtLT ¶
PublishedAtLT applies the LT predicate on the "published_at" field.
func PublishedAtLTE ¶
PublishedAtLTE applies the LTE predicate on the "published_at" field.
func PublishedAtNEQ ¶
PublishedAtNEQ applies the NEQ predicate on the "published_at" field.
func PublishedAtNotIn ¶
PublishedAtNotIn applies the NotIn predicate on the "published_at" field.
func PublishedAtNotNil ¶
PublishedAtNotNil applies the NotNil predicate on the "published_at" field.
func Redirect ¶
Redirect applies equality check predicate on the "redirect" field. It's identical to RedirectEQ.
func RedirectContains ¶
RedirectContains applies the Contains predicate on the "redirect" field.
func RedirectContainsFold ¶
RedirectContainsFold applies the ContainsFold predicate on the "redirect" field.
func RedirectEQ ¶
RedirectEQ applies the EQ predicate on the "redirect" field.
func RedirectEqualFold ¶
RedirectEqualFold applies the EqualFold predicate on the "redirect" field.
func RedirectGT ¶
RedirectGT applies the GT predicate on the "redirect" field.
func RedirectGTE ¶
RedirectGTE applies the GTE predicate on the "redirect" field.
func RedirectHasPrefix ¶
RedirectHasPrefix applies the HasPrefix predicate on the "redirect" field.
func RedirectHasSuffix ¶
RedirectHasSuffix applies the HasSuffix predicate on the "redirect" field.
func RedirectIn ¶
RedirectIn applies the In predicate on the "redirect" field.
func RedirectIsNil ¶
RedirectIsNil applies the IsNil predicate on the "redirect" field.
func RedirectLT ¶
RedirectLT applies the LT predicate on the "redirect" field.
func RedirectLTE ¶
RedirectLTE applies the LTE predicate on the "redirect" field.
func RedirectNEQ ¶
RedirectNEQ applies the NEQ predicate on the "redirect" field.
func RedirectNotIn ¶
RedirectNotIn applies the NotIn predicate on the "redirect" field.
func RedirectNotNil ¶
RedirectNotNil applies the NotNil predicate on the "redirect" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedByID ¶
UpdatedByID applies equality check predicate on the "updated_by_id" field. It's identical to UpdatedByIDEQ.
func UpdatedByIDEQ ¶
UpdatedByIDEQ applies the EQ predicate on the "updated_by_id" field.
func UpdatedByIDGT ¶
UpdatedByIDGT applies the GT predicate on the "updated_by_id" field.
func UpdatedByIDGTE ¶
UpdatedByIDGTE applies the GTE predicate on the "updated_by_id" field.
func UpdatedByIDIn ¶
UpdatedByIDIn applies the In predicate on the "updated_by_id" field.
func UpdatedByIDIsNil ¶
UpdatedByIDIsNil applies the IsNil predicate on the "updated_by_id" field.
func UpdatedByIDLT ¶
UpdatedByIDLT applies the LT predicate on the "updated_by_id" field.
func UpdatedByIDLTE ¶
UpdatedByIDLTE applies the LTE predicate on the "updated_by_id" field.
func UpdatedByIDNEQ ¶
UpdatedByIDNEQ applies the NEQ predicate on the "updated_by_id" field.
func UpdatedByIDNotIn ¶
UpdatedByIDNotIn applies the NotIn predicate on the "updated_by_id" field.
func UpdatedByIDNotNil ¶
UpdatedByIDNotNil applies the NotNil predicate on the "updated_by_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Menu queries.
func ByAffix ¶
func ByAffix(opts ...sql.OrderTermOption) OrderOption
ByAffix orders the results by the affix field.
func ByArchivedAt ¶
func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
ByArchivedAt orders the results by the archived_at field.
func ByChildren ¶
func ByChildren(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByChildren orders the results by children terms.
func ByChildrenCount ¶
func ByChildrenCount(opts ...sql.OrderTermOption) OrderOption
ByChildrenCount orders the results by children count.
func ByComponent ¶
func ByComponent(opts ...sql.OrderTermOption) OrderOption
ByComponent orders the results by the component field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedByID ¶
func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
ByCreatedByID orders the results by the created_by_id field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedByID ¶
func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
ByDeletedByID orders the results by the deleted_by_id field.
func ByHidden ¶
func ByHidden(opts ...sql.OrderTermOption) OrderOption
ByHidden orders the results by the hidden field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIcon ¶
func ByIcon(opts ...sql.OrderTermOption) OrderOption
ByIcon orders the results by the icon field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByOwnerDomainID ¶
func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption
ByOwnerDomainID orders the results by the owner_domain_id field.
func ByParentField ¶
func ByParentField(field string, opts ...sql.OrderTermOption) OrderOption
ByParentField orders the results by parent field.
func ByParentID ¶
func ByParentID(opts ...sql.OrderTermOption) OrderOption
ByParentID orders the results by the parent_id field.
func ByPath ¶
func ByPath(opts ...sql.OrderTermOption) OrderOption
ByPath orders the results by the path field.
func ByPublishedAt ¶
func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
ByPublishedAt orders the results by the published_at field.
func ByRedirect ¶
func ByRedirect(opts ...sql.OrderTermOption) OrderOption
ByRedirect orders the results by the redirect field.
func ByRoles ¶
func ByRoles(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByRoles orders the results by roles terms.
func ByRolesCount ¶
func ByRolesCount(opts ...sql.OrderTermOption) OrderOption
ByRolesCount orders the results by roles count.
func BySort ¶
func BySort(opts ...sql.OrderTermOption) OrderOption
BySort orders the results by the sort field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedByID ¶
func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
ByUpdatedByID orders the results by the updated_by_id field.