rolebinding

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 28, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the rolebinding type in the database.
	Label = "role_binding"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedByID holds the string denoting the created_by_id field in the database.
	FieldCreatedByID = "created_by_id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedByID holds the string denoting the updated_by_id field in the database.
	FieldUpdatedByID = "updated_by_id"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldDeletedByID holds the string denoting the deleted_by_id field in the database.
	FieldDeletedByID = "deleted_by_id"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldPublishedAt holds the string denoting the published_at field in the database.
	FieldPublishedAt = "published_at"
	// FieldArchivedAt holds the string denoting the archived_at field in the database.
	FieldArchivedAt = "archived_at"
	// FieldOwnerDomainID holds the string denoting the owner_domain_id field in the database.
	FieldOwnerDomainID = "owner_domain_id"
	// FieldSubjectType holds the string denoting the subject_type field in the database.
	FieldSubjectType = "subject_type"
	// FieldSubjectID holds the string denoting the subject_id field in the database.
	FieldSubjectID = "subject_id"
	// FieldRoleCode holds the string denoting the role_code field in the database.
	FieldRoleCode = "role_code"
	// FieldProjectID holds the string denoting the project_id field in the database.
	FieldProjectID = "project_id"
	// FieldScopeType holds the string denoting the scope_type field in the database.
	FieldScopeType = "scope_type"
	// FieldScopeValue holds the string denoting the scope_value field in the database.
	FieldScopeValue = "scope_value"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// Table holds the table name of the rolebinding in the database.
	Table = "role_bindings"
)
const DefaultScopeType = ScopeTypeCURRENT

ScopeTypeCURRENT is the default value of the ScopeType enum.

const DefaultStatus = StatusActive

StatusActive is the default value of the Status enum.

const DefaultSubjectType = SubjectTypeUser

SubjectTypeUser is the default value of the SubjectType enum.

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// RoleCodeValidator is a validator for the "role_code" field. It is called by the builders before save.
	RoleCodeValidator func(string) error
	// ScopeValueValidator is a validator for the "scope_value" field. It is called by the builders before save.
	ScopeValueValidator func(string) error
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for rolebinding fields.

Functions

func And

func And(predicates ...predicate.RoleBinding) predicate.RoleBinding

And groups predicates with the AND operator between them.

func ArchivedAt

func ArchivedAt(v time.Time) predicate.RoleBinding

ArchivedAt applies equality check predicate on the "archived_at" field. It's identical to ArchivedAtEQ.

func ArchivedAtEQ

func ArchivedAtEQ(v time.Time) predicate.RoleBinding

ArchivedAtEQ applies the EQ predicate on the "archived_at" field.

func ArchivedAtGT

func ArchivedAtGT(v time.Time) predicate.RoleBinding

ArchivedAtGT applies the GT predicate on the "archived_at" field.

func ArchivedAtGTE

func ArchivedAtGTE(v time.Time) predicate.RoleBinding

ArchivedAtGTE applies the GTE predicate on the "archived_at" field.

func ArchivedAtIn

func ArchivedAtIn(vs ...time.Time) predicate.RoleBinding

ArchivedAtIn applies the In predicate on the "archived_at" field.

func ArchivedAtIsNil

func ArchivedAtIsNil() predicate.RoleBinding

ArchivedAtIsNil applies the IsNil predicate on the "archived_at" field.

func ArchivedAtLT

func ArchivedAtLT(v time.Time) predicate.RoleBinding

ArchivedAtLT applies the LT predicate on the "archived_at" field.

func ArchivedAtLTE

func ArchivedAtLTE(v time.Time) predicate.RoleBinding

ArchivedAtLTE applies the LTE predicate on the "archived_at" field.

func ArchivedAtNEQ

func ArchivedAtNEQ(v time.Time) predicate.RoleBinding

ArchivedAtNEQ applies the NEQ predicate on the "archived_at" field.

func ArchivedAtNotIn

func ArchivedAtNotIn(vs ...time.Time) predicate.RoleBinding

ArchivedAtNotIn applies the NotIn predicate on the "archived_at" field.

func ArchivedAtNotNil

func ArchivedAtNotNil() predicate.RoleBinding

ArchivedAtNotNil applies the NotNil predicate on the "archived_at" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.RoleBinding

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.RoleBinding

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.RoleBinding

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.RoleBinding

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.RoleBinding

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.RoleBinding

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.RoleBinding

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.RoleBinding

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.RoleBinding

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.RoleBinding

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.RoleBinding

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedByID

func CreatedByID(v uuid.UUID) predicate.RoleBinding

CreatedByID applies equality check predicate on the "created_by_id" field. It's identical to CreatedByIDEQ.

func CreatedByIDEQ

func CreatedByIDEQ(v uuid.UUID) predicate.RoleBinding

CreatedByIDEQ applies the EQ predicate on the "created_by_id" field.

func CreatedByIDGT

func CreatedByIDGT(v uuid.UUID) predicate.RoleBinding

CreatedByIDGT applies the GT predicate on the "created_by_id" field.

func CreatedByIDGTE

func CreatedByIDGTE(v uuid.UUID) predicate.RoleBinding

CreatedByIDGTE applies the GTE predicate on the "created_by_id" field.

func CreatedByIDIn

func CreatedByIDIn(vs ...uuid.UUID) predicate.RoleBinding

CreatedByIDIn applies the In predicate on the "created_by_id" field.

func CreatedByIDIsNil

func CreatedByIDIsNil() predicate.RoleBinding

CreatedByIDIsNil applies the IsNil predicate on the "created_by_id" field.

func CreatedByIDLT

func CreatedByIDLT(v uuid.UUID) predicate.RoleBinding

CreatedByIDLT applies the LT predicate on the "created_by_id" field.

func CreatedByIDLTE

func CreatedByIDLTE(v uuid.UUID) predicate.RoleBinding

CreatedByIDLTE applies the LTE predicate on the "created_by_id" field.

func CreatedByIDNEQ

func CreatedByIDNEQ(v uuid.UUID) predicate.RoleBinding

CreatedByIDNEQ applies the NEQ predicate on the "created_by_id" field.

func CreatedByIDNotIn

func CreatedByIDNotIn(vs ...uuid.UUID) predicate.RoleBinding

CreatedByIDNotIn applies the NotIn predicate on the "created_by_id" field.

func CreatedByIDNotNil

func CreatedByIDNotNil() predicate.RoleBinding

CreatedByIDNotNil applies the NotNil predicate on the "created_by_id" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.RoleBinding

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.RoleBinding

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.RoleBinding

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.RoleBinding

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.RoleBinding

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.RoleBinding

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.RoleBinding

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.RoleBinding

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.RoleBinding

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.RoleBinding

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.RoleBinding

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedByID

func DeletedByID(v uuid.UUID) predicate.RoleBinding

DeletedByID applies equality check predicate on the "deleted_by_id" field. It's identical to DeletedByIDEQ.

func DeletedByIDEQ

func DeletedByIDEQ(v uuid.UUID) predicate.RoleBinding

DeletedByIDEQ applies the EQ predicate on the "deleted_by_id" field.

func DeletedByIDGT

func DeletedByIDGT(v uuid.UUID) predicate.RoleBinding

DeletedByIDGT applies the GT predicate on the "deleted_by_id" field.

func DeletedByIDGTE

func DeletedByIDGTE(v uuid.UUID) predicate.RoleBinding

DeletedByIDGTE applies the GTE predicate on the "deleted_by_id" field.

func DeletedByIDIn

func DeletedByIDIn(vs ...uuid.UUID) predicate.RoleBinding

DeletedByIDIn applies the In predicate on the "deleted_by_id" field.

func DeletedByIDIsNil

func DeletedByIDIsNil() predicate.RoleBinding

DeletedByIDIsNil applies the IsNil predicate on the "deleted_by_id" field.

func DeletedByIDLT

func DeletedByIDLT(v uuid.UUID) predicate.RoleBinding

DeletedByIDLT applies the LT predicate on the "deleted_by_id" field.

func DeletedByIDLTE

func DeletedByIDLTE(v uuid.UUID) predicate.RoleBinding

DeletedByIDLTE applies the LTE predicate on the "deleted_by_id" field.

func DeletedByIDNEQ

func DeletedByIDNEQ(v uuid.UUID) predicate.RoleBinding

DeletedByIDNEQ applies the NEQ predicate on the "deleted_by_id" field.

func DeletedByIDNotIn

func DeletedByIDNotIn(vs ...uuid.UUID) predicate.RoleBinding

DeletedByIDNotIn applies the NotIn predicate on the "deleted_by_id" field.

func DeletedByIDNotNil

func DeletedByIDNotNil() predicate.RoleBinding

DeletedByIDNotNil applies the NotNil predicate on the "deleted_by_id" field.

func ID

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.RoleBinding

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.RoleBinding

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.RoleBinding

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.RoleBinding

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.RoleBinding

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.RoleBinding

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.RoleBinding

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.RoleBinding

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.RoleBinding) predicate.RoleBinding

Or groups predicates with the OR operator between them.

func OwnerDomainID

func OwnerDomainID(v uuid.UUID) predicate.RoleBinding

OwnerDomainID applies equality check predicate on the "owner_domain_id" field. It's identical to OwnerDomainIDEQ.

func OwnerDomainIDEQ

func OwnerDomainIDEQ(v uuid.UUID) predicate.RoleBinding

OwnerDomainIDEQ applies the EQ predicate on the "owner_domain_id" field.

func OwnerDomainIDGT

func OwnerDomainIDGT(v uuid.UUID) predicate.RoleBinding

OwnerDomainIDGT applies the GT predicate on the "owner_domain_id" field.

func OwnerDomainIDGTE

func OwnerDomainIDGTE(v uuid.UUID) predicate.RoleBinding

OwnerDomainIDGTE applies the GTE predicate on the "owner_domain_id" field.

func OwnerDomainIDIn

func OwnerDomainIDIn(vs ...uuid.UUID) predicate.RoleBinding

OwnerDomainIDIn applies the In predicate on the "owner_domain_id" field.

func OwnerDomainIDIsNil

func OwnerDomainIDIsNil() predicate.RoleBinding

OwnerDomainIDIsNil applies the IsNil predicate on the "owner_domain_id" field.

func OwnerDomainIDLT

func OwnerDomainIDLT(v uuid.UUID) predicate.RoleBinding

OwnerDomainIDLT applies the LT predicate on the "owner_domain_id" field.

func OwnerDomainIDLTE

func OwnerDomainIDLTE(v uuid.UUID) predicate.RoleBinding

OwnerDomainIDLTE applies the LTE predicate on the "owner_domain_id" field.

func OwnerDomainIDNEQ

func OwnerDomainIDNEQ(v uuid.UUID) predicate.RoleBinding

OwnerDomainIDNEQ applies the NEQ predicate on the "owner_domain_id" field.

func OwnerDomainIDNotIn

func OwnerDomainIDNotIn(vs ...uuid.UUID) predicate.RoleBinding

OwnerDomainIDNotIn applies the NotIn predicate on the "owner_domain_id" field.

func OwnerDomainIDNotNil

func OwnerDomainIDNotNil() predicate.RoleBinding

OwnerDomainIDNotNil applies the NotNil predicate on the "owner_domain_id" field.

func ProjectID

func ProjectID(v uuid.UUID) predicate.RoleBinding

ProjectID applies equality check predicate on the "project_id" field. It's identical to ProjectIDEQ.

func ProjectIDEQ

func ProjectIDEQ(v uuid.UUID) predicate.RoleBinding

ProjectIDEQ applies the EQ predicate on the "project_id" field.

func ProjectIDGT

func ProjectIDGT(v uuid.UUID) predicate.RoleBinding

ProjectIDGT applies the GT predicate on the "project_id" field.

func ProjectIDGTE

func ProjectIDGTE(v uuid.UUID) predicate.RoleBinding

ProjectIDGTE applies the GTE predicate on the "project_id" field.

func ProjectIDIn

func ProjectIDIn(vs ...uuid.UUID) predicate.RoleBinding

ProjectIDIn applies the In predicate on the "project_id" field.

func ProjectIDIsNil

func ProjectIDIsNil() predicate.RoleBinding

ProjectIDIsNil applies the IsNil predicate on the "project_id" field.

func ProjectIDLT

func ProjectIDLT(v uuid.UUID) predicate.RoleBinding

ProjectIDLT applies the LT predicate on the "project_id" field.

func ProjectIDLTE

func ProjectIDLTE(v uuid.UUID) predicate.RoleBinding

ProjectIDLTE applies the LTE predicate on the "project_id" field.

func ProjectIDNEQ

func ProjectIDNEQ(v uuid.UUID) predicate.RoleBinding

ProjectIDNEQ applies the NEQ predicate on the "project_id" field.

func ProjectIDNotIn

func ProjectIDNotIn(vs ...uuid.UUID) predicate.RoleBinding

ProjectIDNotIn applies the NotIn predicate on the "project_id" field.

func ProjectIDNotNil

func ProjectIDNotNil() predicate.RoleBinding

ProjectIDNotNil applies the NotNil predicate on the "project_id" field.

func PublishedAt

func PublishedAt(v time.Time) predicate.RoleBinding

PublishedAt applies equality check predicate on the "published_at" field. It's identical to PublishedAtEQ.

func PublishedAtEQ

func PublishedAtEQ(v time.Time) predicate.RoleBinding

PublishedAtEQ applies the EQ predicate on the "published_at" field.

func PublishedAtGT

func PublishedAtGT(v time.Time) predicate.RoleBinding

PublishedAtGT applies the GT predicate on the "published_at" field.

func PublishedAtGTE

func PublishedAtGTE(v time.Time) predicate.RoleBinding

PublishedAtGTE applies the GTE predicate on the "published_at" field.

func PublishedAtIn

func PublishedAtIn(vs ...time.Time) predicate.RoleBinding

PublishedAtIn applies the In predicate on the "published_at" field.

func PublishedAtIsNil

func PublishedAtIsNil() predicate.RoleBinding

PublishedAtIsNil applies the IsNil predicate on the "published_at" field.

func PublishedAtLT

func PublishedAtLT(v time.Time) predicate.RoleBinding

PublishedAtLT applies the LT predicate on the "published_at" field.

func PublishedAtLTE

func PublishedAtLTE(v time.Time) predicate.RoleBinding

PublishedAtLTE applies the LTE predicate on the "published_at" field.

func PublishedAtNEQ

func PublishedAtNEQ(v time.Time) predicate.RoleBinding

PublishedAtNEQ applies the NEQ predicate on the "published_at" field.

func PublishedAtNotIn

func PublishedAtNotIn(vs ...time.Time) predicate.RoleBinding

PublishedAtNotIn applies the NotIn predicate on the "published_at" field.

func PublishedAtNotNil

func PublishedAtNotNil() predicate.RoleBinding

PublishedAtNotNil applies the NotNil predicate on the "published_at" field.

func RoleCode

func RoleCode(v string) predicate.RoleBinding

RoleCode applies equality check predicate on the "role_code" field. It's identical to RoleCodeEQ.

func RoleCodeContains

func RoleCodeContains(v string) predicate.RoleBinding

RoleCodeContains applies the Contains predicate on the "role_code" field.

func RoleCodeContainsFold

func RoleCodeContainsFold(v string) predicate.RoleBinding

RoleCodeContainsFold applies the ContainsFold predicate on the "role_code" field.

func RoleCodeEQ

func RoleCodeEQ(v string) predicate.RoleBinding

RoleCodeEQ applies the EQ predicate on the "role_code" field.

func RoleCodeEqualFold

func RoleCodeEqualFold(v string) predicate.RoleBinding

RoleCodeEqualFold applies the EqualFold predicate on the "role_code" field.

func RoleCodeGT

func RoleCodeGT(v string) predicate.RoleBinding

RoleCodeGT applies the GT predicate on the "role_code" field.

func RoleCodeGTE

func RoleCodeGTE(v string) predicate.RoleBinding

RoleCodeGTE applies the GTE predicate on the "role_code" field.

func RoleCodeHasPrefix

func RoleCodeHasPrefix(v string) predicate.RoleBinding

RoleCodeHasPrefix applies the HasPrefix predicate on the "role_code" field.

func RoleCodeHasSuffix

func RoleCodeHasSuffix(v string) predicate.RoleBinding

RoleCodeHasSuffix applies the HasSuffix predicate on the "role_code" field.

func RoleCodeIn

func RoleCodeIn(vs ...string) predicate.RoleBinding

RoleCodeIn applies the In predicate on the "role_code" field.

func RoleCodeLT

func RoleCodeLT(v string) predicate.RoleBinding

RoleCodeLT applies the LT predicate on the "role_code" field.

func RoleCodeLTE

func RoleCodeLTE(v string) predicate.RoleBinding

RoleCodeLTE applies the LTE predicate on the "role_code" field.

func RoleCodeNEQ

func RoleCodeNEQ(v string) predicate.RoleBinding

RoleCodeNEQ applies the NEQ predicate on the "role_code" field.

func RoleCodeNotIn

func RoleCodeNotIn(vs ...string) predicate.RoleBinding

RoleCodeNotIn applies the NotIn predicate on the "role_code" field.

func ScopeTypeEQ

func ScopeTypeEQ(v ScopeType) predicate.RoleBinding

ScopeTypeEQ applies the EQ predicate on the "scope_type" field.

func ScopeTypeIn

func ScopeTypeIn(vs ...ScopeType) predicate.RoleBinding

ScopeTypeIn applies the In predicate on the "scope_type" field.

func ScopeTypeNEQ

func ScopeTypeNEQ(v ScopeType) predicate.RoleBinding

ScopeTypeNEQ applies the NEQ predicate on the "scope_type" field.

func ScopeTypeNotIn

func ScopeTypeNotIn(vs ...ScopeType) predicate.RoleBinding

ScopeTypeNotIn applies the NotIn predicate on the "scope_type" field.

func ScopeTypeValidator

func ScopeTypeValidator(st ScopeType) error

ScopeTypeValidator is a validator for the "scope_type" field enum values. It is called by the builders before save.

func ScopeValue

func ScopeValue(v string) predicate.RoleBinding

ScopeValue applies equality check predicate on the "scope_value" field. It's identical to ScopeValueEQ.

func ScopeValueContains

func ScopeValueContains(v string) predicate.RoleBinding

ScopeValueContains applies the Contains predicate on the "scope_value" field.

func ScopeValueContainsFold

func ScopeValueContainsFold(v string) predicate.RoleBinding

ScopeValueContainsFold applies the ContainsFold predicate on the "scope_value" field.

func ScopeValueEQ

func ScopeValueEQ(v string) predicate.RoleBinding

ScopeValueEQ applies the EQ predicate on the "scope_value" field.

func ScopeValueEqualFold

func ScopeValueEqualFold(v string) predicate.RoleBinding

ScopeValueEqualFold applies the EqualFold predicate on the "scope_value" field.

func ScopeValueGT

func ScopeValueGT(v string) predicate.RoleBinding

ScopeValueGT applies the GT predicate on the "scope_value" field.

func ScopeValueGTE

func ScopeValueGTE(v string) predicate.RoleBinding

ScopeValueGTE applies the GTE predicate on the "scope_value" field.

func ScopeValueHasPrefix

func ScopeValueHasPrefix(v string) predicate.RoleBinding

ScopeValueHasPrefix applies the HasPrefix predicate on the "scope_value" field.

func ScopeValueHasSuffix

func ScopeValueHasSuffix(v string) predicate.RoleBinding

ScopeValueHasSuffix applies the HasSuffix predicate on the "scope_value" field.

func ScopeValueIn

func ScopeValueIn(vs ...string) predicate.RoleBinding

ScopeValueIn applies the In predicate on the "scope_value" field.

func ScopeValueIsNil

func ScopeValueIsNil() predicate.RoleBinding

ScopeValueIsNil applies the IsNil predicate on the "scope_value" field.

func ScopeValueLT

func ScopeValueLT(v string) predicate.RoleBinding

ScopeValueLT applies the LT predicate on the "scope_value" field.

func ScopeValueLTE

func ScopeValueLTE(v string) predicate.RoleBinding

ScopeValueLTE applies the LTE predicate on the "scope_value" field.

func ScopeValueNEQ

func ScopeValueNEQ(v string) predicate.RoleBinding

ScopeValueNEQ applies the NEQ predicate on the "scope_value" field.

func ScopeValueNotIn

func ScopeValueNotIn(vs ...string) predicate.RoleBinding

ScopeValueNotIn applies the NotIn predicate on the "scope_value" field.

func ScopeValueNotNil

func ScopeValueNotNil() predicate.RoleBinding

ScopeValueNotNil applies the NotNil predicate on the "scope_value" field.

func StatusEQ

func StatusEQ(v Status) predicate.RoleBinding

StatusEQ applies the EQ predicate on the "status" field.

func StatusIn

func StatusIn(vs ...Status) predicate.RoleBinding

StatusIn applies the In predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v Status) predicate.RoleBinding

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...Status) predicate.RoleBinding

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusValidator

func StatusValidator(s Status) error

StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.

func SubjectID

func SubjectID(v uuid.UUID) predicate.RoleBinding

SubjectID applies equality check predicate on the "subject_id" field. It's identical to SubjectIDEQ.

func SubjectIDEQ

func SubjectIDEQ(v uuid.UUID) predicate.RoleBinding

SubjectIDEQ applies the EQ predicate on the "subject_id" field.

func SubjectIDGT

func SubjectIDGT(v uuid.UUID) predicate.RoleBinding

SubjectIDGT applies the GT predicate on the "subject_id" field.

func SubjectIDGTE

func SubjectIDGTE(v uuid.UUID) predicate.RoleBinding

SubjectIDGTE applies the GTE predicate on the "subject_id" field.

func SubjectIDIn

func SubjectIDIn(vs ...uuid.UUID) predicate.RoleBinding

SubjectIDIn applies the In predicate on the "subject_id" field.

func SubjectIDLT

func SubjectIDLT(v uuid.UUID) predicate.RoleBinding

SubjectIDLT applies the LT predicate on the "subject_id" field.

func SubjectIDLTE

func SubjectIDLTE(v uuid.UUID) predicate.RoleBinding

SubjectIDLTE applies the LTE predicate on the "subject_id" field.

func SubjectIDNEQ

func SubjectIDNEQ(v uuid.UUID) predicate.RoleBinding

SubjectIDNEQ applies the NEQ predicate on the "subject_id" field.

func SubjectIDNotIn

func SubjectIDNotIn(vs ...uuid.UUID) predicate.RoleBinding

SubjectIDNotIn applies the NotIn predicate on the "subject_id" field.

func SubjectTypeEQ

func SubjectTypeEQ(v SubjectType) predicate.RoleBinding

SubjectTypeEQ applies the EQ predicate on the "subject_type" field.

func SubjectTypeIn

func SubjectTypeIn(vs ...SubjectType) predicate.RoleBinding

SubjectTypeIn applies the In predicate on the "subject_type" field.

func SubjectTypeNEQ

func SubjectTypeNEQ(v SubjectType) predicate.RoleBinding

SubjectTypeNEQ applies the NEQ predicate on the "subject_type" field.

func SubjectTypeNotIn

func SubjectTypeNotIn(vs ...SubjectType) predicate.RoleBinding

SubjectTypeNotIn applies the NotIn predicate on the "subject_type" field.

func SubjectTypeValidator

func SubjectTypeValidator(st SubjectType) error

SubjectTypeValidator is a validator for the "subject_type" field enum values. It is called by the builders before save.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.RoleBinding

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.RoleBinding

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.RoleBinding

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.RoleBinding

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.RoleBinding

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.RoleBinding

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.RoleBinding

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.RoleBinding

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.RoleBinding

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.RoleBinding

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.RoleBinding

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedByID

func UpdatedByID(v uuid.UUID) predicate.RoleBinding

UpdatedByID applies equality check predicate on the "updated_by_id" field. It's identical to UpdatedByIDEQ.

func UpdatedByIDEQ

func UpdatedByIDEQ(v uuid.UUID) predicate.RoleBinding

UpdatedByIDEQ applies the EQ predicate on the "updated_by_id" field.

func UpdatedByIDGT

func UpdatedByIDGT(v uuid.UUID) predicate.RoleBinding

UpdatedByIDGT applies the GT predicate on the "updated_by_id" field.

func UpdatedByIDGTE

func UpdatedByIDGTE(v uuid.UUID) predicate.RoleBinding

UpdatedByIDGTE applies the GTE predicate on the "updated_by_id" field.

func UpdatedByIDIn

func UpdatedByIDIn(vs ...uuid.UUID) predicate.RoleBinding

UpdatedByIDIn applies the In predicate on the "updated_by_id" field.

func UpdatedByIDIsNil

func UpdatedByIDIsNil() predicate.RoleBinding

UpdatedByIDIsNil applies the IsNil predicate on the "updated_by_id" field.

func UpdatedByIDLT

func UpdatedByIDLT(v uuid.UUID) predicate.RoleBinding

UpdatedByIDLT applies the LT predicate on the "updated_by_id" field.

func UpdatedByIDLTE

func UpdatedByIDLTE(v uuid.UUID) predicate.RoleBinding

UpdatedByIDLTE applies the LTE predicate on the "updated_by_id" field.

func UpdatedByIDNEQ

func UpdatedByIDNEQ(v uuid.UUID) predicate.RoleBinding

UpdatedByIDNEQ applies the NEQ predicate on the "updated_by_id" field.

func UpdatedByIDNotIn

func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.RoleBinding

UpdatedByIDNotIn applies the NotIn predicate on the "updated_by_id" field.

func UpdatedByIDNotNil

func UpdatedByIDNotNil() predicate.RoleBinding

UpdatedByIDNotNil applies the NotNil predicate on the "updated_by_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the RoleBinding queries.

func ByArchivedAt

func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption

ByArchivedAt orders the results by the archived_at field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedByID

func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption

ByCreatedByID orders the results by the created_by_id field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedByID

func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption

ByDeletedByID orders the results by the deleted_by_id field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByOwnerDomainID

func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption

ByOwnerDomainID orders the results by the owner_domain_id field.

func ByProjectID

func ByProjectID(opts ...sql.OrderTermOption) OrderOption

ByProjectID orders the results by the project_id field.

func ByPublishedAt

func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption

ByPublishedAt orders the results by the published_at field.

func ByRoleCode

func ByRoleCode(opts ...sql.OrderTermOption) OrderOption

ByRoleCode orders the results by the role_code field.

func ByScopeType

func ByScopeType(opts ...sql.OrderTermOption) OrderOption

ByScopeType orders the results by the scope_type field.

func ByScopeValue

func ByScopeValue(opts ...sql.OrderTermOption) OrderOption

ByScopeValue orders the results by the scope_value field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func BySubjectID

func BySubjectID(opts ...sql.OrderTermOption) OrderOption

BySubjectID orders the results by the subject_id field.

func BySubjectType

func BySubjectType(opts ...sql.OrderTermOption) OrderOption

BySubjectType orders the results by the subject_type field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedByID

func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption

ByUpdatedByID orders the results by the updated_by_id field.

type ScopeType

type ScopeType string

ScopeType defines the type for the "scope_type" enum field.

const (
	ScopeTypeCURRENT      ScopeType = "CURRENT"
	ScopeTypeDESCENDANTS  ScopeType = "DESCENDANTS"
	ScopeTypeASSIGNED_SET ScopeType = "ASSIGNED_SET"
)

ScopeType values.

func (ScopeType) String

func (st ScopeType) String() string

type Status

type Status string

Status defines the type for the "status" enum field.

const (
	StatusActive   Status = "active"
	StatusInactive Status = "inactive"
)

Status values.

func (Status) String

func (s Status) String() string

type SubjectType

type SubjectType string

SubjectType defines the type for the "subject_type" enum field.

const (
	SubjectTypeUser           SubjectType = "user"
	SubjectTypeServiceAccount SubjectType = "service_account"
)

SubjectType values.

func (SubjectType) String

func (st SubjectType) String() string

Jump to