Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Session) predicate.Session
- func ArchivedAt(v time.Time) predicate.Session
- func ArchivedAtEQ(v time.Time) predicate.Session
- func ArchivedAtGT(v time.Time) predicate.Session
- func ArchivedAtGTE(v time.Time) predicate.Session
- func ArchivedAtIn(vs ...time.Time) predicate.Session
- func ArchivedAtIsNil() predicate.Session
- func ArchivedAtLT(v time.Time) predicate.Session
- func ArchivedAtLTE(v time.Time) predicate.Session
- func ArchivedAtNEQ(v time.Time) predicate.Session
- func ArchivedAtNotIn(vs ...time.Time) predicate.Session
- func ArchivedAtNotNil() predicate.Session
- func CreatedAt(v time.Time) predicate.Session
- func CreatedAtEQ(v time.Time) predicate.Session
- func CreatedAtGT(v time.Time) predicate.Session
- func CreatedAtGTE(v time.Time) predicate.Session
- func CreatedAtIn(vs ...time.Time) predicate.Session
- func CreatedAtIsNil() predicate.Session
- func CreatedAtLT(v time.Time) predicate.Session
- func CreatedAtLTE(v time.Time) predicate.Session
- func CreatedAtNEQ(v time.Time) predicate.Session
- func CreatedAtNotIn(vs ...time.Time) predicate.Session
- func CreatedAtNotNil() predicate.Session
- func CreatedByID(v uuid.UUID) predicate.Session
- func CreatedByIDEQ(v uuid.UUID) predicate.Session
- func CreatedByIDGT(v uuid.UUID) predicate.Session
- func CreatedByIDGTE(v uuid.UUID) predicate.Session
- func CreatedByIDIn(vs ...uuid.UUID) predicate.Session
- func CreatedByIDIsNil() predicate.Session
- func CreatedByIDLT(v uuid.UUID) predicate.Session
- func CreatedByIDLTE(v uuid.UUID) predicate.Session
- func CreatedByIDNEQ(v uuid.UUID) predicate.Session
- func CreatedByIDNotIn(vs ...uuid.UUID) predicate.Session
- func CreatedByIDNotNil() predicate.Session
- func DeletedAt(v time.Time) predicate.Session
- func DeletedAtEQ(v time.Time) predicate.Session
- func DeletedAtGT(v time.Time) predicate.Session
- func DeletedAtGTE(v time.Time) predicate.Session
- func DeletedAtIn(vs ...time.Time) predicate.Session
- func DeletedAtIsNil() predicate.Session
- func DeletedAtLT(v time.Time) predicate.Session
- func DeletedAtLTE(v time.Time) predicate.Session
- func DeletedAtNEQ(v time.Time) predicate.Session
- func DeletedAtNotIn(vs ...time.Time) predicate.Session
- func DeletedAtNotNil() predicate.Session
- func DeletedByID(v uuid.UUID) predicate.Session
- func DeletedByIDEQ(v uuid.UUID) predicate.Session
- func DeletedByIDGT(v uuid.UUID) predicate.Session
- func DeletedByIDGTE(v uuid.UUID) predicate.Session
- func DeletedByIDIn(vs ...uuid.UUID) predicate.Session
- func DeletedByIDIsNil() predicate.Session
- func DeletedByIDLT(v uuid.UUID) predicate.Session
- func DeletedByIDLTE(v uuid.UUID) predicate.Session
- func DeletedByIDNEQ(v uuid.UUID) predicate.Session
- func DeletedByIDNotIn(vs ...uuid.UUID) predicate.Session
- func DeletedByIDNotNil() predicate.Session
- func ExpiresAt(v time.Time) predicate.Session
- func ExpiresAtEQ(v time.Time) predicate.Session
- func ExpiresAtGT(v time.Time) predicate.Session
- func ExpiresAtGTE(v time.Time) predicate.Session
- func ExpiresAtIn(vs ...time.Time) predicate.Session
- func ExpiresAtLT(v time.Time) predicate.Session
- func ExpiresAtLTE(v time.Time) predicate.Session
- func ExpiresAtNEQ(v time.Time) predicate.Session
- func ExpiresAtNotIn(vs ...time.Time) predicate.Session
- func HasUser() predicate.Session
- func HasUserWith(preds ...predicate.User) predicate.Session
- func ID(id uuid.UUID) predicate.Session
- func IDEQ(id uuid.UUID) predicate.Session
- func IDGT(id uuid.UUID) predicate.Session
- func IDGTE(id uuid.UUID) predicate.Session
- func IDIn(ids ...uuid.UUID) predicate.Session
- func IDLT(id uuid.UUID) predicate.Session
- func IDLTE(id uuid.UUID) predicate.Session
- func IDNEQ(id uuid.UUID) predicate.Session
- func IDNotIn(ids ...uuid.UUID) predicate.Session
- func IPAddress(v string) predicate.Session
- func IPAddressContains(v string) predicate.Session
- func IPAddressContainsFold(v string) predicate.Session
- func IPAddressEQ(v string) predicate.Session
- func IPAddressEqualFold(v string) predicate.Session
- func IPAddressGT(v string) predicate.Session
- func IPAddressGTE(v string) predicate.Session
- func IPAddressHasPrefix(v string) predicate.Session
- func IPAddressHasSuffix(v string) predicate.Session
- func IPAddressIn(vs ...string) predicate.Session
- func IPAddressIsNil() predicate.Session
- func IPAddressLT(v string) predicate.Session
- func IPAddressLTE(v string) predicate.Session
- func IPAddressNEQ(v string) predicate.Session
- func IPAddressNotIn(vs ...string) predicate.Session
- func IPAddressNotNil() predicate.Session
- func IsRevoked(v bool) predicate.Session
- func IsRevokedEQ(v bool) predicate.Session
- func IsRevokedNEQ(v bool) predicate.Session
- func Not(p predicate.Session) predicate.Session
- func Or(predicates ...predicate.Session) predicate.Session
- func OwnerDomainID(v uuid.UUID) predicate.Session
- func OwnerDomainIDEQ(v uuid.UUID) predicate.Session
- func OwnerDomainIDGT(v uuid.UUID) predicate.Session
- func OwnerDomainIDGTE(v uuid.UUID) predicate.Session
- func OwnerDomainIDIn(vs ...uuid.UUID) predicate.Session
- func OwnerDomainIDIsNil() predicate.Session
- func OwnerDomainIDLT(v uuid.UUID) predicate.Session
- func OwnerDomainIDLTE(v uuid.UUID) predicate.Session
- func OwnerDomainIDNEQ(v uuid.UUID) predicate.Session
- func OwnerDomainIDNotIn(vs ...uuid.UUID) predicate.Session
- func OwnerDomainIDNotNil() predicate.Session
- func PublishedAt(v time.Time) predicate.Session
- func PublishedAtEQ(v time.Time) predicate.Session
- func PublishedAtGT(v time.Time) predicate.Session
- func PublishedAtGTE(v time.Time) predicate.Session
- func PublishedAtIn(vs ...time.Time) predicate.Session
- func PublishedAtIsNil() predicate.Session
- func PublishedAtLT(v time.Time) predicate.Session
- func PublishedAtLTE(v time.Time) predicate.Session
- func PublishedAtNEQ(v time.Time) predicate.Session
- func PublishedAtNotIn(vs ...time.Time) predicate.Session
- func PublishedAtNotNil() predicate.Session
- func TokenHash(v string) predicate.Session
- func TokenHashContains(v string) predicate.Session
- func TokenHashContainsFold(v string) predicate.Session
- func TokenHashEQ(v string) predicate.Session
- func TokenHashEqualFold(v string) predicate.Session
- func TokenHashGT(v string) predicate.Session
- func TokenHashGTE(v string) predicate.Session
- func TokenHashHasPrefix(v string) predicate.Session
- func TokenHashHasSuffix(v string) predicate.Session
- func TokenHashIn(vs ...string) predicate.Session
- func TokenHashLT(v string) predicate.Session
- func TokenHashLTE(v string) predicate.Session
- func TokenHashNEQ(v string) predicate.Session
- func TokenHashNotIn(vs ...string) predicate.Session
- func UpdatedAt(v time.Time) predicate.Session
- func UpdatedAtEQ(v time.Time) predicate.Session
- func UpdatedAtGT(v time.Time) predicate.Session
- func UpdatedAtGTE(v time.Time) predicate.Session
- func UpdatedAtIn(vs ...time.Time) predicate.Session
- func UpdatedAtIsNil() predicate.Session
- func UpdatedAtLT(v time.Time) predicate.Session
- func UpdatedAtLTE(v time.Time) predicate.Session
- func UpdatedAtNEQ(v time.Time) predicate.Session
- func UpdatedAtNotIn(vs ...time.Time) predicate.Session
- func UpdatedAtNotNil() predicate.Session
- func UpdatedByID(v uuid.UUID) predicate.Session
- func UpdatedByIDEQ(v uuid.UUID) predicate.Session
- func UpdatedByIDGT(v uuid.UUID) predicate.Session
- func UpdatedByIDGTE(v uuid.UUID) predicate.Session
- func UpdatedByIDIn(vs ...uuid.UUID) predicate.Session
- func UpdatedByIDIsNil() predicate.Session
- func UpdatedByIDLT(v uuid.UUID) predicate.Session
- func UpdatedByIDLTE(v uuid.UUID) predicate.Session
- func UpdatedByIDNEQ(v uuid.UUID) predicate.Session
- func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.Session
- func UpdatedByIDNotNil() predicate.Session
- func UserAgent(v string) predicate.Session
- func UserAgentContains(v string) predicate.Session
- func UserAgentContainsFold(v string) predicate.Session
- func UserAgentEQ(v string) predicate.Session
- func UserAgentEqualFold(v string) predicate.Session
- func UserAgentGT(v string) predicate.Session
- func UserAgentGTE(v string) predicate.Session
- func UserAgentHasPrefix(v string) predicate.Session
- func UserAgentHasSuffix(v string) predicate.Session
- func UserAgentIn(vs ...string) predicate.Session
- func UserAgentIsNil() predicate.Session
- func UserAgentLT(v string) predicate.Session
- func UserAgentLTE(v string) predicate.Session
- func UserAgentNEQ(v string) predicate.Session
- func UserAgentNotIn(vs ...string) predicate.Session
- func UserAgentNotNil() predicate.Session
- func ValidColumn(column string) bool
- type OrderOption
- func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
- func ByExpiresAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIPAddress(opts ...sql.OrderTermOption) OrderOption
- func ByIsRevoked(opts ...sql.OrderTermOption) OrderOption
- func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption
- func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
- func ByTokenHash(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
- func ByUser(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByUserAgent(opts ...sql.OrderTermOption) OrderOption
- func ByUserCount(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the session type in the database. Label = "session" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedByID holds the string denoting the created_by_id field in the database. FieldCreatedByID = "created_by_id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedByID holds the string denoting the updated_by_id field in the database. FieldUpdatedByID = "updated_by_id" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedByID holds the string denoting the deleted_by_id field in the database. FieldDeletedByID = "deleted_by_id" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldPublishedAt holds the string denoting the published_at field in the database. FieldPublishedAt = "published_at" // FieldArchivedAt holds the string denoting the archived_at field in the database. FieldArchivedAt = "archived_at" // FieldOwnerDomainID holds the string denoting the owner_domain_id field in the database. FieldOwnerDomainID = "owner_domain_id" // FieldTokenHash holds the string denoting the token_hash field in the database. FieldTokenHash = "token_hash" // FieldExpiresAt holds the string denoting the expires_at field in the database. FieldExpiresAt = "expires_at" // FieldIPAddress holds the string denoting the ip_address field in the database. FieldIPAddress = "ip_address" // FieldUserAgent holds the string denoting the user_agent field in the database. FieldUserAgent = "user_agent" // FieldIsRevoked holds the string denoting the is_revoked field in the database. FieldIsRevoked = "is_revoked" // EdgeUser holds the string denoting the user edge name in mutations. EdgeUser = "user" // Table holds the table name of the session in the database. Table = "sessions" // UserTable is the table that holds the user relation/edge. The primary key declared below. UserTable = "user_sessions" // UserInverseTable is the table name for the User entity. // It exists in this package in order to avoid circular dependency with the "user" package. UserInverseTable = "users" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // TokenHashValidator is a validator for the "token_hash" field. It is called by the builders before save. TokenHashValidator func(string) error // DefaultIsRevoked holds the default value on creation for the "is_revoked" field. DefaultIsRevoked bool // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldCreatedByID, FieldCreatedAt, FieldUpdatedByID, FieldUpdatedAt, FieldDeletedByID, FieldDeletedAt, FieldPublishedAt, FieldArchivedAt, FieldOwnerDomainID, FieldTokenHash, FieldExpiresAt, FieldIPAddress, FieldUserAgent, FieldIsRevoked, }
Columns holds all SQL columns for session fields.
var ( // UserPrimaryKey and UserColumn2 are the table columns denoting the // primary key for the user relation (M2M). UserPrimaryKey = []string{"user_id", "session_id"} )
Functions ¶
func ArchivedAt ¶
ArchivedAt applies equality check predicate on the "archived_at" field. It's identical to ArchivedAtEQ.
func ArchivedAtEQ ¶
ArchivedAtEQ applies the EQ predicate on the "archived_at" field.
func ArchivedAtGT ¶
ArchivedAtGT applies the GT predicate on the "archived_at" field.
func ArchivedAtGTE ¶
ArchivedAtGTE applies the GTE predicate on the "archived_at" field.
func ArchivedAtIn ¶
ArchivedAtIn applies the In predicate on the "archived_at" field.
func ArchivedAtIsNil ¶
ArchivedAtIsNil applies the IsNil predicate on the "archived_at" field.
func ArchivedAtLT ¶
ArchivedAtLT applies the LT predicate on the "archived_at" field.
func ArchivedAtLTE ¶
ArchivedAtLTE applies the LTE predicate on the "archived_at" field.
func ArchivedAtNEQ ¶
ArchivedAtNEQ applies the NEQ predicate on the "archived_at" field.
func ArchivedAtNotIn ¶
ArchivedAtNotIn applies the NotIn predicate on the "archived_at" field.
func ArchivedAtNotNil ¶
ArchivedAtNotNil applies the NotNil predicate on the "archived_at" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedByID ¶
CreatedByID applies equality check predicate on the "created_by_id" field. It's identical to CreatedByIDEQ.
func CreatedByIDEQ ¶
CreatedByIDEQ applies the EQ predicate on the "created_by_id" field.
func CreatedByIDGT ¶
CreatedByIDGT applies the GT predicate on the "created_by_id" field.
func CreatedByIDGTE ¶
CreatedByIDGTE applies the GTE predicate on the "created_by_id" field.
func CreatedByIDIn ¶
CreatedByIDIn applies the In predicate on the "created_by_id" field.
func CreatedByIDIsNil ¶
CreatedByIDIsNil applies the IsNil predicate on the "created_by_id" field.
func CreatedByIDLT ¶
CreatedByIDLT applies the LT predicate on the "created_by_id" field.
func CreatedByIDLTE ¶
CreatedByIDLTE applies the LTE predicate on the "created_by_id" field.
func CreatedByIDNEQ ¶
CreatedByIDNEQ applies the NEQ predicate on the "created_by_id" field.
func CreatedByIDNotIn ¶
CreatedByIDNotIn applies the NotIn predicate on the "created_by_id" field.
func CreatedByIDNotNil ¶
CreatedByIDNotNil applies the NotNil predicate on the "created_by_id" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedByID ¶
DeletedByID applies equality check predicate on the "deleted_by_id" field. It's identical to DeletedByIDEQ.
func DeletedByIDEQ ¶
DeletedByIDEQ applies the EQ predicate on the "deleted_by_id" field.
func DeletedByIDGT ¶
DeletedByIDGT applies the GT predicate on the "deleted_by_id" field.
func DeletedByIDGTE ¶
DeletedByIDGTE applies the GTE predicate on the "deleted_by_id" field.
func DeletedByIDIn ¶
DeletedByIDIn applies the In predicate on the "deleted_by_id" field.
func DeletedByIDIsNil ¶
DeletedByIDIsNil applies the IsNil predicate on the "deleted_by_id" field.
func DeletedByIDLT ¶
DeletedByIDLT applies the LT predicate on the "deleted_by_id" field.
func DeletedByIDLTE ¶
DeletedByIDLTE applies the LTE predicate on the "deleted_by_id" field.
func DeletedByIDNEQ ¶
DeletedByIDNEQ applies the NEQ predicate on the "deleted_by_id" field.
func DeletedByIDNotIn ¶
DeletedByIDNotIn applies the NotIn predicate on the "deleted_by_id" field.
func DeletedByIDNotNil ¶
DeletedByIDNotNil applies the NotNil predicate on the "deleted_by_id" field.
func ExpiresAt ¶
ExpiresAt applies equality check predicate on the "expires_at" field. It's identical to ExpiresAtEQ.
func ExpiresAtEQ ¶
ExpiresAtEQ applies the EQ predicate on the "expires_at" field.
func ExpiresAtGT ¶
ExpiresAtGT applies the GT predicate on the "expires_at" field.
func ExpiresAtGTE ¶
ExpiresAtGTE applies the GTE predicate on the "expires_at" field.
func ExpiresAtIn ¶
ExpiresAtIn applies the In predicate on the "expires_at" field.
func ExpiresAtLT ¶
ExpiresAtLT applies the LT predicate on the "expires_at" field.
func ExpiresAtLTE ¶
ExpiresAtLTE applies the LTE predicate on the "expires_at" field.
func ExpiresAtNEQ ¶
ExpiresAtNEQ applies the NEQ predicate on the "expires_at" field.
func ExpiresAtNotIn ¶
ExpiresAtNotIn applies the NotIn predicate on the "expires_at" field.
func HasUserWith ¶
HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).
func IPAddress ¶
IPAddress applies equality check predicate on the "ip_address" field. It's identical to IPAddressEQ.
func IPAddressContains ¶
IPAddressContains applies the Contains predicate on the "ip_address" field.
func IPAddressContainsFold ¶
IPAddressContainsFold applies the ContainsFold predicate on the "ip_address" field.
func IPAddressEQ ¶
IPAddressEQ applies the EQ predicate on the "ip_address" field.
func IPAddressEqualFold ¶
IPAddressEqualFold applies the EqualFold predicate on the "ip_address" field.
func IPAddressGT ¶
IPAddressGT applies the GT predicate on the "ip_address" field.
func IPAddressGTE ¶
IPAddressGTE applies the GTE predicate on the "ip_address" field.
func IPAddressHasPrefix ¶
IPAddressHasPrefix applies the HasPrefix predicate on the "ip_address" field.
func IPAddressHasSuffix ¶
IPAddressHasSuffix applies the HasSuffix predicate on the "ip_address" field.
func IPAddressIn ¶
IPAddressIn applies the In predicate on the "ip_address" field.
func IPAddressIsNil ¶
IPAddressIsNil applies the IsNil predicate on the "ip_address" field.
func IPAddressLT ¶
IPAddressLT applies the LT predicate on the "ip_address" field.
func IPAddressLTE ¶
IPAddressLTE applies the LTE predicate on the "ip_address" field.
func IPAddressNEQ ¶
IPAddressNEQ applies the NEQ predicate on the "ip_address" field.
func IPAddressNotIn ¶
IPAddressNotIn applies the NotIn predicate on the "ip_address" field.
func IPAddressNotNil ¶
IPAddressNotNil applies the NotNil predicate on the "ip_address" field.
func IsRevoked ¶
IsRevoked applies equality check predicate on the "is_revoked" field. It's identical to IsRevokedEQ.
func IsRevokedEQ ¶
IsRevokedEQ applies the EQ predicate on the "is_revoked" field.
func IsRevokedNEQ ¶
IsRevokedNEQ applies the NEQ predicate on the "is_revoked" field.
func OwnerDomainID ¶
OwnerDomainID applies equality check predicate on the "owner_domain_id" field. It's identical to OwnerDomainIDEQ.
func OwnerDomainIDEQ ¶
OwnerDomainIDEQ applies the EQ predicate on the "owner_domain_id" field.
func OwnerDomainIDGT ¶
OwnerDomainIDGT applies the GT predicate on the "owner_domain_id" field.
func OwnerDomainIDGTE ¶
OwnerDomainIDGTE applies the GTE predicate on the "owner_domain_id" field.
func OwnerDomainIDIn ¶
OwnerDomainIDIn applies the In predicate on the "owner_domain_id" field.
func OwnerDomainIDIsNil ¶
OwnerDomainIDIsNil applies the IsNil predicate on the "owner_domain_id" field.
func OwnerDomainIDLT ¶
OwnerDomainIDLT applies the LT predicate on the "owner_domain_id" field.
func OwnerDomainIDLTE ¶
OwnerDomainIDLTE applies the LTE predicate on the "owner_domain_id" field.
func OwnerDomainIDNEQ ¶
OwnerDomainIDNEQ applies the NEQ predicate on the "owner_domain_id" field.
func OwnerDomainIDNotIn ¶
OwnerDomainIDNotIn applies the NotIn predicate on the "owner_domain_id" field.
func OwnerDomainIDNotNil ¶
OwnerDomainIDNotNil applies the NotNil predicate on the "owner_domain_id" field.
func PublishedAt ¶
PublishedAt applies equality check predicate on the "published_at" field. It's identical to PublishedAtEQ.
func PublishedAtEQ ¶
PublishedAtEQ applies the EQ predicate on the "published_at" field.
func PublishedAtGT ¶
PublishedAtGT applies the GT predicate on the "published_at" field.
func PublishedAtGTE ¶
PublishedAtGTE applies the GTE predicate on the "published_at" field.
func PublishedAtIn ¶
PublishedAtIn applies the In predicate on the "published_at" field.
func PublishedAtIsNil ¶
PublishedAtIsNil applies the IsNil predicate on the "published_at" field.
func PublishedAtLT ¶
PublishedAtLT applies the LT predicate on the "published_at" field.
func PublishedAtLTE ¶
PublishedAtLTE applies the LTE predicate on the "published_at" field.
func PublishedAtNEQ ¶
PublishedAtNEQ applies the NEQ predicate on the "published_at" field.
func PublishedAtNotIn ¶
PublishedAtNotIn applies the NotIn predicate on the "published_at" field.
func PublishedAtNotNil ¶
PublishedAtNotNil applies the NotNil predicate on the "published_at" field.
func TokenHash ¶
TokenHash applies equality check predicate on the "token_hash" field. It's identical to TokenHashEQ.
func TokenHashContains ¶
TokenHashContains applies the Contains predicate on the "token_hash" field.
func TokenHashContainsFold ¶
TokenHashContainsFold applies the ContainsFold predicate on the "token_hash" field.
func TokenHashEQ ¶
TokenHashEQ applies the EQ predicate on the "token_hash" field.
func TokenHashEqualFold ¶
TokenHashEqualFold applies the EqualFold predicate on the "token_hash" field.
func TokenHashGT ¶
TokenHashGT applies the GT predicate on the "token_hash" field.
func TokenHashGTE ¶
TokenHashGTE applies the GTE predicate on the "token_hash" field.
func TokenHashHasPrefix ¶
TokenHashHasPrefix applies the HasPrefix predicate on the "token_hash" field.
func TokenHashHasSuffix ¶
TokenHashHasSuffix applies the HasSuffix predicate on the "token_hash" field.
func TokenHashIn ¶
TokenHashIn applies the In predicate on the "token_hash" field.
func TokenHashLT ¶
TokenHashLT applies the LT predicate on the "token_hash" field.
func TokenHashLTE ¶
TokenHashLTE applies the LTE predicate on the "token_hash" field.
func TokenHashNEQ ¶
TokenHashNEQ applies the NEQ predicate on the "token_hash" field.
func TokenHashNotIn ¶
TokenHashNotIn applies the NotIn predicate on the "token_hash" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedByID ¶
UpdatedByID applies equality check predicate on the "updated_by_id" field. It's identical to UpdatedByIDEQ.
func UpdatedByIDEQ ¶
UpdatedByIDEQ applies the EQ predicate on the "updated_by_id" field.
func UpdatedByIDGT ¶
UpdatedByIDGT applies the GT predicate on the "updated_by_id" field.
func UpdatedByIDGTE ¶
UpdatedByIDGTE applies the GTE predicate on the "updated_by_id" field.
func UpdatedByIDIn ¶
UpdatedByIDIn applies the In predicate on the "updated_by_id" field.
func UpdatedByIDIsNil ¶
UpdatedByIDIsNil applies the IsNil predicate on the "updated_by_id" field.
func UpdatedByIDLT ¶
UpdatedByIDLT applies the LT predicate on the "updated_by_id" field.
func UpdatedByIDLTE ¶
UpdatedByIDLTE applies the LTE predicate on the "updated_by_id" field.
func UpdatedByIDNEQ ¶
UpdatedByIDNEQ applies the NEQ predicate on the "updated_by_id" field.
func UpdatedByIDNotIn ¶
UpdatedByIDNotIn applies the NotIn predicate on the "updated_by_id" field.
func UpdatedByIDNotNil ¶
UpdatedByIDNotNil applies the NotNil predicate on the "updated_by_id" field.
func UserAgent ¶
UserAgent applies equality check predicate on the "user_agent" field. It's identical to UserAgentEQ.
func UserAgentContains ¶
UserAgentContains applies the Contains predicate on the "user_agent" field.
func UserAgentContainsFold ¶
UserAgentContainsFold applies the ContainsFold predicate on the "user_agent" field.
func UserAgentEQ ¶
UserAgentEQ applies the EQ predicate on the "user_agent" field.
func UserAgentEqualFold ¶
UserAgentEqualFold applies the EqualFold predicate on the "user_agent" field.
func UserAgentGT ¶
UserAgentGT applies the GT predicate on the "user_agent" field.
func UserAgentGTE ¶
UserAgentGTE applies the GTE predicate on the "user_agent" field.
func UserAgentHasPrefix ¶
UserAgentHasPrefix applies the HasPrefix predicate on the "user_agent" field.
func UserAgentHasSuffix ¶
UserAgentHasSuffix applies the HasSuffix predicate on the "user_agent" field.
func UserAgentIn ¶
UserAgentIn applies the In predicate on the "user_agent" field.
func UserAgentIsNil ¶
UserAgentIsNil applies the IsNil predicate on the "user_agent" field.
func UserAgentLT ¶
UserAgentLT applies the LT predicate on the "user_agent" field.
func UserAgentLTE ¶
UserAgentLTE applies the LTE predicate on the "user_agent" field.
func UserAgentNEQ ¶
UserAgentNEQ applies the NEQ predicate on the "user_agent" field.
func UserAgentNotIn ¶
UserAgentNotIn applies the NotIn predicate on the "user_agent" field.
func UserAgentNotNil ¶
UserAgentNotNil applies the NotNil predicate on the "user_agent" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Session queries.
func ByArchivedAt ¶
func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
ByArchivedAt orders the results by the archived_at field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedByID ¶
func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
ByCreatedByID orders the results by the created_by_id field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedByID ¶
func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
ByDeletedByID orders the results by the deleted_by_id field.
func ByExpiresAt ¶
func ByExpiresAt(opts ...sql.OrderTermOption) OrderOption
ByExpiresAt orders the results by the expires_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIPAddress ¶
func ByIPAddress(opts ...sql.OrderTermOption) OrderOption
ByIPAddress orders the results by the ip_address field.
func ByIsRevoked ¶
func ByIsRevoked(opts ...sql.OrderTermOption) OrderOption
ByIsRevoked orders the results by the is_revoked field.
func ByOwnerDomainID ¶
func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption
ByOwnerDomainID orders the results by the owner_domain_id field.
func ByPublishedAt ¶
func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
ByPublishedAt orders the results by the published_at field.
func ByTokenHash ¶
func ByTokenHash(opts ...sql.OrderTermOption) OrderOption
ByTokenHash orders the results by the token_hash field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedByID ¶
func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
ByUpdatedByID orders the results by the updated_by_id field.
func ByUser ¶
func ByUser(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByUser orders the results by user terms.
func ByUserAgent ¶
func ByUserAgent(opts ...sql.OrderTermOption) OrderOption
ByUserAgent orders the results by the user_agent field.
func ByUserCount ¶
func ByUserCount(opts ...sql.OrderTermOption) OrderOption
ByUserCount orders the results by user count.