Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.User) predicate.User
- func ArchivedAt(v time.Time) predicate.User
- func ArchivedAtEQ(v time.Time) predicate.User
- func ArchivedAtGT(v time.Time) predicate.User
- func ArchivedAtGTE(v time.Time) predicate.User
- func ArchivedAtIn(vs ...time.Time) predicate.User
- func ArchivedAtIsNil() predicate.User
- func ArchivedAtLT(v time.Time) predicate.User
- func ArchivedAtLTE(v time.Time) predicate.User
- func ArchivedAtNEQ(v time.Time) predicate.User
- func ArchivedAtNotIn(vs ...time.Time) predicate.User
- func ArchivedAtNotNil() predicate.User
- func Avatar(v string) predicate.User
- func AvatarContains(v string) predicate.User
- func AvatarContainsFold(v string) predicate.User
- func AvatarEQ(v string) predicate.User
- func AvatarEqualFold(v string) predicate.User
- func AvatarGT(v string) predicate.User
- func AvatarGTE(v string) predicate.User
- func AvatarHasPrefix(v string) predicate.User
- func AvatarHasSuffix(v string) predicate.User
- func AvatarIn(vs ...string) predicate.User
- func AvatarIsNil() predicate.User
- func AvatarLT(v string) predicate.User
- func AvatarLTE(v string) predicate.User
- func AvatarNEQ(v string) predicate.User
- func AvatarNotIn(vs ...string) predicate.User
- func AvatarNotNil() predicate.User
- func CreatedAt(v time.Time) predicate.User
- func CreatedAtEQ(v time.Time) predicate.User
- func CreatedAtGT(v time.Time) predicate.User
- func CreatedAtGTE(v time.Time) predicate.User
- func CreatedAtIn(vs ...time.Time) predicate.User
- func CreatedAtIsNil() predicate.User
- func CreatedAtLT(v time.Time) predicate.User
- func CreatedAtLTE(v time.Time) predicate.User
- func CreatedAtNEQ(v time.Time) predicate.User
- func CreatedAtNotIn(vs ...time.Time) predicate.User
- func CreatedAtNotNil() predicate.User
- func CreatedByID(v uuid.UUID) predicate.User
- func CreatedByIDEQ(v uuid.UUID) predicate.User
- func CreatedByIDGT(v uuid.UUID) predicate.User
- func CreatedByIDGTE(v uuid.UUID) predicate.User
- func CreatedByIDIn(vs ...uuid.UUID) predicate.User
- func CreatedByIDIsNil() predicate.User
- func CreatedByIDLT(v uuid.UUID) predicate.User
- func CreatedByIDLTE(v uuid.UUID) predicate.User
- func CreatedByIDNEQ(v uuid.UUID) predicate.User
- func CreatedByIDNotIn(vs ...uuid.UUID) predicate.User
- func CreatedByIDNotNil() predicate.User
- func DeletedAt(v time.Time) predicate.User
- func DeletedAtEQ(v time.Time) predicate.User
- func DeletedAtGT(v time.Time) predicate.User
- func DeletedAtGTE(v time.Time) predicate.User
- func DeletedAtIn(vs ...time.Time) predicate.User
- func DeletedAtIsNil() predicate.User
- func DeletedAtLT(v time.Time) predicate.User
- func DeletedAtLTE(v time.Time) predicate.User
- func DeletedAtNEQ(v time.Time) predicate.User
- func DeletedAtNotIn(vs ...time.Time) predicate.User
- func DeletedAtNotNil() predicate.User
- func DeletedByID(v uuid.UUID) predicate.User
- func DeletedByIDEQ(v uuid.UUID) predicate.User
- func DeletedByIDGT(v uuid.UUID) predicate.User
- func DeletedByIDGTE(v uuid.UUID) predicate.User
- func DeletedByIDIn(vs ...uuid.UUID) predicate.User
- func DeletedByIDIsNil() predicate.User
- func DeletedByIDLT(v uuid.UUID) predicate.User
- func DeletedByIDLTE(v uuid.UUID) predicate.User
- func DeletedByIDNEQ(v uuid.UUID) predicate.User
- func DeletedByIDNotIn(vs ...uuid.UUID) predicate.User
- func DeletedByIDNotNil() predicate.User
- func Email(v string) predicate.User
- func EmailContains(v string) predicate.User
- func EmailContainsFold(v string) predicate.User
- func EmailEQ(v string) predicate.User
- func EmailEqualFold(v string) predicate.User
- func EmailGT(v string) predicate.User
- func EmailGTE(v string) predicate.User
- func EmailHasPrefix(v string) predicate.User
- func EmailHasSuffix(v string) predicate.User
- func EmailIn(vs ...string) predicate.User
- func EmailLT(v string) predicate.User
- func EmailLTE(v string) predicate.User
- func EmailNEQ(v string) predicate.User
- func EmailNotIn(vs ...string) predicate.User
- func HasAPIKeys() predicate.User
- func HasAPIKeysWith(preds ...predicate.ApiKey) predicate.User
- func HasAuditLogs() predicate.User
- func HasAuditLogsWith(preds ...predicate.AuditLog) predicate.User
- func HasMedia() predicate.User
- func HasMediaWith(preds ...predicate.Media) predicate.User
- func HasOperationLogs() predicate.User
- func HasOperationLogsWith(preds ...predicate.OperationLog) predicate.User
- func HasPosts() predicate.User
- func HasPostsWith(preds ...predicate.Post) predicate.User
- func HasRoles() predicate.User
- func HasRolesWith(preds ...predicate.Role) predicate.User
- func HasSessions() predicate.User
- func HasSessionsWith(preds ...predicate.Session) predicate.User
- func HasSystemErrors() predicate.User
- func HasSystemErrorsWith(preds ...predicate.SystemError) predicate.User
- func ID(id uuid.UUID) predicate.User
- func IDEQ(id uuid.UUID) predicate.User
- func IDGT(id uuid.UUID) predicate.User
- func IDGTE(id uuid.UUID) predicate.User
- func IDIn(ids ...uuid.UUID) predicate.User
- func IDLT(id uuid.UUID) predicate.User
- func IDLTE(id uuid.UUID) predicate.User
- func IDNEQ(id uuid.UUID) predicate.User
- func IDNotIn(ids ...uuid.UUID) predicate.User
- func IsSuperAdmin(v bool) predicate.User
- func IsSuperAdminEQ(v bool) predicate.User
- func IsSuperAdminNEQ(v bool) predicate.User
- func MetadataIsNil() predicate.User
- func MetadataNotNil() predicate.User
- func Nickname(v string) predicate.User
- func NicknameContains(v string) predicate.User
- func NicknameContainsFold(v string) predicate.User
- func NicknameEQ(v string) predicate.User
- func NicknameEqualFold(v string) predicate.User
- func NicknameGT(v string) predicate.User
- func NicknameGTE(v string) predicate.User
- func NicknameHasPrefix(v string) predicate.User
- func NicknameHasSuffix(v string) predicate.User
- func NicknameIn(vs ...string) predicate.User
- func NicknameLT(v string) predicate.User
- func NicknameLTE(v string) predicate.User
- func NicknameNEQ(v string) predicate.User
- func NicknameNotIn(vs ...string) predicate.User
- func Not(p predicate.User) predicate.User
- func Or(predicates ...predicate.User) predicate.User
- func OwnerDomainID(v uuid.UUID) predicate.User
- func OwnerDomainIDEQ(v uuid.UUID) predicate.User
- func OwnerDomainIDGT(v uuid.UUID) predicate.User
- func OwnerDomainIDGTE(v uuid.UUID) predicate.User
- func OwnerDomainIDIn(vs ...uuid.UUID) predicate.User
- func OwnerDomainIDIsNil() predicate.User
- func OwnerDomainIDLT(v uuid.UUID) predicate.User
- func OwnerDomainIDLTE(v uuid.UUID) predicate.User
- func OwnerDomainIDNEQ(v uuid.UUID) predicate.User
- func OwnerDomainIDNotIn(vs ...uuid.UUID) predicate.User
- func OwnerDomainIDNotNil() predicate.User
- func PasswordHash(v string) predicate.User
- func PasswordHashContains(v string) predicate.User
- func PasswordHashContainsFold(v string) predicate.User
- func PasswordHashEQ(v string) predicate.User
- func PasswordHashEqualFold(v string) predicate.User
- func PasswordHashGT(v string) predicate.User
- func PasswordHashGTE(v string) predicate.User
- func PasswordHashHasPrefix(v string) predicate.User
- func PasswordHashHasSuffix(v string) predicate.User
- func PasswordHashIn(vs ...string) predicate.User
- func PasswordHashIsNil() predicate.User
- func PasswordHashLT(v string) predicate.User
- func PasswordHashLTE(v string) predicate.User
- func PasswordHashNEQ(v string) predicate.User
- func PasswordHashNotIn(vs ...string) predicate.User
- func PasswordHashNotNil() predicate.User
- func Phone(v string) predicate.User
- func PhoneContains(v string) predicate.User
- func PhoneContainsFold(v string) predicate.User
- func PhoneEQ(v string) predicate.User
- func PhoneEqualFold(v string) predicate.User
- func PhoneGT(v string) predicate.User
- func PhoneGTE(v string) predicate.User
- func PhoneHasPrefix(v string) predicate.User
- func PhoneHasSuffix(v string) predicate.User
- func PhoneIn(vs ...string) predicate.User
- func PhoneIsNil() predicate.User
- func PhoneLT(v string) predicate.User
- func PhoneLTE(v string) predicate.User
- func PhoneNEQ(v string) predicate.User
- func PhoneNotIn(vs ...string) predicate.User
- func PhoneNotNil() predicate.User
- func PublishedAt(v time.Time) predicate.User
- func PublishedAtEQ(v time.Time) predicate.User
- func PublishedAtGT(v time.Time) predicate.User
- func PublishedAtGTE(v time.Time) predicate.User
- func PublishedAtIn(vs ...time.Time) predicate.User
- func PublishedAtIsNil() predicate.User
- func PublishedAtLT(v time.Time) predicate.User
- func PublishedAtLTE(v time.Time) predicate.User
- func PublishedAtNEQ(v time.Time) predicate.User
- func PublishedAtNotIn(vs ...time.Time) predicate.User
- func PublishedAtNotNil() predicate.User
- func StatusEQ(v Status) predicate.User
- func StatusIn(vs ...Status) predicate.User
- func StatusNEQ(v Status) predicate.User
- func StatusNotIn(vs ...Status) predicate.User
- func StatusValidator(s Status) error
- func UpdatedAt(v time.Time) predicate.User
- func UpdatedAtEQ(v time.Time) predicate.User
- func UpdatedAtGT(v time.Time) predicate.User
- func UpdatedAtGTE(v time.Time) predicate.User
- func UpdatedAtIn(vs ...time.Time) predicate.User
- func UpdatedAtIsNil() predicate.User
- func UpdatedAtLT(v time.Time) predicate.User
- func UpdatedAtLTE(v time.Time) predicate.User
- func UpdatedAtNEQ(v time.Time) predicate.User
- func UpdatedAtNotIn(vs ...time.Time) predicate.User
- func UpdatedAtNotNil() predicate.User
- func UpdatedByID(v uuid.UUID) predicate.User
- func UpdatedByIDEQ(v uuid.UUID) predicate.User
- func UpdatedByIDGT(v uuid.UUID) predicate.User
- func UpdatedByIDGTE(v uuid.UUID) predicate.User
- func UpdatedByIDIn(vs ...uuid.UUID) predicate.User
- func UpdatedByIDIsNil() predicate.User
- func UpdatedByIDLT(v uuid.UUID) predicate.User
- func UpdatedByIDLTE(v uuid.UUID) predicate.User
- func UpdatedByIDNEQ(v uuid.UUID) predicate.User
- func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.User
- func UpdatedByIDNotNil() predicate.User
- func Username(v string) predicate.User
- func UsernameContains(v string) predicate.User
- func UsernameContainsFold(v string) predicate.User
- func UsernameEQ(v string) predicate.User
- func UsernameEqualFold(v string) predicate.User
- func UsernameGT(v string) predicate.User
- func UsernameGTE(v string) predicate.User
- func UsernameHasPrefix(v string) predicate.User
- func UsernameHasSuffix(v string) predicate.User
- func UsernameIn(vs ...string) predicate.User
- func UsernameLT(v string) predicate.User
- func UsernameLTE(v string) predicate.User
- func UsernameNEQ(v string) predicate.User
- func UsernameNotIn(vs ...string) predicate.User
- func ValidColumn(column string) bool
- type OrderOption
- func ByAPIKeys(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByAPIKeysCount(opts ...sql.OrderTermOption) OrderOption
- func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
- func ByAuditLogs(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByAuditLogsCount(opts ...sql.OrderTermOption) OrderOption
- func ByAvatar(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
- func ByEmail(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIsSuperAdmin(opts ...sql.OrderTermOption) OrderOption
- func ByMedia(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByMediaCount(opts ...sql.OrderTermOption) OrderOption
- func ByNickname(opts ...sql.OrderTermOption) OrderOption
- func ByOperationLogs(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByOperationLogsCount(opts ...sql.OrderTermOption) OrderOption
- func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption
- func ByPasswordHash(opts ...sql.OrderTermOption) OrderOption
- func ByPhone(opts ...sql.OrderTermOption) OrderOption
- func ByPosts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByPostsCount(opts ...sql.OrderTermOption) OrderOption
- func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
- func ByRoles(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByRolesCount(opts ...sql.OrderTermOption) OrderOption
- func BySessions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func BySessionsCount(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func BySystemErrors(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func BySystemErrorsCount(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
- func ByUsername(opts ...sql.OrderTermOption) OrderOption
- type Status
Constants ¶
const ( // Label holds the string label denoting the user type in the database. Label = "user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedByID holds the string denoting the created_by_id field in the database. FieldCreatedByID = "created_by_id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedByID holds the string denoting the updated_by_id field in the database. FieldUpdatedByID = "updated_by_id" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedByID holds the string denoting the deleted_by_id field in the database. FieldDeletedByID = "deleted_by_id" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldPublishedAt holds the string denoting the published_at field in the database. FieldPublishedAt = "published_at" // FieldArchivedAt holds the string denoting the archived_at field in the database. FieldArchivedAt = "archived_at" // FieldOwnerDomainID holds the string denoting the owner_domain_id field in the database. FieldOwnerDomainID = "owner_domain_id" // FieldUsername holds the string denoting the username field in the database. FieldUsername = "username" // FieldEmail holds the string denoting the email field in the database. FieldEmail = "email" // FieldPasswordHash holds the string denoting the password_hash field in the database. FieldPasswordHash = "password_hash" // FieldNickname holds the string denoting the nickname field in the database. FieldNickname = "nickname" // FieldPhone holds the string denoting the phone field in the database. FieldPhone = "phone" // FieldAvatar holds the string denoting the avatar field in the database. FieldAvatar = "avatar" // FieldIsSuperAdmin holds the string denoting the is_super_admin field in the database. FieldIsSuperAdmin = "is_super_admin" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldMetadata holds the string denoting the metadata field in the database. FieldMetadata = "metadata" // EdgeRoles holds the string denoting the roles edge name in mutations. EdgeRoles = "roles" // EdgePosts holds the string denoting the posts edge name in mutations. EdgePosts = "posts" // EdgeMedia holds the string denoting the media edge name in mutations. EdgeMedia = "media" // EdgeAPIKeys holds the string denoting the api_keys edge name in mutations. EdgeAPIKeys = "api_keys" // EdgeSessions holds the string denoting the sessions edge name in mutations. EdgeSessions = "sessions" // EdgeAuditLogs holds the string denoting the audit_logs edge name in mutations. EdgeAuditLogs = "audit_logs" // EdgeOperationLogs holds the string denoting the operation_logs edge name in mutations. EdgeOperationLogs = "operation_logs" // EdgeSystemErrors holds the string denoting the system_errors edge name in mutations. EdgeSystemErrors = "system_errors" // Table holds the table name of the user in the database. Table = "users" // RolesTable is the table that holds the roles relation/edge. The primary key declared below. RolesTable = "user_roles" // RolesInverseTable is the table name for the Role entity. // It exists in this package in order to avoid circular dependency with the "role" package. RolesInverseTable = "roles" // PostsTable is the table that holds the posts relation/edge. The primary key declared below. PostsTable = "user_posts" // PostsInverseTable is the table name for the Post entity. // It exists in this package in order to avoid circular dependency with the "post" package. PostsInverseTable = "posts" // MediaTable is the table that holds the media relation/edge. MediaTable = "media" // MediaInverseTable is the table name for the Media entity. // It exists in this package in order to avoid circular dependency with the "media" package. MediaInverseTable = "media" // MediaColumn is the table column denoting the media relation/edge. MediaColumn = "owner_id" // APIKeysTable is the table that holds the api_keys relation/edge. APIKeysTable = "api_keys" // APIKeysInverseTable is the table name for the ApiKey entity. // It exists in this package in order to avoid circular dependency with the "apikey" package. APIKeysInverseTable = "api_keys" // APIKeysColumn is the table column denoting the api_keys relation/edge. APIKeysColumn = "user_api_keys" // SessionsTable is the table that holds the sessions relation/edge. The primary key declared below. SessionsTable = "user_sessions" // SessionsInverseTable is the table name for the Session entity. // It exists in this package in order to avoid circular dependency with the "session" package. SessionsInverseTable = "sessions" // AuditLogsTable is the table that holds the audit_logs relation/edge. The primary key declared below. AuditLogsTable = "user_audit_logs" // AuditLogsInverseTable is the table name for the AuditLog entity. // It exists in this package in order to avoid circular dependency with the "auditlog" package. AuditLogsInverseTable = "audit_logs" // OperationLogsTable is the table that holds the operation_logs relation/edge. OperationLogsTable = "operation_logs" // OperationLogsInverseTable is the table name for the OperationLog entity. // It exists in this package in order to avoid circular dependency with the "operationlog" package. OperationLogsInverseTable = "operation_logs" // OperationLogsColumn is the table column denoting the operation_logs relation/edge. OperationLogsColumn = "user_id" // SystemErrorsTable is the table that holds the system_errors relation/edge. SystemErrorsTable = "system_errors" // SystemErrorsInverseTable is the table name for the SystemError entity. // It exists in this package in order to avoid circular dependency with the "systemerror" package. SystemErrorsInverseTable = "system_errors" // SystemErrorsColumn is the table column denoting the system_errors relation/edge. SystemErrorsColumn = "user_id" )
const DefaultStatus = StatusActive
StatusActive is the default value of the Status enum.
Variables ¶
var ( // RolesPrimaryKey and RolesColumn2 are the table columns denoting the // primary key for the roles relation (M2M). RolesPrimaryKey = []string{"user_id", "role_id"} // PostsPrimaryKey and PostsColumn2 are the table columns denoting the // primary key for the posts relation (M2M). PostsPrimaryKey = []string{"user_id", "post_id"} // SessionsPrimaryKey and SessionsColumn2 are the table columns denoting the // primary key for the sessions relation (M2M). SessionsPrimaryKey = []string{"user_id", "session_id"} // AuditLogsPrimaryKey and AuditLogsColumn2 are the table columns denoting the // primary key for the audit_logs relation (M2M). AuditLogsPrimaryKey = []string{"user_id", "audit_log_id"} )
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // UsernameValidator is a validator for the "username" field. It is called by the builders before save. UsernameValidator func(string) error // EmailValidator is a validator for the "email" field. It is called by the builders before save. EmailValidator func(string) error // DefaultNickname holds the default value on creation for the "nickname" field. DefaultNickname string // DefaultIsSuperAdmin holds the default value on creation for the "is_super_admin" field. DefaultIsSuperAdmin bool // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldCreatedByID, FieldCreatedAt, FieldUpdatedByID, FieldUpdatedAt, FieldDeletedByID, FieldDeletedAt, FieldPublishedAt, FieldArchivedAt, FieldOwnerDomainID, FieldUsername, FieldEmail, FieldPasswordHash, FieldNickname, FieldPhone, FieldAvatar, FieldIsSuperAdmin, FieldStatus, FieldMetadata, }
Columns holds all SQL columns for user fields.
Functions ¶
func ArchivedAt ¶
ArchivedAt applies equality check predicate on the "archived_at" field. It's identical to ArchivedAtEQ.
func ArchivedAtEQ ¶
ArchivedAtEQ applies the EQ predicate on the "archived_at" field.
func ArchivedAtGT ¶
ArchivedAtGT applies the GT predicate on the "archived_at" field.
func ArchivedAtGTE ¶
ArchivedAtGTE applies the GTE predicate on the "archived_at" field.
func ArchivedAtIn ¶
ArchivedAtIn applies the In predicate on the "archived_at" field.
func ArchivedAtIsNil ¶
ArchivedAtIsNil applies the IsNil predicate on the "archived_at" field.
func ArchivedAtLT ¶
ArchivedAtLT applies the LT predicate on the "archived_at" field.
func ArchivedAtLTE ¶
ArchivedAtLTE applies the LTE predicate on the "archived_at" field.
func ArchivedAtNEQ ¶
ArchivedAtNEQ applies the NEQ predicate on the "archived_at" field.
func ArchivedAtNotIn ¶
ArchivedAtNotIn applies the NotIn predicate on the "archived_at" field.
func ArchivedAtNotNil ¶
ArchivedAtNotNil applies the NotNil predicate on the "archived_at" field.
func Avatar ¶
Avatar applies equality check predicate on the "avatar" field. It's identical to AvatarEQ.
func AvatarContains ¶
AvatarContains applies the Contains predicate on the "avatar" field.
func AvatarContainsFold ¶
AvatarContainsFold applies the ContainsFold predicate on the "avatar" field.
func AvatarEqualFold ¶
AvatarEqualFold applies the EqualFold predicate on the "avatar" field.
func AvatarHasPrefix ¶
AvatarHasPrefix applies the HasPrefix predicate on the "avatar" field.
func AvatarHasSuffix ¶
AvatarHasSuffix applies the HasSuffix predicate on the "avatar" field.
func AvatarIsNil ¶
AvatarIsNil applies the IsNil predicate on the "avatar" field.
func AvatarNotIn ¶
AvatarNotIn applies the NotIn predicate on the "avatar" field.
func AvatarNotNil ¶
AvatarNotNil applies the NotNil predicate on the "avatar" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedByID ¶
CreatedByID applies equality check predicate on the "created_by_id" field. It's identical to CreatedByIDEQ.
func CreatedByIDEQ ¶
CreatedByIDEQ applies the EQ predicate on the "created_by_id" field.
func CreatedByIDGT ¶
CreatedByIDGT applies the GT predicate on the "created_by_id" field.
func CreatedByIDGTE ¶
CreatedByIDGTE applies the GTE predicate on the "created_by_id" field.
func CreatedByIDIn ¶
CreatedByIDIn applies the In predicate on the "created_by_id" field.
func CreatedByIDIsNil ¶
CreatedByIDIsNil applies the IsNil predicate on the "created_by_id" field.
func CreatedByIDLT ¶
CreatedByIDLT applies the LT predicate on the "created_by_id" field.
func CreatedByIDLTE ¶
CreatedByIDLTE applies the LTE predicate on the "created_by_id" field.
func CreatedByIDNEQ ¶
CreatedByIDNEQ applies the NEQ predicate on the "created_by_id" field.
func CreatedByIDNotIn ¶
CreatedByIDNotIn applies the NotIn predicate on the "created_by_id" field.
func CreatedByIDNotNil ¶
CreatedByIDNotNil applies the NotNil predicate on the "created_by_id" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedByID ¶
DeletedByID applies equality check predicate on the "deleted_by_id" field. It's identical to DeletedByIDEQ.
func DeletedByIDEQ ¶
DeletedByIDEQ applies the EQ predicate on the "deleted_by_id" field.
func DeletedByIDGT ¶
DeletedByIDGT applies the GT predicate on the "deleted_by_id" field.
func DeletedByIDGTE ¶
DeletedByIDGTE applies the GTE predicate on the "deleted_by_id" field.
func DeletedByIDIn ¶
DeletedByIDIn applies the In predicate on the "deleted_by_id" field.
func DeletedByIDIsNil ¶
DeletedByIDIsNil applies the IsNil predicate on the "deleted_by_id" field.
func DeletedByIDLT ¶
DeletedByIDLT applies the LT predicate on the "deleted_by_id" field.
func DeletedByIDLTE ¶
DeletedByIDLTE applies the LTE predicate on the "deleted_by_id" field.
func DeletedByIDNEQ ¶
DeletedByIDNEQ applies the NEQ predicate on the "deleted_by_id" field.
func DeletedByIDNotIn ¶
DeletedByIDNotIn applies the NotIn predicate on the "deleted_by_id" field.
func DeletedByIDNotNil ¶
DeletedByIDNotNil applies the NotNil predicate on the "deleted_by_id" field.
func Email ¶
Email applies equality check predicate on the "email" field. It's identical to EmailEQ.
func EmailContains ¶
EmailContains applies the Contains predicate on the "email" field.
func EmailContainsFold ¶
EmailContainsFold applies the ContainsFold predicate on the "email" field.
func EmailEqualFold ¶
EmailEqualFold applies the EqualFold predicate on the "email" field.
func EmailHasPrefix ¶
EmailHasPrefix applies the HasPrefix predicate on the "email" field.
func EmailHasSuffix ¶
EmailHasSuffix applies the HasSuffix predicate on the "email" field.
func EmailNotIn ¶
EmailNotIn applies the NotIn predicate on the "email" field.
func HasAPIKeys ¶
HasAPIKeys applies the HasEdge predicate on the "api_keys" edge.
func HasAPIKeysWith ¶
HasAPIKeysWith applies the HasEdge predicate on the "api_keys" edge with a given conditions (other predicates).
func HasAuditLogs ¶
HasAuditLogs applies the HasEdge predicate on the "audit_logs" edge.
func HasAuditLogsWith ¶
HasAuditLogsWith applies the HasEdge predicate on the "audit_logs" edge with a given conditions (other predicates).
func HasMediaWith ¶
HasMediaWith applies the HasEdge predicate on the "media" edge with a given conditions (other predicates).
func HasOperationLogs ¶
HasOperationLogs applies the HasEdge predicate on the "operation_logs" edge.
func HasOperationLogsWith ¶
func HasOperationLogsWith(preds ...predicate.OperationLog) predicate.User
HasOperationLogsWith applies the HasEdge predicate on the "operation_logs" edge with a given conditions (other predicates).
func HasPostsWith ¶
HasPostsWith applies the HasEdge predicate on the "posts" edge with a given conditions (other predicates).
func HasRolesWith ¶
HasRolesWith applies the HasEdge predicate on the "roles" edge with a given conditions (other predicates).
func HasSessions ¶
HasSessions applies the HasEdge predicate on the "sessions" edge.
func HasSessionsWith ¶
HasSessionsWith applies the HasEdge predicate on the "sessions" edge with a given conditions (other predicates).
func HasSystemErrors ¶
HasSystemErrors applies the HasEdge predicate on the "system_errors" edge.
func HasSystemErrorsWith ¶
func HasSystemErrorsWith(preds ...predicate.SystemError) predicate.User
HasSystemErrorsWith applies the HasEdge predicate on the "system_errors" edge with a given conditions (other predicates).
func IsSuperAdmin ¶
IsSuperAdmin applies equality check predicate on the "is_super_admin" field. It's identical to IsSuperAdminEQ.
func IsSuperAdminEQ ¶
IsSuperAdminEQ applies the EQ predicate on the "is_super_admin" field.
func IsSuperAdminNEQ ¶
IsSuperAdminNEQ applies the NEQ predicate on the "is_super_admin" field.
func MetadataIsNil ¶
MetadataIsNil applies the IsNil predicate on the "metadata" field.
func MetadataNotNil ¶
MetadataNotNil applies the NotNil predicate on the "metadata" field.
func Nickname ¶
Nickname applies equality check predicate on the "nickname" field. It's identical to NicknameEQ.
func NicknameContains ¶
NicknameContains applies the Contains predicate on the "nickname" field.
func NicknameContainsFold ¶
NicknameContainsFold applies the ContainsFold predicate on the "nickname" field.
func NicknameEQ ¶
NicknameEQ applies the EQ predicate on the "nickname" field.
func NicknameEqualFold ¶
NicknameEqualFold applies the EqualFold predicate on the "nickname" field.
func NicknameGT ¶
NicknameGT applies the GT predicate on the "nickname" field.
func NicknameGTE ¶
NicknameGTE applies the GTE predicate on the "nickname" field.
func NicknameHasPrefix ¶
NicknameHasPrefix applies the HasPrefix predicate on the "nickname" field.
func NicknameHasSuffix ¶
NicknameHasSuffix applies the HasSuffix predicate on the "nickname" field.
func NicknameIn ¶
NicknameIn applies the In predicate on the "nickname" field.
func NicknameLT ¶
NicknameLT applies the LT predicate on the "nickname" field.
func NicknameLTE ¶
NicknameLTE applies the LTE predicate on the "nickname" field.
func NicknameNEQ ¶
NicknameNEQ applies the NEQ predicate on the "nickname" field.
func NicknameNotIn ¶
NicknameNotIn applies the NotIn predicate on the "nickname" field.
func OwnerDomainID ¶
OwnerDomainID applies equality check predicate on the "owner_domain_id" field. It's identical to OwnerDomainIDEQ.
func OwnerDomainIDEQ ¶
OwnerDomainIDEQ applies the EQ predicate on the "owner_domain_id" field.
func OwnerDomainIDGT ¶
OwnerDomainIDGT applies the GT predicate on the "owner_domain_id" field.
func OwnerDomainIDGTE ¶
OwnerDomainIDGTE applies the GTE predicate on the "owner_domain_id" field.
func OwnerDomainIDIn ¶
OwnerDomainIDIn applies the In predicate on the "owner_domain_id" field.
func OwnerDomainIDIsNil ¶
OwnerDomainIDIsNil applies the IsNil predicate on the "owner_domain_id" field.
func OwnerDomainIDLT ¶
OwnerDomainIDLT applies the LT predicate on the "owner_domain_id" field.
func OwnerDomainIDLTE ¶
OwnerDomainIDLTE applies the LTE predicate on the "owner_domain_id" field.
func OwnerDomainIDNEQ ¶
OwnerDomainIDNEQ applies the NEQ predicate on the "owner_domain_id" field.
func OwnerDomainIDNotIn ¶
OwnerDomainIDNotIn applies the NotIn predicate on the "owner_domain_id" field.
func OwnerDomainIDNotNil ¶
OwnerDomainIDNotNil applies the NotNil predicate on the "owner_domain_id" field.
func PasswordHash ¶
PasswordHash applies equality check predicate on the "password_hash" field. It's identical to PasswordHashEQ.
func PasswordHashContains ¶
PasswordHashContains applies the Contains predicate on the "password_hash" field.
func PasswordHashContainsFold ¶
PasswordHashContainsFold applies the ContainsFold predicate on the "password_hash" field.
func PasswordHashEQ ¶
PasswordHashEQ applies the EQ predicate on the "password_hash" field.
func PasswordHashEqualFold ¶
PasswordHashEqualFold applies the EqualFold predicate on the "password_hash" field.
func PasswordHashGT ¶
PasswordHashGT applies the GT predicate on the "password_hash" field.
func PasswordHashGTE ¶
PasswordHashGTE applies the GTE predicate on the "password_hash" field.
func PasswordHashHasPrefix ¶
PasswordHashHasPrefix applies the HasPrefix predicate on the "password_hash" field.
func PasswordHashHasSuffix ¶
PasswordHashHasSuffix applies the HasSuffix predicate on the "password_hash" field.
func PasswordHashIn ¶
PasswordHashIn applies the In predicate on the "password_hash" field.
func PasswordHashIsNil ¶
PasswordHashIsNil applies the IsNil predicate on the "password_hash" field.
func PasswordHashLT ¶
PasswordHashLT applies the LT predicate on the "password_hash" field.
func PasswordHashLTE ¶
PasswordHashLTE applies the LTE predicate on the "password_hash" field.
func PasswordHashNEQ ¶
PasswordHashNEQ applies the NEQ predicate on the "password_hash" field.
func PasswordHashNotIn ¶
PasswordHashNotIn applies the NotIn predicate on the "password_hash" field.
func PasswordHashNotNil ¶
PasswordHashNotNil applies the NotNil predicate on the "password_hash" field.
func Phone ¶
Phone applies equality check predicate on the "phone" field. It's identical to PhoneEQ.
func PhoneContains ¶
PhoneContains applies the Contains predicate on the "phone" field.
func PhoneContainsFold ¶
PhoneContainsFold applies the ContainsFold predicate on the "phone" field.
func PhoneEqualFold ¶
PhoneEqualFold applies the EqualFold predicate on the "phone" field.
func PhoneHasPrefix ¶
PhoneHasPrefix applies the HasPrefix predicate on the "phone" field.
func PhoneHasSuffix ¶
PhoneHasSuffix applies the HasSuffix predicate on the "phone" field.
func PhoneIsNil ¶
PhoneIsNil applies the IsNil predicate on the "phone" field.
func PhoneNotIn ¶
PhoneNotIn applies the NotIn predicate on the "phone" field.
func PhoneNotNil ¶
PhoneNotNil applies the NotNil predicate on the "phone" field.
func PublishedAt ¶
PublishedAt applies equality check predicate on the "published_at" field. It's identical to PublishedAtEQ.
func PublishedAtEQ ¶
PublishedAtEQ applies the EQ predicate on the "published_at" field.
func PublishedAtGT ¶
PublishedAtGT applies the GT predicate on the "published_at" field.
func PublishedAtGTE ¶
PublishedAtGTE applies the GTE predicate on the "published_at" field.
func PublishedAtIn ¶
PublishedAtIn applies the In predicate on the "published_at" field.
func PublishedAtIsNil ¶
PublishedAtIsNil applies the IsNil predicate on the "published_at" field.
func PublishedAtLT ¶
PublishedAtLT applies the LT predicate on the "published_at" field.
func PublishedAtLTE ¶
PublishedAtLTE applies the LTE predicate on the "published_at" field.
func PublishedAtNEQ ¶
PublishedAtNEQ applies the NEQ predicate on the "published_at" field.
func PublishedAtNotIn ¶
PublishedAtNotIn applies the NotIn predicate on the "published_at" field.
func PublishedAtNotNil ¶
PublishedAtNotNil applies the NotNil predicate on the "published_at" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func StatusValidator ¶
StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedByID ¶
UpdatedByID applies equality check predicate on the "updated_by_id" field. It's identical to UpdatedByIDEQ.
func UpdatedByIDEQ ¶
UpdatedByIDEQ applies the EQ predicate on the "updated_by_id" field.
func UpdatedByIDGT ¶
UpdatedByIDGT applies the GT predicate on the "updated_by_id" field.
func UpdatedByIDGTE ¶
UpdatedByIDGTE applies the GTE predicate on the "updated_by_id" field.
func UpdatedByIDIn ¶
UpdatedByIDIn applies the In predicate on the "updated_by_id" field.
func UpdatedByIDIsNil ¶
UpdatedByIDIsNil applies the IsNil predicate on the "updated_by_id" field.
func UpdatedByIDLT ¶
UpdatedByIDLT applies the LT predicate on the "updated_by_id" field.
func UpdatedByIDLTE ¶
UpdatedByIDLTE applies the LTE predicate on the "updated_by_id" field.
func UpdatedByIDNEQ ¶
UpdatedByIDNEQ applies the NEQ predicate on the "updated_by_id" field.
func UpdatedByIDNotIn ¶
UpdatedByIDNotIn applies the NotIn predicate on the "updated_by_id" field.
func UpdatedByIDNotNil ¶
UpdatedByIDNotNil applies the NotNil predicate on the "updated_by_id" field.
func Username ¶
Username applies equality check predicate on the "username" field. It's identical to UsernameEQ.
func UsernameContains ¶
UsernameContains applies the Contains predicate on the "username" field.
func UsernameContainsFold ¶
UsernameContainsFold applies the ContainsFold predicate on the "username" field.
func UsernameEQ ¶
UsernameEQ applies the EQ predicate on the "username" field.
func UsernameEqualFold ¶
UsernameEqualFold applies the EqualFold predicate on the "username" field.
func UsernameGT ¶
UsernameGT applies the GT predicate on the "username" field.
func UsernameGTE ¶
UsernameGTE applies the GTE predicate on the "username" field.
func UsernameHasPrefix ¶
UsernameHasPrefix applies the HasPrefix predicate on the "username" field.
func UsernameHasSuffix ¶
UsernameHasSuffix applies the HasSuffix predicate on the "username" field.
func UsernameIn ¶
UsernameIn applies the In predicate on the "username" field.
func UsernameLT ¶
UsernameLT applies the LT predicate on the "username" field.
func UsernameLTE ¶
UsernameLTE applies the LTE predicate on the "username" field.
func UsernameNEQ ¶
UsernameNEQ applies the NEQ predicate on the "username" field.
func UsernameNotIn ¶
UsernameNotIn applies the NotIn predicate on the "username" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the User queries.
func ByAPIKeys ¶
func ByAPIKeys(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByAPIKeys orders the results by api_keys terms.
func ByAPIKeysCount ¶
func ByAPIKeysCount(opts ...sql.OrderTermOption) OrderOption
ByAPIKeysCount orders the results by api_keys count.
func ByArchivedAt ¶
func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
ByArchivedAt orders the results by the archived_at field.
func ByAuditLogs ¶
func ByAuditLogs(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByAuditLogs orders the results by audit_logs terms.
func ByAuditLogsCount ¶
func ByAuditLogsCount(opts ...sql.OrderTermOption) OrderOption
ByAuditLogsCount orders the results by audit_logs count.
func ByAvatar ¶
func ByAvatar(opts ...sql.OrderTermOption) OrderOption
ByAvatar orders the results by the avatar field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedByID ¶
func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
ByCreatedByID orders the results by the created_by_id field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedByID ¶
func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
ByDeletedByID orders the results by the deleted_by_id field.
func ByEmail ¶
func ByEmail(opts ...sql.OrderTermOption) OrderOption
ByEmail orders the results by the email field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIsSuperAdmin ¶
func ByIsSuperAdmin(opts ...sql.OrderTermOption) OrderOption
ByIsSuperAdmin orders the results by the is_super_admin field.
func ByMedia ¶
func ByMedia(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByMedia orders the results by media terms.
func ByMediaCount ¶
func ByMediaCount(opts ...sql.OrderTermOption) OrderOption
ByMediaCount orders the results by media count.
func ByNickname ¶
func ByNickname(opts ...sql.OrderTermOption) OrderOption
ByNickname orders the results by the nickname field.
func ByOperationLogs ¶
func ByOperationLogs(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByOperationLogs orders the results by operation_logs terms.
func ByOperationLogsCount ¶
func ByOperationLogsCount(opts ...sql.OrderTermOption) OrderOption
ByOperationLogsCount orders the results by operation_logs count.
func ByOwnerDomainID ¶
func ByOwnerDomainID(opts ...sql.OrderTermOption) OrderOption
ByOwnerDomainID orders the results by the owner_domain_id field.
func ByPasswordHash ¶
func ByPasswordHash(opts ...sql.OrderTermOption) OrderOption
ByPasswordHash orders the results by the password_hash field.
func ByPhone ¶
func ByPhone(opts ...sql.OrderTermOption) OrderOption
ByPhone orders the results by the phone field.
func ByPosts ¶
func ByPosts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByPosts orders the results by posts terms.
func ByPostsCount ¶
func ByPostsCount(opts ...sql.OrderTermOption) OrderOption
ByPostsCount orders the results by posts count.
func ByPublishedAt ¶
func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
ByPublishedAt orders the results by the published_at field.
func ByRoles ¶
func ByRoles(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByRoles orders the results by roles terms.
func ByRolesCount ¶
func ByRolesCount(opts ...sql.OrderTermOption) OrderOption
ByRolesCount orders the results by roles count.
func BySessions ¶
func BySessions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
BySessions orders the results by sessions terms.
func BySessionsCount ¶
func BySessionsCount(opts ...sql.OrderTermOption) OrderOption
BySessionsCount orders the results by sessions count.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func BySystemErrors ¶
func BySystemErrors(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
BySystemErrors orders the results by system_errors terms.
func BySystemErrorsCount ¶
func BySystemErrorsCount(opts ...sql.OrderTermOption) OrderOption
BySystemErrorsCount orders the results by system_errors count.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedByID ¶
func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
ByUpdatedByID orders the results by the updated_by_id field.
func ByUsername ¶
func ByUsername(opts ...sql.OrderTermOption) OrderOption
ByUsername orders the results by the username field.